#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <math.h>
#include "sysstuff.h"
#include "typedefs.h"
#include "macros.h"
#include "smalloc.h"
#include "assert.h"
#include "physics.h"
#include "macros.h"
#include "vec.h"
#include "force.h"
#include "invblock.h"
#include "confio.h"
#include "nsb.h"
#include "names.h"
#include "network.h"
#include "wnblist.h"
#include "pbc.h"
#include "ns.h"
#include "nrnb.h"
#include "bondf.h"
#include "mshift.h"
#include "txtdump.h"
#include "copyrite.h"
#include <stdio.h>
#include <string.h>
#include "typedefs.h"
#include "gmx_random.h"
#include "lambdadynamics.h"
#include <stdlib.h>
#ifdef GMX_MPI
#include <mpi.h>
#endif

int ts_array = 4;
double adaption_treshold = 15.0; /* in picoseconds */
double group_count = 0; /* number of lambda groups */


/* ftegele: gauss distributed random number generator
   based on the box mueller method

   ASSUMES AN INITIALIZED RANDOM NUMBER GENERATOR
   for compatbility reasons function rand() is used */

/* this version is the polar form   */
/* similar to the orginal gaussdist */
real rnd_gauss_box_mueller(void) {
    real x1, x2, w, y1, y2; 
         do {
           x1 = 2.0 * rand()/RAND_MAX - 1.0;
           x2 = 2.0 * rand()/RAND_MAX - 1.0;
            w = x1 * x1 + x2 * x2;
         } while ( w >= 1.0 );

         w = sqrt( (-2.0 * log( w ) ) / w );
         //y2 = x2 * w;
    return x1*w;
}


real gaussdist(gmx_rng_t rng,real sigma){
  real r=2.0,x,y;
  do{
    x = 2.0*(real)gmx_rng_uniform_real(rng)-1.0;
    y = 2.0*(real)gmx_rng_uniform_real(rng)-1.0;
    r = x*x+y*y;
  }while(r>1.0||r==0.0);
  r = x*sqrt(-2.0*log(r)/r);
  r = r*sigma;
  return (r);
}

// returns -1 on error, 1 on EOF, 0 else
int read_ph_data(FILE* dat, struct ph_adapt* ph) {
    char temp[255];
    ph->next = (struct ph_adapt*)  malloc (sizeof (struct ph_adapt));
    ph->residue = malloc( sizeof(char) * 129); // alloc 129 byte to store 128 byte long residue names...

    /* temp could be checked whether correct information is entered */
    if (fscanf(dat, "residue = %s;\n",ph->residue) == EOF)
	return 1;
    if (fscanf(dat, "%s = %g;\n", temp, &(ph->const_a)) == EOF)
	return -1;
    if (fscanf(dat, "%s = %g;\n", temp, &(ph->ph_a)) == EOF)
	return -1;
    if (fscanf(dat, "%s = %g;\n", temp, &(ph->const_2)) == EOF)
	return -1;
    if (fscanf(dat, "%s = %g;\n", temp, &(ph->const_3)) == EOF)
	return -1;
    if (fscanf(dat, "%s = %g;\n", temp, &(ph->const_b)) == EOF)
	return -1;
    if (fscanf(dat, "%s = %g;\n", temp, &(ph->ph_b)) == EOF)
	return -1;    
//    fprintf(stderr, "Read in: %s, %g, %g, %g, %g, %g, %g\n", ph->residue, ph->const_a, ph->ph_a, ph->const_2,ph->const_3,ph->const_b, ph->ph_b);
    if ( (strncmp( (ph->residue),"HIS",3)==0) ) 
      ph->second_pka=14.1;
    else
      ph->second_pka=0; 

    fprintf(stderr, "Read in:first pka=%g; second_pka=%g\n",-(ph->const_b/ph->ph_b),ph->second_pka);

    return 0;
}

/* allocates the memory and initializes data for the multi lambda control */
/* assumes that groups provided in the data file are correctly mapping
   to atoms perturbed in the topology */
void init_mlrec(t_mdatoms *atoms, t_commrec *cr, t_inputrec *ir){
  int xpos,i;
  FILE* dat;
  char temp[255];
  char top2file[255];
  char outfilename[255];
  struct multi_lambda *tmp = NULL;
  struct multi_lambda *old = NULL;
  struct multi_lambda *tmp_temp = NULL;
  int cont_reading = 1;
  real initial_lambda = 0.0;
  FILE* dat_his;
  double micro_pka1, micro_pka2;

  if((dat = fopen("lambda_groups.dat","r")) == NULL)
        fprintf(stderr, "ERROR OPENING lambda_groups.dat!!!!\n");

  /* it is assumed that this file is not empty */
  /* structure of the file:
      name = %s
      initial lambda = %lg
      number of atoms = %i
      atom1 atom2 atom3 atom4 ...
      
      name = %s
      .
      .
      .
   */


  //fprintf(stderr, "Version 0.95 - adaptive Barrier potential and all the cool stuff\n");
  fprintf(stderr, "Version 1.3 - Constant pH MD (1 lambda/node) with Gromacs 3.3.3 \n");

  //  if (atoms->nPerturbed > 0) //there are perturbed atoms
	// {
    ml_rec = tmp = malloc ( sizeof (struct multi_lambda));
    while (cont_reading == 1)
    { 
      fprintf(stderr, "Reading in with cont_reading = %i\n", cont_reading);
      
      tmp->name = malloc ( sizeof ( char) * 256 );
      tmp->lambda = malloc ( sizeof ( struct t_ldrec));
      
      /* use the index file to read in the different lambda dynamics groups */
      /* assume we have read in atoms 3,4,5,6 */

      if (fscanf(dat, "%s = %s\n",temp, tmp->name) != 2)
      {
        /* if here is an readin failure, this means the file is at its end,
           simply exit */
 fprintf(stderr,"Reading is ending here... %s und %s\n", temp, tmp->name);
        cont_reading = 0;
      }
      else
      {
        /* there is no error */
	//sprintf(outfilename,""); //define the output file name for this lambda group 
        //tmp->out = ffopen("lambdadynamics.xvg","w");  

        fscanf(dat, "%s = %i\n", temp, &(tmp->residue_number));
		fprintf(stderr,"%s\n", temp);
        fscanf(dat, "%s = %g\n", temp, &initial_lambda);
		fprintf(stderr,"%s\n", temp);
        fscanf(dat, "%s = %g\n", temp, &tmp->barrier_l2_0);
		fprintf(stderr,"%s\n", temp);
        fscanf(dat, "%s = %g\n", temp, &tmp->barrier_l2_1);
		fprintf(stderr,"%s\n", temp);
        fscanf(dat, "%s = %d\n", temp, &tmp->pts);
		fprintf(stderr,"%s\n", temp);
        fscanf(dat, "%s = %g\n", temp, &tmp->interval_adapt_barr);
		fprintf(stderr,"%s\n", temp);
        fscanf(dat, "%s = %i\n", temp, &(tmp->nr_atoms));
		fprintf(stderr,"%s\n", temp);
		fprintf(stderr, "Reading in %i atoms for lambda group %s with initial lambda = %g spline_points = %d and barrier_l2_0 = %g barrier_l2_1 = %g\n", tmp->nr_atoms, tmp->name, initial_lambda,tmp->pts,tmp->barrier_l2_0,tmp->barrier_l2_1);

        group_count+=1.0;	

        tmp->atoms = malloc ( sizeof(int) * tmp->nr_atoms);
        tmp->chargeA = malloc ( sizeof(real) * tmp->nr_atoms);
        tmp->chargeB = malloc ( sizeof(real) * tmp->nr_atoms);
        tmp->massA = malloc ( sizeof(real) * tmp->nr_atoms);
        tmp->massB = malloc ( sizeof(real) * tmp->nr_atoms);
        tmp->typeA = malloc ( sizeof (int) * tmp->nr_atoms);
        tmp->typeB = malloc ( sizeof (int) * tmp->nr_atoms);

        for (xpos=0; xpos<tmp->nr_atoms; xpos++)
        {
          if (fscanf(dat, "%i", &(tmp->atoms[xpos])) == EOF)
            fprintf(stderr,"FATAL ERROR: Crap in the input file for lambda groups\n");
	  else
	  {
	     /* readin successful, check whether this atom is really perturbed */
            tmp->atoms[xpos] = tmp->atoms[xpos]-1; /* counting is shifted by one */
            fprintf(stderr,"atom=%i, perturbed=%i\n", tmp->atoms[xpos], atoms->bPerturbed[tmp->atoms[xpos]]);
	  }	 
          tmp->chargeA[xpos] = atoms->chargeA[tmp->atoms[xpos]]; //initial charge
          tmp->chargeB[xpos] = atoms->chargeB[tmp->atoms[xpos]]; //initial charge
          tmp->massA[xpos] = atoms->massA[tmp->atoms[xpos]]; //initial mass
          tmp->massB[xpos] = atoms->massB[tmp->atoms[xpos]]; //initial mass
          tmp->typeA[xpos] = atoms->typeA[tmp->atoms[xpos]]; //initial typeA
          tmp->typeB[xpos] = atoms->typeB[tmp->atoms[xpos]]; //initial typeB
	  fprintf(stderr, "Charges: %lg to %lg, Masses: %lg to %lg\n",  tmp->chargeA[xpos],  tmp->chargeB[xpos],  tmp->massA[xpos],  tmp->massB[xpos]);
        }

	/* Overwrite the charges (and masses) of HISB according to file HIS2.top */
	/* The topologies (charges) of the four possible HIS are now stored in chargeA (HISH) and chargeB (HISA) of residue HISA */
	/* (read from topol.top) and in chargeA (HISB) and chargeB (HISnegative) of HISB (read from HIS2.top). */

	if ( (strncmp( (tmp->name),"HISB",4)==0) ) /* 4 states model */
        {
	    if((dat_his = fopen("HISB.top","r")) == NULL)
		    fprintf(stderr, "ERROR OPENING HISB.top!!!!\n");
	    fscanf(dat_his, "%s %s %s %s %s %s %s\n",temp,temp,temp,temp,temp,temp,temp);
	    for (xpos=0; xpos<tmp->nr_atoms; xpos++)
	    {
		fscanf(dat_his, "%i %s %g %g %s %g %g\n",&i,temp,&(tmp->chargeA[xpos]),&(tmp->massA[xpos]),temp,&(tmp->chargeB[xpos]),&(tmp->massB[xpos]) );
		fprintf(stderr,"HISB atom %d: %g %g %g %g\n",xpos,tmp->chargeA[xpos],tmp->massA[xpos],tmp->chargeB[xpos],tmp->massB[xpos]);
	    } 
	    fclose(dat_his);
	}

	if (  (strncmp( (tmp->name),"GL2B",4)==0) || (strncmp( (tmp->name),"AS2B",4)==0) || (strncmp( (tmp->name),"HI2B",4)==0)|| (strncmp( (tmp->name),"PR2B",4)==0) || (strncmp( (tmp->name),"VD2B",4)==0)) /* 3 states model; same stuff as 4 states */
        {
	    sprintf(top2file,"%s.top",tmp->name);
	    if((dat_his = fopen(top2file,"r")) == NULL)
		    fprintf(stderr, "ERROR OPENING %s!!!!\n",top2file);
	    fscanf(dat_his, "%s %s %s %s %s %s %s\n",temp,temp,temp,temp,temp,temp,temp);
	    for (xpos=0; xpos<tmp->nr_atoms; xpos++)
	    {
		fscanf(dat_his, "%i %s %g %g %s %g %g\n",&i,temp,&(tmp->chargeA[xpos]),&(tmp->massA[xpos]),temp,&(tmp->chargeB[xpos]),&(tmp->massB[xpos]) );
		fprintf(stderr,"%s atom %d: %g %g %g %g\n",tmp->name,xpos,tmp->chargeA[xpos],tmp->massA[xpos],tmp->chargeB[xpos],tmp->massB[xpos]);
	    } 
	    fclose(dat_his);
	}

	/* we want to overwrite types, bonds and angles for GL2 and AS2 (only A state, B is uncharged, therefore same as B state in topol.top) */
	//if (  (strncmp( (tmp->name),"GL2B",4)==0) || (strncmp( (tmp->name),"AS2B",4)==0) )
        //{
	  /* this is for the types */
	  //for (xpos=0; xpos<tmp->nr_atoms; xpos++) /* for gromos topologies: oxygens at xpos 1 and 3 */
	  /*  {
	      if (xpos==1){
	        tmp->typeA[xpos]=atoms->typeA[tmp->atoms[xpos+2]];
                fprintf (stderr,"%s atom %d: typeA from %d to %d\n",tmp->name,xpos,atoms->typeA[tmp->atoms[xpos]],tmp->typeA[xpos]);
	      }	
	      if (xpos==3) {
	        tmp->typeA[xpos]=atoms->typeA[tmp->atoms[xpos-2]];
                fprintf (stderr,"%s atom %d: typeA from %d to %d\n",tmp->name,xpos,atoms->typeA[tmp->atoms[xpos]],tmp->typeA[xpos]);
	      }	
	    } 
	    }*/

        /* initalize every ldrec on its own (i know this is not perfect ;) */
        ir->init_lambda = initial_lambda;
        init_ldrec(cr, ir, tmp->lambda, tmp->name,tmp->pts,tmp->barrier_l2_0,tmp->barrier_l2_1); //then the ph dependency data could be saved directly there?

	tmp->lambda->transitions->interval=tmp->interval_adapt_barr/(ir->delta_t); /* convert to time steps */
        //tmp->lambda->transitions->max_energy=3*(-2.494*log(1/(tmp->lambda->transitions->interval))); /* 1/interval is the case in which you have 1 lambda in the bin*/
        tmp->lambda->transitions->max_energy=3*(-2.494*log(1/(tmp->lambda->transitions->interval))); /* 1/interval is the case in which you have 1 lambda in the bin*/
        fprintf(stderr,"Adaptive barrier interval=%f\n",tmp->lambda->transitions->interval*(ir->delta_t));
         tmp->lambda->transitions->corr=0;
        fprintf(stderr,"Adaptive barrier correction=%f\n",tmp->lambda->transitions->corr);
        /* set the initial dvdl to zero */
        ml_rec->dvdl = 0;
        
        /* set tmp to point on its next element */
	tmp->next = malloc ( sizeof (struct multi_lambda));
        tmp->his_partner=NULL;
        old = tmp;
        tmp = tmp->next;
      }
    }
    //  }
  old->next = NULL;

  tmp=ml_rec;
      while (tmp != NULL) {
	  tmp_temp=tmp;
	  if (strncmp(tmp->name,"HISA",4)==0) {
	      while (tmp_temp != NULL) {
	         if( ( (strncmp( (tmp_temp->name),"HISB",4)==0) ) && ((tmp_temp->residue_number)==(tmp->residue_number)) ) { 
		   fprintf(stderr, "sono in IF:%s res num=%i and %s res num=%i\n",tmp->name,tmp->residue_number, tmp_temp->name,tmp_temp->residue_number);
         	    tmp->his_partner=tmp_temp;
		    tmp->lambda->his_partner_const_b=tmp->his_partner->lambda->phc->const_b;
		    tmp_temp->his_partner=tmp;
		    tmp_temp->lambda->his_partner_const_b=tmp->lambda->phc->const_b;
		    fprintf(stderr, "his_partner_const_b= %g, partner's his_partner_const_b= %g \n",tmp->lambda->his_partner_const_b,tmp_temp->lambda->his_partner_const_b);
                    tmp_temp = NULL;
	         }
		 else
                    tmp_temp=tmp_temp->next; 
              }
          }
          old = tmp;
          tmp = tmp->next;   
      }
      old->next = NULL;

  tmp=ml_rec;
      while (tmp != NULL) {
	  tmp_temp=tmp;
	  if (strncmp(tmp->name,"GL2A",4)==0) {
	      while (tmp_temp != NULL) {
	         if( ( (strncmp( (tmp_temp->name),"GL2B",4)==0) ) && ((tmp_temp->residue_number)==(tmp->residue_number)) ) { 
		   fprintf(stderr, "sono in IF:%s res num=%i and %s res num=%i\n",tmp->name,tmp->residue_number, tmp_temp->name,tmp_temp->residue_number);
         	    tmp->his_partner=tmp_temp;
		    tmp->lambda->his_partner_const_b=tmp->his_partner->lambda->phc->const_b;
		    tmp_temp->his_partner=tmp;
		    tmp_temp->lambda->his_partner_const_b=tmp->lambda->phc->const_b;
		    micro_pka1 = (double) -(tmp->lambda->phc->const_b) / (tmp->lambda->phc->ph_b); 
		    micro_pka2 = (double) -(tmp_temp->lambda->phc->const_b) / (tmp_temp->lambda->phc->ph_b); 
		    tmp->lambda->micro_diff= - (tmp->lambda->phc->ph_b)*(micro_pka2 - micro_pka1);
		    tmp_temp->lambda->micro_diff = tmp->lambda->micro_diff;
		    tmp->lambda->macro_pka = log10((exp10(micro_pka1)+exp10(micro_pka2)));
		    tmp_temp->lambda->macro_pka = tmp->lambda->macro_pka;
		    fprintf(stderr, "his_partner_const_b= %g, partner's his_partner_const_b= %g \n",tmp->lambda->his_partner_const_b,tmp_temp->lambda->his_partner_const_b);
		    fprintf(stderr, "GL2A/GL2B residue %d pka_macro= %lg %lg\n", tmp->residue_number, tmp->lambda->macro_pka,tmp_temp->lambda->macro_pka );
		    fprintf(stderr, "pka_micro_GL2B - pka_micro_GL2A= %lg - %lg = %lg %lg\n",(-((tmp->lambda->phc->ph_b))*(micro_pka2)),(-((tmp->lambda->phc->ph_b))*(micro_pka1)),tmp->lambda->micro_diff,tmp_temp->lambda->micro_diff);
                    tmp_temp = NULL;
	         }
		 else
                    tmp_temp=tmp_temp->next; 
              }
          }
          old = tmp;
          tmp = tmp->next;   
      }
      old->next = NULL;

  tmp=ml_rec;
      while (tmp != NULL) {
	  tmp_temp=tmp;
	  if (strncmp(tmp->name,"AS2A",4)==0) {  /* 3 states model; same stuff as 4 states */
	    while (tmp_temp != NULL) {
	         if( ( (strncmp( (tmp_temp->name),"AS2B",4)==0) ) && ((tmp_temp->residue_number)==(tmp->residue_number)) ) { 
		   fprintf(stderr, "sono in IF:%s res num=%i and %s res num=%i\n",tmp->name,tmp->residue_number, tmp_temp->name,tmp_temp->residue_number);
         	    tmp->his_partner=tmp_temp;
		    tmp->lambda->his_partner_const_b=tmp->his_partner->lambda->phc->const_b;
		    tmp_temp->his_partner=tmp;
		    tmp_temp->lambda->his_partner_const_b=tmp->lambda->phc->const_b;
		    micro_pka1 = (double) -(tmp->lambda->phc->const_b) / (tmp->lambda->phc->ph_b); 
		    micro_pka2 = (double) -(tmp_temp->lambda->phc->const_b) / (tmp_temp->lambda->phc->ph_b); 
		    tmp->lambda->micro_diff= - (tmp->lambda->phc->ph_b)*(micro_pka2 - micro_pka1);
		    tmp_temp->lambda->micro_diff = tmp->lambda->micro_diff;
		    tmp->lambda->macro_pka = log10((exp10(micro_pka1)+exp10(micro_pka2)));
		    tmp_temp->lambda->macro_pka = tmp->lambda->macro_pka;
		    fprintf(stderr, "his_partner_const_b= %g, partner's his_partner_const_b= %g \n",tmp->lambda->his_partner_const_b,tmp_temp->lambda->his_partner_const_b);
		    fprintf(stderr, "AS2A/AS2B residue %d pka_macro= %lg %lg\n", tmp->residue_number, tmp->lambda->macro_pka,tmp_temp->lambda->macro_pka );
		    fprintf(stderr, "pka_micro_AS2B - pka_micro_AS2A= %lg - %lg = %lg %lg\n",(-((tmp->lambda->phc->ph_b))*(micro_pka2)),(-((tmp->lambda->phc->ph_b))*(micro_pka1)),tmp->lambda->micro_diff,tmp_temp->lambda->micro_diff);
                    tmp_temp = NULL;
	         }
		 else
                    tmp_temp=tmp_temp->next; 
              }
          }
          old = tmp;
          tmp = tmp->next;   
      }
      old->next = NULL;

  tmp=ml_rec;
      while (tmp != NULL) {
	  tmp_temp=tmp;
	  if (strncmp(tmp->name,"HI2A",4)==0) {  /* 3 states model; same stuff as 4 states */
	    while (tmp_temp != NULL) {
	         if( ( (strncmp( (tmp_temp->name),"HI2B",4)==0) ) && ((tmp_temp->residue_number)==(tmp->residue_number)) ) { 
		   fprintf(stderr, "sono in IF:%s res num=%i and %s res num=%i\n",tmp->name,tmp->residue_number, tmp_temp->name,tmp_temp->residue_number);
         	    tmp->his_partner=tmp_temp;
		    tmp->lambda->his_partner_const_b=tmp->his_partner->lambda->phc->const_b;
		    tmp_temp->his_partner=tmp;
		    tmp_temp->lambda->his_partner_const_b=tmp->lambda->phc->const_b;
		    micro_pka1 = (double) -(tmp->lambda->phc->const_b) / (tmp->lambda->phc->ph_b); 
		    micro_pka2 = (double) -(tmp_temp->lambda->phc->const_b) / (tmp_temp->lambda->phc->ph_b); 
		    tmp->lambda->micro_diff= - (tmp->lambda->phc->ph_b)*(micro_pka2 - micro_pka1);
		    tmp_temp->lambda->micro_diff = tmp->lambda->micro_diff;
		    tmp->lambda->macro_pka = -(log10((exp10(-micro_pka1)+exp10(-micro_pka2))));
		    tmp_temp->lambda->macro_pka = tmp->lambda->macro_pka;
		    fprintf(stderr, "his_partner_const_b= %g, partner's his_partner_const_b= %g \n",tmp->lambda->his_partner_const_b,tmp_temp->lambda->his_partner_const_b);
		    fprintf(stderr, "HI2A/HI2B residue %d pka_macro= %lg %lg\n", tmp->residue_number, tmp->lambda->macro_pka,tmp_temp->lambda->macro_pka );
		    fprintf(stderr, "pka_micro_HI2B - pka_micro_HI2A= %lg - %lg = %lg %lg\n",(-((tmp->lambda->phc->ph_b))*(micro_pka2)),(-((tmp->lambda->phc->ph_b))*(micro_pka1)),tmp->lambda->micro_diff,tmp_temp->lambda->micro_diff);
                    tmp_temp = NULL;
	         }
		 else
                    tmp_temp=tmp_temp->next; 
              }
          }
          old = tmp;
          tmp = tmp->next;   
      }
      old->next = NULL;

  tmp=ml_rec;
      while (tmp != NULL) {
	  tmp_temp=tmp;
	  if (strncmp(tmp->name,"PR2A",4)==0) {  /* 3 states model; same stuff as 4 states */
	    while (tmp_temp != NULL) {
	         if( ( (strncmp( (tmp_temp->name),"PR2B",4)==0) ) && ((tmp_temp->residue_number)==(tmp->residue_number)) ) { 
		   fprintf(stderr, "sono in IF:%s res num=%i and %s res num=%i\n",tmp->name,tmp->residue_number, tmp_temp->name,tmp_temp->residue_number);
         	    tmp->his_partner=tmp_temp;
		    tmp->lambda->his_partner_const_b=tmp->his_partner->lambda->phc->const_b;
		    tmp_temp->his_partner=tmp;
		    tmp_temp->lambda->his_partner_const_b=tmp->lambda->phc->const_b;
		    micro_pka1 = (double) -(tmp->lambda->phc->const_b) / (tmp->lambda->phc->ph_b); 
		    micro_pka2 = (double) -(tmp_temp->lambda->phc->const_b) / (tmp_temp->lambda->phc->ph_b); 
		    tmp->lambda->micro_diff= - (tmp->lambda->phc->ph_b)*(micro_pka2 - micro_pka1);
		    tmp_temp->lambda->micro_diff = tmp->lambda->micro_diff;
		    tmp->lambda->macro_pka = log10((exp10(micro_pka1)+exp10(micro_pka2)));
		    tmp_temp->lambda->macro_pka = tmp->lambda->macro_pka;
		    fprintf(stderr, "his_partner_const_b= %g, partner's his_partner_const_b= %g \n",tmp->lambda->his_partner_const_b,tmp_temp->lambda->his_partner_const_b);
		    fprintf(stderr, "PR2A/PR2B residue %d pka_macro= %lg %lg\n", tmp->residue_number, tmp->lambda->macro_pka,tmp_temp->lambda->macro_pka );
		    fprintf(stderr, "pka_micro_PR2B - pka_micro_PR2A= %lg - %lg = %lg %lg\n",(-((tmp->lambda->phc->ph_b))*(micro_pka2)),(-((tmp->lambda->phc->ph_b))*(micro_pka1)),tmp->lambda->micro_diff,tmp_temp->lambda->micro_diff);
                    tmp_temp = NULL;
	         }
		 else
                    tmp_temp=tmp_temp->next; 
              }
          }
          old = tmp;
          tmp = tmp->next;   
      }
      old->next = NULL;

  tmp=ml_rec;
      while (tmp != NULL) {
	  tmp_temp=tmp;
	  if (strncmp(tmp->name,"VD2A",4)==0) {  /* 3 states model; same stuff as 4 states */
	    while (tmp_temp != NULL) {
	         if( ( (strncmp( (tmp_temp->name),"VD2B",4)==0) ) && ((tmp_temp->residue_number)==(tmp->residue_number)) ) { 
		   fprintf(stderr, "sono in IF:%s res num=%i and %s res num=%i\n",tmp->name,tmp->residue_number, tmp_temp->name,tmp_temp->residue_number);
         	    tmp->his_partner=tmp_temp;
		    tmp->lambda->his_partner_const_b=tmp->his_partner->lambda->phc->const_b;
		    tmp_temp->his_partner=tmp;
		    tmp_temp->lambda->his_partner_const_b=tmp->lambda->phc->const_b;
		    micro_pka1 = (double) -(tmp->lambda->phc->const_b) / (tmp->lambda->phc->ph_b); 
		    micro_pka2 = (double) -(tmp_temp->lambda->phc->const_b) / (tmp_temp->lambda->phc->ph_b); 
		    tmp->lambda->micro_diff= - (tmp->lambda->phc->ph_b)*(micro_pka2 - micro_pka1);
		    tmp_temp->lambda->micro_diff = tmp->lambda->micro_diff;
		    tmp->lambda->macro_pka = log10((exp10(micro_pka1)+exp10(micro_pka2)));
		    tmp_temp->lambda->macro_pka = tmp->lambda->macro_pka;
		    fprintf(stderr, "his_partner_const_b= %g, partner's his_partner_const_b= %g \n",tmp->lambda->his_partner_const_b,tmp_temp->lambda->his_partner_const_b);
		    fprintf(stderr, "VD2A/VD2B residue %d pka_macro= %lg %lg\n", tmp->residue_number, tmp->lambda->macro_pka,tmp_temp->lambda->macro_pka );
		    fprintf(stderr, "pka_micro_VD2B - pka_micro_VD2A= %lg - %lg = %lg %lg\n",(-((tmp->lambda->phc->ph_b))*(micro_pka2)),(-((tmp->lambda->phc->ph_b))*(micro_pka1)),tmp->lambda->micro_diff,tmp_temp->lambda->micro_diff);
                    tmp_temp = NULL;
	         }
		 else
                    tmp_temp=tmp_temp->next; 
              }
          }
          old = tmp;
          tmp = tmp->next;   
      }
      old->next = NULL;
      //}//if perturbed atoms

  fclose(dat);
   
}


void init_ldrec(t_commrec *cr, t_inputrec *ir, struct t_ldrec *ld, char* name, int pts, real barrier_l2_0, real barrier_l2_1){
  
    FILE* dat;
    FILE* temp_ph;
    FILE* param_his;
    int res = 0;
    struct ph_adapt* curr;
    int i,j;
    char param2file[255];
    char fullnameres[255];
    int bins=11;
    i=0;j=0;
    real radius = 0.55;

  ld->x0 = ld->x = ir->init_lambda;
  ld->v = 0;
  ld->T_ref = ir->T_lambda; /* new variable */
  ld->T = 0.0; /* instantaneous temp at t=0 */
  ld->m = ir->m_lambda; /* new variable */
  ld->ekin = 0;
  ld->nu_T = (ir->delta_t)*(ir->nu_T_lambda); /* a value of nu_T_lambda = 5 means: Every fifth timestep*/

  /* theta from lambda_init */
  ld->thetha = acos((ir->init_lambda-0.5)/radius);
  //  ld->thetha = acos(2*(ir->init_lambda)-1);
  ld->v_thetha = 0; /* no initial kinetic energy */

  /* init ph_depend */
  ld->ph_value = 5.5;
  ld->phc = (struct ph_adapt*)  malloc (sizeof (struct ph_adapt));

  ld->pts=pts;/*initialize number of points for spline barrier potential */
  ld->x_spline = (double*) (calloc(ld->pts,sizeof(double)));
  if (!ld->x_spline) {
    fprintf(stderr,"No memory allocated: x_spline\n");
    exit(1);
  }
  ld->dqspline_l2_0 =  (double**) (calloc(ld->pts,sizeof(double*)));
  ld->dqspline_l2_1 =  (double**) (calloc(ld->pts,sizeof(double*)));
  for (i=0;i< ((ld->pts)-1);i++) {
    ld->dqspline_l2_0[i] = (double*) (calloc(3,sizeof(double)));
    ld->dqspline_l2_1[i] = (double*) (calloc(3,sizeof(double)));
  }
  if (!ld->dqspline_l2_0 || !ld->dqspline_l2_1) {
    fprintf(stderr,"No memory allocated: dqspline\n");
    exit(1);
  }

  /* inizialize the spline in the ldrec*/
  fprintf(stderr,"Residue %s:\n",name);
  if (pts != 0) {
    fprintf(stderr,"Barrier at lambda partner=0\n");
    init_spline(ld->pts,ld->x_spline,ld->dqspline_l2_0,(double)barrier_l2_0);
    fprintf(stderr,"Barrier at lambda partner=1\n");
    init_spline(ld->pts,ld->x_spline,ld->dqspline_l2_1,(double)barrier_l2_1);
  }
  else
    fprintf(stderr,"Parabolic biasing potential\n");

  ld->transitions = (struct lambda_ts*) malloc (sizeof (struct lambda_ts) * ts_array);
  /*ld->transitions->interval=10/(ir->delta_t); initialized in init_mlrec*/
  ld->transitions->counter=1;
  ld->transitions->scale=0;
  ld->transitions->l=(int*)(calloc(bins,sizeof(int)));
  ld->transitions->h=(float*)(calloc(bins,sizeof(float)));
  ld->transitions->f_old=(float*)(calloc(bins,sizeof(float)));
  ld->adapt_corr=0;

  /* get this data from the file pka_data.dat */
  if((dat = fopen("pka_data.dat","r")) == NULL)
      fprintf(stderr, "ERROR OPENING pka_data.dat!!!!\n");
  curr = ld->phc;
  while ((res=read_ph_data(dat, curr)) == 0)
      curr = curr->next;
  
  switch (res) {
    case -1:
        break;
    case 1:
	break;
    case 0:
	free(curr->next);
	curr->next = NULL;
  }

  fclose(dat);

  curr=ld->phc;
  while (curr != NULL) {
      if (strncmp(curr->residue,name,4)==0) {
	  ld->phc=curr;
       	  fprintf(stderr, "Read in: %s, %g, %g, %g, %g, %g, %g\n",ld->phc->residue,ld->phc->const_a,ld->phc->ph_a,ld->phc->const_2,ld->phc->const_3,ld->phc->const_b,ld->phc->ph_b);
	  if ( (strncmp(curr->residue,"HISA",4)==0) || (strncmp(curr->residue,"HISB",4)==0) || (strncmp(curr->residue,"GL2A",4)==0) || (strncmp(curr->residue,"GL2B",4)==0) || (strncmp(curr->residue,"AS2A",4)==0) || (strncmp(curr->residue,"AS2B",4)==0) || (strncmp(curr->residue,"HI2A",4)==0) || (strncmp(curr->residue,"HI2B",4)==0) || (strncmp(curr->residue,"PR2A",4)==0) || (strncmp(curr->residue,"PR2B",4)==0) || (strncmp(curr->residue,"VD2A",4)==0) || (strncmp(curr->residue,"VD2B",4)==0)  ) { /* 4 and 3 states model */
	      strncpy(fullnameres,curr->residue,4);
	      fullnameres[4] = '\0';
	      sprintf(param2file,"param_%s.dat",fullnameres);
	      fprintf(stderr, "param2file=%s,fullnameres=%s\n",param2file,fullnameres);
	      if((param_his = fopen(param2file,"r")) == NULL)
		fprintf(stderr, "ERROR OPENING %s!!!!\n",param2file);
	      fprintf(stderr, "Read in: %s,",ld->phc->residue);
	      for (i=0;i<4;i++) {
		  for (j=1;j<5;j++) {
		      fscanf(param_his,"%g ",&ld->phc->param_his[i][j]);
		      fprintf(stderr, "%g, ",ld->phc->param_his[i][j]);
		  }
	      }
	      fprintf(stderr, "\n");
	      if(param_his!=NULL)
		 fclose(param_his);
	  }
          curr=NULL;
      }	      
      else
	  curr=curr->next;
  }

  if ((temp_ph = fopen("ph.dat", "r")) == NULL)
      fprintf(stderr, "Error opening ph.dat file.\n");

  fscanf(temp_ph, "%g;\n", &(ld->ph_value));
  fprintf(stderr, "Read in %g as pH-value\n", ld->ph_value);

  fclose(temp_ph);
  fprintf(stderr, "v1.12: Initializing the ldrec T_ref = %lg m = %lg nu_T = %lg ir->nu_T_lambda %d\n", ld->T_ref, ld->m, ld->nu_T, ir->nu_T_lambda);
}



real fpot(real x, struct t_ldrec *ld){
  /* place a gaussian barrier of 2 kt on the lamda variable */
  real
    a,v,r,rsq,f,b=25;
  r   = (0.5-x);
  rsq = r*r;
  a = 2*ld->T_ref*BOLTZ;
  v   = a*exp(-rsq*b);
  f = -(2*a*b*exp(-b*rsq)*r);
  fprintf(stderr,"pot = %lg, f = %lg\n",v,f);
  return (f);
} /* fpot */



/* currently only for a one dimensional particle */
/* int flag selects the coupling method 
   0 = Andersen thermostat#
   1 = Berendsen
*/
/* return values:
   0 = failure
   1 = success
*/
int tcouple(struct t_ldrec *ld, real* v, t_commrec *cr, int flag, t_inputrec *ir) {
  real rnr=0.0,sigma=0.0, cv=6.90329e-24, lambda=0.0; //cv is currently making tau_t = ld->nu_T
  real kb=1.380658e-23;
  static real tau_t=0.0;
  static gmx_rng_t 
    rng;
  static int start_seed=0;
  
  if(!start_seed){
    /* use the seed initializer to calculate tau for
       berendsen thermostat */
    // divided by one due to 1 particle = 1 deg of freedom
    tau_t = ld->nu_T*1*kb/(2*cv);
    if(MASTER(cr)){
      start_seed = gmx_rng_make_seed();
    }
#ifdef GMX_MPI
    if(PAR(cr)){
      MPI_Bcast(&start_seed,1,MPI_INT,0,MPI_COMM_WORLD);
    }
#endif
		   //rng = gmx_rng_init(42/*start_seed*/); 
		   /* the seed for andersen thermostat is now set in the mdp file. Sdo 17.09.2009*/
		   /* if it is 0 a random number is generated every time */
     if (!ir->andersen_seed)
	rng = gmx_rng_init(start_seed);
     else
        rng = gmx_rng_init((ir->andersen_seed));
  }


		     //fprintf(stderr, "nu_T: %lg, T_ref: %lg, mass: %lg, v: %lg\n", ld->nu_T, ld->T_ref, ld->m, *v);
  /* select da method */
  switch (flag) {
      case 0:
	  /* andersen thermocoupling */
          /* stochastic temperature coupling */
	  //rnr = rnd_gauss_box_mueller();//gmx_rng_uniform_real(rng); 
	  rnr = (real)gmx_rng_uniform_real(rng); /* really uniformely distriubuted
					      number */
	      //fprintf(stderr,"random number generated: %lg and compared to %lg\n",rnr, ld->nu_T);
	  if(fabs(rnr)<ld->nu_T){ 
//fprintf(stderr,"random number really used: %lg\n",rnr);
	      sigma = sqrt(ld->T_ref*BOLTZ/ld->m);
	      *v = gaussdist(rng,sigma);
	  }
	  /**/
	  return 1;
	  break;
      case 1:
	  /* berendsen thermostat */
	  // ld-T contains the temperature of the last step
	  // scale the velocity down by the berendsen lambda factor
	  //fprintf(stderr,"ir->delta_t=%lg tau_t=%lg ld-T_ref=%lg ld->T=%lg BOLTZ=%lg\n", ir->delta_t, tau_t,ld->T_ref,ld->T, BOLTZ);
	  lambda=sqrt(1.0+ir->delta_t/tau_t*(ld->T_ref/ld->T-1.0));
	  //fprintf(stderr,"berendsen-lambda: %lg\n",lambda);
	  if (lambda>1.2) lambda=1.2;
	  if (lambda<0.8) lambda=0.8;
	  *v = *v*lambda;
	  return 1;
	  break;
      default:
	  return 0;
  }
}
real fric(real v){
  return(0);
} /* fric */

real adaptive_barrier (struct lambda_ts* t, real lambda, float barrier) {

  FILE* fw2;
  FILE* fw2_;
  real corr_adapt=0.0;
  float b_interval=0.1;
  int g_begin_bin=1;
  int g_end_bin=9;
  float sigma=0.07;
  float sigma_be=0.01;
  int b,i,j,iter;
  int begin,end;
  int bins=11;
  double* f;
  double* f_4print;
  float *f_ref;
  double **g; /* here you store the value of each gaussian at different lambda values */
  double **dg;
  double *sum_g_arr;
  double *sum_dg_arr;
  double sum_dg_arr_begin=0;
  double sum_dg_arr_end=0;
  float area_f,area,min_f,x,sum_g,sum_dg,max_f_ref,corr_g;
  float running_bin;
  float RT;
  float l1;
  RT=0.00831451*300.0;
  corr_g=0;

  fw2=fopen("gaussians1.dat","a");
  fw2_=fopen("gaussians2.dat","a");

  f = (double*)(calloc(bins,(sizeof(double))));
  f_4print = (double*)(calloc(bins,(sizeof(double))));
  f_ref = (float*)(calloc(bins,(sizeof(float))));
  g = (double**)(malloc(bins*(sizeof(double*))));
  dg = (double**)(malloc(bins*(sizeof(double*))));
  for (i=0;i<bins;i++) {
      g[i]=(double*)(calloc((bins),(sizeof(double))));
      dg[i]=(double*)(calloc((bins),(sizeof(double))));
  }
  sum_g_arr = (double*)(calloc(bins,(sizeof(double))));
  sum_dg_arr = (double*)(calloc(bins,(sizeof(double)))); 


  /* calculate frequency at end poins (<0.05 and >0.95): if >65% then do nothing */
  
  if (t->counter==0 ) {

  if ( (t->l[0]+t->l[10])/(t->interval*1.0)<0.65 ) {

  fprintf(fw2,"adaptive_barrier_correction YES lambda=%lg: frequency at end states smaller than 0.65 (%.3f)\n",lambda,(t->l[0]+t->l[10])/(t->interval*1.0));

/* the reference should be done only once at the beginning for all groups: the reference bins */
  f_ref[0]=0;
  f_ref[bins-1]=0;
  for (b=1;b<(bins-1);b++) {
      x=b*b_interval;
      f_ref[b]= (RT*0.5*log( x*(1-x) )+5.5) + (-4*barrier*(x-0.5)*(x-0.5)+barrier);
  }
  max_f_ref=f_ref[5];

  area_f=0;

  for (b=0;b<bins;b++) {
    if (t->l[b]==0) { /* no transitions. the energy would go to +infinite; decide about a max treshold */
	//f[b]=t->max_energy;
	f[b]=2*max_f_ref; /* in this way the correction flattens the barrier of biasing and entropic to zero */
	//f[b]=2*f_ref[b]; /* if you apply this than you will always have zero at the end states */ 
        //fprintf(fw2,"f(real:occupancy=zero)[%d]= %lg\n",b,f[b]);
    }
    else {
	f[b]=-RT*log((double)t->l[b]/(t->interval*1.0));  /*this is the actual energy distribution*/ 
        //fprintf(fw2,"f(real)[%d]= %lg\n",b,f[b]);
    }
    //if (f[b]>2*f_ref[b]) {
    //f[b]=2*f_ref[b];
	if (f[b]>2*max_f_ref) {
	    f[b]=2*max_f_ref;
	//fprintf(fw2,"f(real:>2maxref)[%d]= %lg\n",b,f[b]);
    }
    f_4print[b]=f[b];
  }
  

  min_f=f[0];               /* set the zero of the actual energy distribution at the end states */
  if (f[(bins-1)]<min_f)
    min_f=f[(bins-1)];
  //fprintf(fw2,"min_f=%f\n",min_f);
   
  for (b=0;b<bins;b++) {
      if ( t->l[b]!=0 ) {
	  f[b]=f_ref[b]-(f[b]-min_f);  /* f[b] is now the energy to be added to the energy landscape to get the barrier+circle */
	  if (f[b]<0)
	      f[b]=0; /* correct only if the real landscape is lower then the reference: i.e. the barrier can only be increased with respect to the reference one!! */
      }
      else
	  f[b]=t->f_old[b]; /* if the lambda bin is empty use the delta of the previous interval; works also at the first correction because if the bin is empty the energy will be larger than the ref and the delta=0 */
      //b]=(f[b]-min_f); /* to test parabola landscape */
    area_f+=f[b]*b_interval;  /* area of the correction distribution */
  }

  /* fit a gaussian to each bin of the correction distribution */
      for (b=0;b<bins;b++) {
        t->h[b]=f[b]; 
	t->f_old[b]=f[b];
	for (i=0;i<bins;i++) { /* use lambda at intervals of 0.1 to build gaussians */
	  g[b][i]=(double)t->h[b]*exp(-((i-b)*b_interval)*((i-b)*b_interval)/(2*sigma*sigma));
	}      
      }
/* iteratively adjust the height of gaussians */
      sum_g=0;
      area=0;
      iter=0;
      while ( (area/area_f > 1.05 || area/area_f < 0.95) && iter < 100 ) { /*treshold for accuracy gaussians distribution */
           for (b=0;b<bins;b++) {
	     sum_g=0;
	     for (i=0;i<bins;i++) {
	       sum_g+=g[i][b];
	     }
	     t->h[b]=t->h[b]+(f[b]-sum_g);
	   }
	   for (b=0;b<bins;b++) {
	     for (i=0;i<bins;i++) {
	       g[b][i]=(double)t->h[b]*exp(-((i-b)*b_interval)*((i-b)*b_interval)/(2*sigma*sigma));
	       dg[b][i]=(double)-g[b][i]*((i-b)*b_interval)/(sigma*sigma);
	     }
	   }
      /* check total area (approximate to histogram) gaussians */
	   for (i=0;i<bins;i++) {
	     sum_g=0;
	     sum_dg=0;
	     for (b=0;b<bins;b++) { 
	       sum_g+=g[b][i];
               sum_dg+=dg[b][i];
	     }
	     sum_g_arr[i]=sum_g;
             sum_dg_arr[i]=sum_dg; 
	   }
	   area=0;
	   for (i=0;i<bins;i++) {
	     area+=sum_g_arr[i]*b_interval;
	   }
	   //fprintf(fw2,"@ Area=%f/%f=%f,iter=%d\n",area,area_f,area/area_f,iter);
	   iter++;
      }/* end while*/

	  fprintf(fw2,"@ Area=%f/%f=%f,iter=%d\n",area,area_f,area/area_f,iter); 
	  fprintf(fw2,"@ bin l_occupancy ref real delta sum_g_arr sum_dg_arr min_f eff_barrier:\n");
	  for (b=0;b<bins;b++) {
	      //fprintf(fw2,"BIN %d %f %f %f %f %lg %lg %f %f\n",b,t->l[b]/(t->interval*1.0),f_ref[b],(f_ref[b]-f[b]+min_f),f[b],sum_g_arr[b],sum_dg_arr[b],min_f,(f_ref[b]+f[b]));
	      fprintf(fw2,"BIN %d %.3f %.3f %.3f %.3f %.3lg %.3lg %.3f %.3f\n",b,t->l[b]/(t->interval*1.0),f_ref[b],f_4print[b],f[b],sum_g_arr[b],sum_dg_arr[b],min_f,(f_ref[b]+f[b]));
	      //with tab: fprintf(fw2,"BIN %d %.3f\t%.3f\t%.3f\t%.3f\t\t%.3lg\t\t%.3lg\t%.3f\t%.3f\n",b,t->l[b]/(t->interval*1.0),f_ref[b],f_4print[b],f[b],sum_g_arr[b],sum_dg_arr[b],min_f,(f_ref[b]+f[b]));
	  }
	  fprintf(fw2,"\n");

      /*if (barrier==3.0) {
	  fprintf(fw2,"@ Area=%f/%f=%f,iter=%d\n",area,area_f,area/area_f,iter); 
	  fprintf(fw2,"@ bin l_occupancy ref real delta sum_g_arr sum_dg_arr min_f:\n");
	  for (b=0;b<bins;b++) {
	      fprintf(fw2,"%d %f %f %f %f %lg %lg %f\n",b,t->l[b]/(t->interval*1.0),f_ref[b],(f_ref[b]-f[b]+min_f),f[b],sum_g_arr[b],sum_dg_arr[b],min_f);
	  }
	  fprintf(fw2,"\n");
      }
      else {
	  fprintf(fw2_,"@ Area=%f/%f=%f,iter=%d\n",area,area_f,area/area_f,iter); 
	  fprintf(fw2_,"@ bin l_occupancy ref real delta sum_g_arr sum_dg_arr min_f:\n");
	  for (b=0;b<bins;b++) {
	      fprintf(fw2_,"%d %f %f %f %f %lg %lg %f\n",b,t->l[b]/(t->interval*1.0),f_ref[b],(f_ref[b]-f[b]+min_f),f[b],sum_g_arr[b],sum_dg_arr[b],min_f);
	  }
	  fprintf(fw2_,"\n");
      }*/
      for (b=0;b<bins;b++) /* reset the bin occupancy to zero */
	t->l[b]=0;

  } /*end if frequency endpoints */
  else {
      fprintf(fw2,"adaptive_barrier_correction NO lambda=%lg: frequency at end states greater than 0.65 (%.3f)\n",lambda,(t->l[0]+t->l[10])/(t->interval*1.0));
      for (b=0;b<bins;b++) /* reset the bin occupancy to zero */
	t->l[b]=0;
  }
  } /*end if counter=zero */

 /* correct the derivative according to the adaptive barrier */
 /* for the beginning (0-0.1) and end (0.9-1.0) bins use half gaussian sigma=0.01 */

  if (lambda<0.1) { 
      for (b=0;b<bins;b++) {
	  sum_dg_arr_begin+=(double)-t->h[b]*exp(-(g_begin_bin*b_interval-b*b_interval)*(g_begin_bin*b_interval-b*b_interval)/(2*sigma*sigma))*(g_begin_bin*b_interval-b*b_interval)/(sigma*sigma);
      }
      corr_adapt=(double)sum_dg_arr_begin*exp(-(lambda-g_begin_bin*b_interval)*(lambda-g_begin_bin*b_interval)/(2*sigma_be*sigma_be));
      //fprintf(fw1,"AA %f %lg %lg %d %lg\n",lambda,corr_adapt,sum_dg_arr[g_begin_bin],g_begin_bin,sum_dg_arr[1]);
    }
    else if (lambda>0.9) {
      for (b=0;b<bins;b++) {
	  sum_dg_arr_end+=(double)-t->h[b]*exp(-(g_end_bin*b_interval-b*b_interval)*(g_end_bin*b_interval-b*b_interval)/(2*sigma*sigma))*(g_end_bin*b_interval-b*b_interval)/(sigma*sigma);
      }
      corr_adapt=(double)sum_dg_arr_end*exp(-(lambda-g_end_bin*b_interval)*(lambda-g_end_bin*b_interval)/(2*sigma_be*sigma_be));
      //fprintf(fw1,"ZZ %f %lg %lg %d\n",lambda,corr_adapt,sum_dg_arr[g_end_bin],g_end_bin);      
    }
    else
      for (b=0;b<bins;b++) {
        corr_adapt+=(double)-t->h[b]*exp(-(lambda-b*b_interval)*(lambda-b*b_interval)/(2*sigma*sigma))*(lambda-b*b_interval)/(sigma*sigma);
	corr_g+=(double)t->h[b]*exp(-(lambda-b*b_interval)*(lambda-b*b_interval)/(2*sigma*sigma));
      }
    t->corr=corr_adapt;

  fclose(fw2);
  fclose(fw2_);
  free (sum_g_arr);
  free(sum_dg_arr);
  free(f_ref); free(f); free(f_4print);
  for (i=0;i<bins;i++) {
    free(g[i]);
    free(dg[i]);
  }
  free(g);
  
  //fprintf(stderr,"lambda=%f,corr_adapt=%lg ",lambda,corr_adapt);

  return (real) corr_adapt;
}

/* lambda_4 implies the seperate andersen heat bath,
   theta dynamics and additional dgdl modification
   to mimic correct dgdl behaviour and allow
   constant pH simulations
*/

real update_lambda_4(t_commrec *cr, double dvdl, 
		     t_inputrec *ir, struct t_ldrec *ld,real l_his_partner, real barrier_tmp1, real barrier_tmp2){
     
  
  int iPos=0;
  real comp;
  static long steps=0; /* very stupid counter */
  struct ph_adapt* tmp_adapt;
  real diff=0.0, ts_now=0.0;
  real dvdl2, radius=0.55, ft=0.0, vn=0.0; /* ft = force on thetha */
  real lambda=0.0;
  real barrier;real barrier_tmp;
  double lambda_double=0.0;
  struct lambda_ts* transitions;
  //real beta = 0.0; // from brooks paper constant-ph 1.25 molecular dynamics, Lee et. al
  real corr=0.0;real corr_spline_l2_0=0;real corr_spline_l2_1=0; 
  //MPI_Barrier(MPI_COMM_WORLD);
  int i,j,tmpint,bins;
  i=0;j=0;bins=11;

  //  barrier = ld->phc->barrier*(-8); /* barrier for barrier potential in kJ/mol */
  barrier = ((1-l_his_partner)*barrier_tmp1+l_his_partner*barrier_tmp2)*(-8); 
  barrier_tmp=((1-l_his_partner)*barrier_tmp1+l_his_partner*barrier_tmp2);//for corr_adaptive_barrier
  /* we set lambba to 0 on all nodes, then compute the actual
     dvdl, and send this to the master (i.e. we sum up all local
     dvdl's ). The master does the integration and obtains the new
     lambda. Via a gmx_sumd, the lambda values gets communicated to
     all nodes. SInce these had lambda=0, they trhus obtain the same
     value as the one on the master.
   */

//  fprintf(stderr, "dvdl before broadcast: %lg\n", dvdl);
//  if(PAR(cr)){
//    ;//gmx_sumd(1,&dvdl,cr); /* broadcasting the dvdl */- 26-5-2011 done in md.c
//  } 
//  fprintf(stderr, "dvdl after broadcast: %lg\n", dvdl);
//  if(MASTER(cr)) {
//      fprintf(stderr, "%g, %g, ", dvdl, ld->x); 

      transitions = ld->transitions;

      /* set the transitions value to zero */
      /* the beginning entry is the starting entry from the ld_rec */
      if (steps==0) {
	  /* first step */
	  //fprintf(stderr, "Setting ts entries to zero %i\n", ts_array);
	  transitions[0].lambda = ld->x0;
	  transitions[0].ts = 0.0;
	  for (iPos=1; iPos<=ts_array-1; iPos++)
	  {
	      //fprintf(stderr, "Setting ts on %i\n", iPos);
	      transitions[iPos].ts = 0.0;
	      transitions[iPos].lambda = 0.0;
	  }
      }


    /* correct for the amino_acid's ph correction function */
    //find the corresponding ph function
      tmp_adapt = ld->phc;
      //fprintf(stderr, "%s\n",tmp_adapt->residue); 
      //fprintf(stderr, "Adaption %lf, %lf, %lf, %lf, %lf\n\n", ld->ph_value, tmp_adapt->const_a, tmp_adapt->ph_a, tmp_adapt->const_b, tmp_adapt->ph_b);



      /* first one 
      corr = tmp_adapt->const_a + (tmp_adapt->ph_a * ld->ph_value) + (tmp_adapt->const_b + (tmp_adapt->ph_b * ld->ph_value)) * ld->x;
      */

      /* 20080428 - new params with lambda independent pH correction */

      if (l_his_partner!=-1) {
	  //corr = -(-38.646440685 + 26.819102719 * l_his_partner + (-0.104390885+0.106434888* l_his_partner)* ld->x);//flaten the landscape of his in vacuum
	  //flaten the landscape of his in water (cubic regression) 
	  for (i=0;i<4;i++) {
	      tmp_adapt->param_his[i][0]=tmp_adapt->param_his[i][1]+tmp_adapt->param_his[i][2]*l_his_partner+tmp_adapt->param_his[i][3]*l_his_partner*l_his_partner+tmp_adapt->param_his[i][4]*l_his_partner*l_his_partner*l_his_partner;
	  }
	  i=0;
	  corr = -(tmp_adapt->param_his[i][0]+tmp_adapt->param_his[i+1][0]*ld->x+tmp_adapt->param_his[i+2][0]*ld->x*ld->x+tmp_adapt->param_his[i+3][0]*ld->x*ld->x*ld->x);
          //fprintf(stderr, "corr_flat= %g, ", (corr));
	  if (l_his_partner<0)
	    l_his_partner=0;
	  if (l_his_partner>1)
	    l_his_partner=1;
	  if ( (strncmp( (tmp_adapt->residue),"HIS",3)==0) ) /* four states */
	    corr +=  (1-l_his_partner)*(tmp_adapt->const_b + tmp_adapt->ph_b * ld->ph_value) + l_his_partner*(- tmp_adapt->ph_b*tmp_adapt->second_pka +tmp_adapt->ph_b * ld->ph_value); /* lambda his partner dependent pH correction */
	  if ( (strncmp( (tmp_adapt->residue),"GL2B",4)==0) || (strncmp((tmp_adapt->residue),"AS2B",4)==0) ||  (strncmp((tmp_adapt->residue),"HI2B",4)==0) || (strncmp((tmp_adapt->residue),"PR2B",4)==0) || (strncmp((tmp_adapt->residue),"VD2B",4)==0) ) /* 3 states model */
	    corr+= ( tmp_adapt->const_b - ld->his_partner_const_b ); /* lambda is here the switching coordinate, no pH correction */
	  if ( (strncmp( (tmp_adapt->residue),"GL2A",4)==0) || (strncmp((tmp_adapt->residue),"AS2A",4)==0) || (strncmp((tmp_adapt->residue),"HI2A",4)==0) || (strncmp((tmp_adapt->residue),"PR2A",4)==0) || (strncmp((tmp_adapt->residue),"VD2A",4)==0) ) /* 3 states model */ 
	    corr +=  (- tmp_adapt->ph_b *ld->macro_pka + tmp_adapt->ph_b * ld->ph_value); /* lambda his partner dependent pH correction */  
          //fprintf(stderr, "corr_flat+pka= %g, ", (corr));
	  //corr += -0.5 * barrier + barrier * ld->x; /* barrier potential */
          //fprintf(stderr, "corr_flat+pka+barr= %g, ", (corr));

      }
      else { 
	  
	corr = -(tmp_adapt->const_a + tmp_adapt->ph_a * ld->x + tmp_adapt->const_2 * (powf(ld->x,2)) + tmp_adapt->const_3 * (powf(ld->x,3)));//flaten the landscape
	  corr += tmp_adapt->const_b + tmp_adapt->ph_b * ld->ph_value; //pH correction          
        //corr += -0.5 * barrier + tmp_adapt->const_b + tmp_adapt->ph_b * ld->ph_value + barrier * ld->x;//pH and barrier correction
      }    
      /* barrier potential correction*/

      /*for (i=0;i<((ld->pts)-1);i++) {
	fprintf(stderr,"i=%d, dq0= %g, dq1= %g, dq2= %g\n",i,ld->dqspline_l2_0[i][0],ld->dqspline_l2_0[i][1], ld->dqspline_l2_0[i][2]);
	}
	for (i=0;i<((ld->pts));i++)
	  fprintf(stderr,"x[%d]=%f\n",i,ld->x_spline[i]); */

          if (ld->pts == 0)
	    corr += -0.5 * barrier + barrier * ld->x; //parabola barrier correction
	  else { // spline barrier correction - June 2011
	    corr_spline_l2_0 = 0;
	    corr_spline_l2_1 = 0;
	    for (i=0;i<((ld->pts)-1);i++) {
	      if ( ld->x > ld->x_spline[i] && ld->x <= ld->x_spline[i+1] ) {
		corr_spline_l2_0 = ld->dqspline_l2_0[i][0]*ld->x*ld->x + ld->dqspline_l2_0[i][1]*ld->x + ld->dqspline_l2_0[i][2];
		corr_spline_l2_1 = ld->dqspline_l2_1[i][0]*ld->x*ld->x + ld->dqspline_l2_1[i][1]*ld->x + ld->dqspline_l2_1[i][2];
	      }
	    }
	    if (l_his_partner!=-1) {
	      corr += (1-l_his_partner)*corr_spline_l2_0 + l_his_partner*corr_spline_l2_1;
              //fprintf(stderr, "corr_spline_l2_0= %g, corr_spline_l2_1= %g corr= %g, ",corr_spline_l2_0,corr_spline_l2_1,((1-l_his_partner)*corr_spline_l2_0 + l_his_partner*corr_spline_l2_1));
            }
	    else {
	      corr += corr_spline_l2_0; /*corr_spline_l2_0 equals corr_spline_l2_1*/ 
              //fprintf(stderr, "corr_spline_l2_0= %g, corr_spline_l2_1= %g corr= %g, ",corr_spline_l2_0,corr_spline_l2_1,corr_spline_l2_0);
	    }
	  }
	    	
      //fprintf(stderr, "%g, ", (corr));

    /* adaptive barrier correction - October 2009 */

    if (ld->transitions->interval>0) {
      if ( ld->transitions->counter < (ld->transitions->interval) ) { /* collect lambda during an interval */
	tmpint=(int) lround((double)((ld->x)*10)); 
	//fprintf(stderr,"ld->x=%lg,tmpint= %d ",ld->x,tmpint);
	if (ld->x > 1.0)
	  ld->transitions->l[(bins-1)]++;
	else if (ld->x < 0.0)
	  ld->transitions->l[0]++;  
	else
	  ld->transitions->l[tmpint]++;
	//fprintf(stderr,"counter=%d ",ld->transitions->counter);
	if ( (ld->transitions->scale)<1) {
	    if (ld->x >= 0.93 || ld->x <= 0.07)
		ld->transitions->scale=1;
	    else
		ld->transitions->scale+=1/(ld->transitions->interval*0.1); /* scale the adapt.barrier correction so that it is reached in 1/10 of the interval ps */
	}
	if ( (ld->transitions->scale)>1)
	    ld->transitions->scale=1; 
	//fprintf(stderr,"scale= %f\t",ld->transitions->scale);
      }       
      else { 
	tmpint=(int) lround((double)((ld->x)*10)); 
	//fprintf(stderr,"ld->x=%lg,tmpint= %d ",ld->x,tmpint);
	if (ld->x > 1.0)
	  ld->transitions->l[(bins-1)]++;
	else if (ld->x < 0.0)
	  ld->transitions->l[0]++;  
	else
	  ld->transitions->l[tmpint]++;
	ld->transitions->counter=0;
	if (ld->x < 0.9 && ld->x > 0.1 )
	    ld->transitions->scale=1/(ld->transitions->interval*0.1);
	else
	    ld->transitions->scale=1; 
	//fprintf(stderr,"scale= %f\t",ld->transitions->scale);
      }
      corr+=adaptive_barrier(ld->transitions,ld->x,barrier_tmp)*ld->transitions->scale;
      ld->adapt_corr=ld->transitions->corr;
      ld->transitions->counter++;
      //fprintf(stderr,"End adaptive corr= %lg\t",corr);
      //fprintf(stderr,"ld->transitions->counter=%d\tld->transitions->interval= %lg\t",ld->transitions->counter,ld->transitions->interval);
    }

    /* final dvdl calculation */
    dvdl2 = dvdl + corr;

    ft = dvdl2 * radius*(sin(ld->thetha));

    vn  = ld->v_thetha;
    vn += ft/ld->m*(ir->delta_t); /* vn eq. speed of theta particle */


    //fprintf(stderr, "dvdl2= %g, ", dvdl2);

    //fprintf(stderr, "%g, %g,  ", dvdl2, ft);
    
    /* we want to couple the speed of the lambda-particle to the heat bath */
    /* lambda = r*cos(theta(t)+0.5 */
    /* v_lambda = -r*sin(theta)*vn */
       /*ld->v = -radius*sin(ld->thetha)*vn; */

       /* thermocoupling */
       tcouple(ld, &vn, cr, 0, ir); //andersen
       //tcouple(ld,&vn,cr,1,ir); //berendsen
       
       /* calculate back from the lambda velocity to theta velocity */
       //vn=-(ld->v)/(radius*sin(ld->thetha));

    ld->thetha += vn*(ir->delta_t);
    /* ekin of theta */
    /* ld->ekin = 0.5*ld->m*vn*vn*radius*radius; */
    /* ekin of lambda */
    ld->v = -radius*sin(ld->thetha)*vn; //translation from the v_theta to v_lambda
    ld->ekin = 0.5*ld->m*ld->v*ld->v;
    ld->x = radius*cos(ld->thetha)+0.5;

    ld->T = 2.0*(ld->ekin)/BOLTZ; /* instantaneaous temperature */      
    ld->v_thetha = vn;

    //fprintf(stderr, "%g, %g, ", ld->thetha, ld->v_thetha);

    lambda=(real)ld->x;
    lambda_double=(double)lambda;

    steps++;
    ts_now = (real)steps*(ir->delta_t)/(real)group_count; 
                                              /* steps is static, that means the 
                                                 function is called group_count 
                                                 times in one step */

    /* check for the necessity to adapt the additonal barrier potential */
    //fprintf(stderr, "Test: %lg, %g, %lg, %lg",ts_now, fabs(lambda-transitions[0].lambda), transitions[ts_array-1].ts, barrier);
    /*
    if (transitions[0].lambda <= 0.1)
	comp = 0.0;
    else
	comp = 1.0;
    if ((diff=fabs(lambda-comp)) < 0.1) {
        // this is defined as to be no transition
	// check for the treshold
	if (ts_now-transitions[ts_array-1].ts > adaption_treshold * ts_array) {
	    // adaption of the potential
	    if (barrier >= -5.0)
		barrier = 0.0; //more can't be done
	    else
		barrier = barrier/1.2; //decrease the barrier
	    //resetting the "transition counter" by faking a tranistion in the last box
	    transitions[ts_array-1].ts = ts_now;
	    fprintf(stderr, "No transition occured till ts %g, Barrier is now %g", ts_now, barrier);
	}
    }
    // the intermediate states are not used in any way for the adaptation
    if (diff > 0.9) {
	// transistion occured -> shifting the array, no for loop
	for (iPos=ts_array-1; iPos>0; iPos--) {
	    transitions[iPos].ts = transitions[iPos-1].ts;
	    transitions[iPos].lambda = transitions[iPos-1].lambda;
	}
	transitions[0].ts = ts_now;
	transitions[0].lambda = lambda;
	fprintf(stderr, "Transition from %lg to %lg occured at ts %lg ps",transitions[1].lambda, transitions[0].lambda, ts_now);

	// check for increasing the barrier potential again
        // currently the barrier is reduced when there when the ts_array's transition time is faster than half of the treshold
        // that means: during half of the adaption_treshold time ts_array transitions have occured
	if (ts_now-transitions[ts_array-1].ts < adaption_treshold * ts_array) {
	    if (barrier == 0.0)
		barrier = -5.0;
	    else
		barrier*=1.05; // increase barrier
	    fprintf(stderr, "Additional barrier potential increased to factor: %lg", barrier);
	}
	else
	    fprintf(stderr, "No change in barrier potential required because average transitions are above treshold");
    }

    // prevent that it gets stuck in the middle
    if (diff > 0.1 && diff < 0.9) {
	// in the middle
        // the transisiton counter was last reset in the last lower the barrier operation
	if (ts_now - transitions[ts_array-1].ts > adaption_treshold)
        { 
	    // increase the barrier again
	    
	    if (barrier == 0.0)
		barrier = -5.0;
	    else
		barrier*=1.01; 
	    transitions[ts_array-1].ts = ts_now;
            // increase barrier
	}
    }
    */
    /* fprintf(stderr,"lambda = %lf, total dvdl = %lf + %lf, T_lambda(thetha) = %lg, ekin_lambda = %lg, thetha = %lg, v_thetha = %lg, v_lambda = %lg, ts = %lg\n",lambda,dvdl,dvdl2, ld->T,ld->ekin, ld->thetha, ld->v_thetha, ld->v, ts_now);
     */
    //  }
    //  if(PAR(cr)){
    /* communication of lambda value */
    //gmx_sumd(1,&lambda,cr);
    //    gmx_sumd(1,&lambda_double,cr);
    //fprintf(stderr, "node %d: %g ",cr->nodeid, lambda);
    //  } 
  lambda=(real)lambda_double;
  
  return ((real)lambda);   
}

real do_lambda_dynamics(t_commrec *cr, double dvdl, 
			t_inputrec *ir,  struct t_ldrec *ld, float l_his_partner, real barrier_tmp1, real barrier_tmp2 ){
  real lambda=0;

  /* only version 4 is supported from 20080221 on */

  /* experimentally fit dgdl to the lambda dynamics function */
  lambda = update_lambda_4(cr,dvdl,ir,ld,l_his_partner,barrier_tmp1,barrier_tmp2);
    /* some printing */
  return lambda;
} /* do_lambda_dynamics */


void init_spline(int pts, double* x_spline, double** dqspline, double h) {

  int i,j,p;
  double k0[pts],k1[pts],n,k2[pts],k3[pts];
  double a1,a2,a3,a4,a5,a6,a7,b1,b2,b3,b4,b5,b6,b7,e1,e2,e3,e4,e5,e6,e7;
  double diffx;
  double a[pts][pts];double b[pts];
  double c1,c2,c3,c4,c5,c6,c7,d1,d2,d3,d4,d5,d6,d7,f1,f2,f3,f4,f5,f6,f7;
  double m1,m2,m3,m4,m5,m6,m7,n1,n2,n3,n4,n5,n6,n7;
  double k[pts],pa[pts],pb[pts],q0[pts],q1[pts],q2[pts],q3[pts];
  double dq1[pts],dq2[pts],dq3[pts];
  double det, detA, detB[pts];

  double x[pts]; double fx[pts];
  i=0;j=0;
  
  x[0]=0.1;   fx[0]=0.0;
  x[1]=0.2;   fx[1]=h/2.25;
  x[2]=0.3;   fx[2]=h/1.25;
  x[3]=0.5;    fx[3]=h;
  x[4]=0.7;    fx[4]=h/1.25;
  x[5]=0.8;    fx[5]=h/2.25;
  x[6]=0.9;    fx[6]=0.0;
  
  fprintf(stderr, "barrier %f\n",h);

  for (i=0;i<pts;i++)
    (x_spline[i])=x[i]; 
  for (i=0;i<(pts);i++)
    fprintf(stderr, "point[%d]: (%f, %f)\n",i,x_spline[i],fx[i]);

   for (i=0;i<(pts);i++) { /* set the first (first) derivative of the first spline to zero */ 
    if (i==0) {
      a[i][0]=1;
      a[i][1]=0;1/(x[1]-x[0]); 
      for (j=2;j<(pts);j++)
	a[i][j]=0.0;
      b[i]=0;
    }
    else if (i==(pts-1)) {  /* set the last (first) derivative of the last spline to zero */ 
      for (j=0;j<(pts-2);j++)
	a[i][j]=0.0;
      a[i][(pts-2)]=0;
      a[i][(pts-1)]=1;
      b[i]=0;
    }
    else  {
      for (j=0;j<(i-1);j++)
	a[i][j]=0.0;
      a[i][j]=1/(x[i]-x[(i-1)]);
      a[i][j+1]=2*(1/(x[i]-x[(i-1)]) + 1/(x[(i+1)]-x[i]));
      a[i][j+2]=1/(x[(i+1)]-x[i]);
      for (j=(i+2);j<(pts);j++)
	a[i][j]=0.0;
      b[i]=3*( (fx[i]-fx[(i-1)])/( (x[i]-x[(i-1)])*(x[i]-x[(i-1)]) ) + (fx[(i+1)]-fx[i])/( (x[(i+1)]-x[i])*(x[(i+1)]-x[i]) ) );
    }
  }

  /* Matrix A is:
   a[i=0][j=0]       ... a[i=0][j=pts-1]    
   .
   .
   .
    a[i=pts-1][j=0]  ... a[i=pts-1][j=pts-1]      
   */

    a1=a[0][0]; b1=a[0][1]; c1=a[0][2]; d1=a[0][3]; e1=a[0][4]; m1=a[0][5]; n1=a[0][6]; f1=b[0];
    a2=a[1][0]; b2=a[1][1]; c2=a[1][2]; d2=a[1][3]; e2=a[1][4]; m2=a[1][5]; n2=a[1][6]; f2=b[1]; 
    a3=a[2][0]; b3=a[2][1]; c3=a[2][2]; d3=a[2][3]; e3=a[2][4]; m3=a[2][5]; n3=a[2][6]; f3=b[2];
    a4=a[3][0]; b4=a[3][1]; c4=a[3][2]; d4=a[3][3]; e4=a[3][4]; m4=a[3][5]; n4=a[3][6]; f4=b[3];
    a5=a[4][0]; b5=a[4][1]; c5=a[4][2]; d5=a[4][3]; e5=a[4][4]; m5=a[4][5]; n5=a[4][6]; f5=b[4];
    a6=a[5][0]; b6=a[5][1]; c6=a[5][2]; d6=a[5][3]; e6=a[5][4]; m6=a[5][5]; n6=a[5][6]; f6=b[5];
    a7=a[6][0]; b7=a[6][1]; c7=a[6][2]; d7=a[6][3]; e7=a[6][4]; m7=a[6][5]; n7=a[6][6]; f7=b[6];

    /*for (i=0;i<pts;i++) {
      for (j=0;j<pts;j++) {
	printf("a[%d][%d]=%f\t",i,j,a[i][j]);
      }
      printf("b[%d]=%f\n",i,b[i]);
      }*/

    if (pts==7) {

      for (p=0;p<(pts+1);p++) {
      
	if (p==0)
	  ;
	else if (p==1) {
	  a1 = f1; 
	  a2 = f2;
	  a3 = f3;
	  a4 = f4;
	  a5 = f5;
	  a6 = f6;
	  a7 = b7;
	}
	else if (p==2) {
		a1=a[0][0]; b1 = f1;
		a2=a[1][0]; b2 = f2;
		a3=a[2][0]; b3 = f3;
		a4=a[3][0]; b4 = f4;
		a5=a[4][0]; b5 = f5;
		a6=a[5][0]; b6 = f6;
		a7=a[6][0]; b7 = f7;
	}
	else if (p==3) {
		b1=a[0][1]; c1 = f1;
		b2=a[1][1]; c2 = f2;
		b3=a[2][1]; c3 = f3;
		b4=a[3][1]; c4 = f4;
		b5=a[4][1]; c5 = f5;
		b6=a[5][1]; c6 = f6;
		b7=a[6][1]; c7 = f7;
	}
	else if (p==4) {
		c1=a[0][2]; d1 = f1;
		c2=a[1][2]; d2 = f2;
		c3=a[2][2]; d3 = f3;
		c4=a[3][2]; d4 = f4;
		c5=a[4][2]; d5 = f5;
		c6=a[5][2]; d6 = f6;
		c7=a[6][2]; d7 = f7;
	}
	else if (p==5) {
		d1=a[0][3]; e1 = f1;
		d2=a[1][3]; e2 = f2;
		d3=a[2][3]; e3 = f3;
		d4=a[3][3]; e4 = f4;
		d5=a[4][3]; e5 = f5;
		d6=a[5][3]; e6 = f6;
		d7=a[6][3]; e7 = f7;
	}
	else if (p==6) { 
		e1=a[0][4]; m1 = f1;
		e2=a[1][4]; m2 = f2;
		e3=a[2][4]; m3 = f3;
		e4=a[3][4]; m4 = f4;
		e5=a[4][4]; m5 = f5;
		e6=a[5][4]; m6 = f6;
		e7=a[6][4]; m7 = f7;
	}
	else { // case (p==7) 
		m1=a[0][5]; n1 = f1;
		m2=a[1][5]; n2 = f2;
		m3=a[2][5]; n3 = f3;
		m4=a[3][5]; n4 = f4;
		m5=a[4][5]; n5 = f5;
		m6=a[5][5]; n6 = f6;
		m7=a[6][5]; n7 = f7;
	}

    det = -m7* (-e6* (a5* b4* c3* d2* n1 - a4* b5* c3* d2* n1 - a5* b3* c4* d2* n1 + 
       a3* b5* c4* d2* n1 + a4* b3* c5* d2* n1 - a3* b4* c5* d2* n1 - 
       a5* b4* c2* d3* n1 + a4* b5* c2* d3* n1 + a5* b2* c4* d3* n1 - 
       a2* b5* c4* d3* n1 - a4* b2* c5* d3* n1 + a2* b4* c5* d3* n1 + 
       a5* b3* c2* d4* n1 - a3* b5* c2* d4* n1 - a5* b2* c3* d4* n1 + 
       a2* b5* c3* d4* n1 + a3* b2* c5* d4* n1 - a2* b3* c5* d4* n1 - 
       a4* b3* c2* d5* n1 + a3* b4* c2* d5* n1 + a4* b2* c3* d5* n1 - 
       a2* b4* c3* d5* n1 - a3* b2* c4* d5* n1 + a2* b3* c4* d5* n1 - 
       a5* b4* c3* d1* n2 + a4* b5* c3* d1* n2 + a5* b3* c4* d1* n2 - 
       a3* b5* c4* d1* n2 - a4* b3* c5* d1* n2 + a3* b4* c5* d1* n2 + 
       a5* b4* c1* d3* n2 - a4* b5* c1* d3* n2 - a5* b1* c4* d3* n2 + 
       a1* b5* c4* d3* n2 + a4* b1* c5* d3* n2 - a1* b4* c5* d3* n2 - 
       a5* b3* c1* d4* n2 + a3* b5* c1* d4* n2 + a5* b1* c3* d4* n2 - 
       a1* b5* c3* d4* n2 - a3* b1* c5* d4* n2 + a1* b3* c5* d4* n2 + 
       a4* b3* c1* d5* n2 - a3* b4* c1* d5* n2 - a4* b1* c3* d5* n2 + 
       a1* b4* c3* d5* n2 + a3* b1* c4* d5* n2 - a1* b3* c4* d5* n2 + 
       a5* b4* c2* d1* n3 - a4* b5* c2* d1* n3 - a5* b2* c4* d1* n3 + 
       a2* b5* c4* d1* n3 + a4* b2* c5* d1* n3 - a2* b4* c5* d1* n3 - 
       a5* b4* c1* d2* n3 + a4* b5* c1* d2* n3 + a5* b1* c4* d2* n3 - 
       a1* b5* c4* d2* n3 - a4* b1* c5* d2* n3 + a1* b4* c5* d2* n3 + 
       a5* b2* c1* d4* n3 - a2* b5* c1* d4* n3 - a5* b1* c2* d4* n3 + 
       a1* b5* c2* d4* n3 + a2* b1* c5* d4* n3 - a1* b2* c5* d4* n3 - 
       a4* b2* c1* d5* n3 + a2* b4* c1* d5* n3 + a4* b1* c2* d5* n3 - 
       a1* b4* c2* d5* n3 - a2* b1* c4* d5* n3 + a1* b2* c4* d5* n3 - 
       a5* b3* c2* d1* n4 + a3* b5* c2* d1* n4 + a5* b2* c3* d1* n4 - 
       a2* b5* c3* d1* n4 - a3* b2* c5* d1* n4 + a2* b3* c5* d1* n4 + 
       a5* b3* c1* d2* n4 - a3* b5* c1* d2* n4 - a5* b1* c3* d2* n4 + 
       a1* b5* c3* d2* n4 + a3* b1* c5* d2* n4 - a1* b3* c5* d2* n4 - 
       a5* b2* c1* d3* n4 + a2* b5* c1* d3* n4 + a5* b1* c2* d3* n4 - 
       a1* b5* c2* d3* n4 - a2* b1* c5* d3* n4 + a1* b2* c5* d3* n4 + 
       a3* b2* c1* d5* n4 - a2* b3* c1* d5* n4 - a3* b1* c2* d5* n4 + 
       a1* b3* c2* d5* n4 + a2* b1* c3* d5* n4 - a1* b2* c3* d5* n4 + 
       a4* b3* c2* d1* n5 - a3* b4* c2* d1* n5 - a4* b2* c3* d1* n5 + 
       a2* b4* c3* d1* n5 + a3* b2* c4* d1* n5 - a2* b3* c4* d1* n5 - 
       a4* b3* c1* d2* n5 + a3* b4* c1* d2* n5 + a4* b1* c3* d2* n5 - 
       a1* b4* c3* d2* n5 - a3* b1* c4* d2* n5 + a1* b3* c4* d2* n5 + 
       a4* b2* c1* d3* n5 - a2* b4* c1* d3* n5 - a4* b1* c2* d3* n5 + 
       a1* b4* c2* d3* n5 + a2* b1* c4* d3* n5 - a1* b2* c4* d3* n5 - 
       a3* b2* c1* d4* n5 + a2* b3* c1* d4* n5 + a3* b1* c2* d4* n5 - 
       a1* b3* c2* d4* n5 - a2* b1* c3* d4* n5 + a1* b2* c3* d4* n5) + 
    d6* (a5* b4* c3* e2* n1 - a4* b5* c3* e2* n1 - a5* b3* c4* e2* n1 + 
       a3* b5* c4* e2* n1 + a4* b3* c5* e2* n1 - a3* b4* c5* e2* n1 - 
       a5* b4* c2* e3* n1 + a4* b5* c2* e3* n1 + a5* b2* c4* e3* n1 - 
       a2* b5* c4* e3* n1 - a4* b2* c5* e3* n1 + a2* b4* c5* e3* n1 + 
       a5* b3* c2* e4* n1 - a3* b5* c2* e4* n1 - a5* b2* c3* e4* n1 + 
       a2* b5* c3* e4* n1 + a3* b2* c5* e4* n1 - a2* b3* c5* e4* n1 - 
       a4* b3* c2* e5* n1 + a3* b4* c2* e5* n1 + a4* b2* c3* e5* n1 - 
       a2* b4* c3* e5* n1 - a3* b2* c4* e5* n1 + a2* b3* c4* e5* n1 - 
       a5* b4* c3* e1* n2 + a4* b5* c3* e1* n2 + a5* b3* c4* e1* n2 - 
       a3* b5* c4* e1* n2 - a4* b3* c5* e1* n2 + a3* b4* c5* e1* n2 + 
       a5* b4* c1* e3* n2 - a4* b5* c1* e3* n2 - a5* b1* c4* e3* n2 + 
       a1* b5* c4* e3* n2 + a4* b1* c5* e3* n2 - a1* b4* c5* e3* n2 - 
       a5* b3* c1* e4* n2 + a3* b5* c1* e4* n2 + a5* b1* c3* e4* n2 - 
       a1* b5* c3* e4* n2 - a3* b1* c5* e4* n2 + a1* b3* c5* e4* n2 + 
       a4* b3* c1* e5* n2 - a3* b4* c1* e5* n2 - a4* b1* c3* e5* n2 + 
       a1* b4* c3* e5* n2 + a3* b1* c4* e5* n2 - a1* b3* c4* e5* n2 + 
       a5* b4* c2* e1* n3 - a4* b5* c2* e1* n3 - a5* b2* c4* e1* n3 + 
       a2* b5* c4* e1* n3 + a4* b2* c5* e1* n3 - a2* b4* c5* e1* n3 - 
       a5* b4* c1* e2* n3 + a4* b5* c1* e2* n3 + a5* b1* c4* e2* n3 - 
       a1* b5* c4* e2* n3 - a4* b1* c5* e2* n3 + a1* b4* c5* e2* n3 + 
       a5* b2* c1* e4* n3 - a2* b5* c1* e4* n3 - a5* b1* c2* e4* n3 + 
       a1* b5* c2* e4* n3 + a2* b1* c5* e4* n3 - a1* b2* c5* e4* n3 - 
       a4* b2* c1* e5* n3 + a2* b4* c1* e5* n3 + a4* b1* c2* e5* n3 - 
       a1* b4* c2* e5* n3 - a2* b1* c4* e5* n3 + a1* b2* c4* e5* n3 - 
       a5* b3* c2* e1* n4 + a3* b5* c2* e1* n4 + a5* b2* c3* e1* n4 - 
       a2* b5* c3* e1* n4 - a3* b2* c5* e1* n4 + a2* b3* c5* e1* n4 + 
       a5* b3* c1* e2* n4 - a3* b5* c1* e2* n4 - a5* b1* c3* e2* n4 + 
       a1* b5* c3* e2* n4 + a3* b1* c5* e2* n4 - a1* b3* c5* e2* n4 - 
       a5* b2* c1* e3* n4 + a2* b5* c1* e3* n4 + a5* b1* c2* e3* n4 - 
       a1* b5* c2* e3* n4 - a2* b1* c5* e3* n4 + a1* b2* c5* e3* n4 + 
       a3* b2* c1* e5* n4 - a2* b3* c1* e5* n4 - a3* b1* c2* e5* n4 + 
       a1* b3* c2* e5* n4 + a2* b1* c3* e5* n4 - a1* b2* c3* e5* n4 + 
       a4* b3* c2* e1* n5 - a3* b4* c2* e1* n5 - a4* b2* c3* e1* n5 + 
       a2* b4* c3* e1* n5 + a3* b2* c4* e1* n5 - a2* b3* c4* e1* n5 - 
       a4* b3* c1* e2* n5 + a3* b4* c1* e2* n5 + a4* b1* c3* e2* n5 - 
       a1* b4* c3* e2* n5 - a3* b1* c4* e2* n5 + a1* b3* c4* e2* n5 + 
       a4* b2* c1* e3* n5 - a2* b4* c1* e3* n5 - a4* b1* c2* e3* n5 + 
       a1* b4* c2* e3* n5 + a2* b1* c4* e3* n5 - a1* b2* c4* e3* n5 - 
       a3* b2* c1* e4* n5 + a2* b3* c1* e4* n5 + a3* b1* c2* e4* n5 - 
       a1* b3* c2* e4* n5 - a2* b1* c3* e4* n5 + a1* b2* c3* e4* n5) - 
    c6* (a5* b4* d3* e2* n1 - a4* b5* d3* e2* n1 - a5* b3* d4* e2* n1 + 
       a3* b5* d4* e2* n1 + a4* b3* d5* e2* n1 - a3* b4* d5* e2* n1 - 
       a5* b4* d2* e3* n1 + a4* b5* d2* e3* n1 + a5* b2* d4* e3* n1 - 
       a2* b5* d4* e3* n1 - a4* b2* d5* e3* n1 + a2* b4* d5* e3* n1 + 
       a5* b3* d2* e4* n1 - a3* b5* d2* e4* n1 - a5* b2* d3* e4* n1 + 
       a2* b5* d3* e4* n1 + a3* b2* d5* e4* n1 - a2* b3* d5* e4* n1 - 
       a4* b3* d2* e5* n1 + a3* b4* d2* e5* n1 + a4* b2* d3* e5* n1 - 
       a2* b4* d3* e5* n1 - a3* b2* d4* e5* n1 + a2* b3* d4* e5* n1 - 
       a5* b4* d3* e1* n2 + a4* b5* d3* e1* n2 + a5* b3* d4* e1* n2 - 
       a3* b5* d4* e1* n2 - a4* b3* d5* e1* n2 + a3* b4* d5* e1* n2 + 
       a5* b4* d1* e3* n2 - a4* b5* d1* e3* n2 - a5* b1* d4* e3* n2 + 
       a1* b5* d4* e3* n2 + a4* b1* d5* e3* n2 - a1* b4* d5* e3* n2 - 
       a5* b3* d1* e4* n2 + a3* b5* d1* e4* n2 + a5* b1* d3* e4* n2 - 
       a1* b5* d3* e4* n2 - a3* b1* d5* e4* n2 + a1* b3* d5* e4* n2 + 
       a4* b3* d1* e5* n2 - a3* b4* d1* e5* n2 - a4* b1* d3* e5* n2 + 
       a1* b4* d3* e5* n2 + a3* b1* d4* e5* n2 - a1* b3* d4* e5* n2 + 
       a5* b4* d2* e1* n3 - a4* b5* d2* e1* n3 - a5* b2* d4* e1* n3 + 
       a2* b5* d4* e1* n3 + a4* b2* d5* e1* n3 - a2* b4* d5* e1* n3 - 
       a5* b4* d1* e2* n3 + a4* b5* d1* e2* n3 + a5* b1* d4* e2* n3 - 
       a1* b5* d4* e2* n3 - a4* b1* d5* e2* n3 + a1* b4* d5* e2* n3 + 
       a5* b2* d1* e4* n3 - a2* b5* d1* e4* n3 - a5* b1* d2* e4* n3 + 
       a1* b5* d2* e4* n3 + a2* b1* d5* e4* n3 - a1* b2* d5* e4* n3 - 
       a4* b2* d1* e5* n3 + a2* b4* d1* e5* n3 + a4* b1* d2* e5* n3 - 
       a1* b4* d2* e5* n3 - a2* b1* d4* e5* n3 + a1* b2* d4* e5* n3 - 
       a5* b3* d2* e1* n4 + a3* b5* d2* e1* n4 + a5* b2* d3* e1* n4 - 
       a2* b5* d3* e1* n4 - a3* b2* d5* e1* n4 + a2* b3* d5* e1* n4 + 
       a5* b3* d1* e2* n4 - a3* b5* d1* e2* n4 - a5* b1* d3* e2* n4 + 
       a1* b5* d3* e2* n4 + a3* b1* d5* e2* n4 - a1* b3* d5* e2* n4 - 
       a5* b2* d1* e3* n4 + a2* b5* d1* e3* n4 + a5* b1* d2* e3* n4 - 
       a1* b5* d2* e3* n4 - a2* b1* d5* e3* n4 + a1* b2* d5* e3* n4 + 
       a3* b2* d1* e5* n4 - a2* b3* d1* e5* n4 - a3* b1* d2* e5* n4 + 
       a1* b3* d2* e5* n4 + a2* b1* d3* e5* n4 - a1* b2* d3* e5* n4 + 
       a4* b3* d2* e1* n5 - a3* b4* d2* e1* n5 - a4* b2* d3* e1* n5 + 
       a2* b4* d3* e1* n5 + a3* b2* d4* e1* n5 - a2* b3* d4* e1* n5 - 
       a4* b3* d1* e2* n5 + a3* b4* d1* e2* n5 + a4* b1* d3* e2* n5 - 
       a1* b4* d3* e2* n5 - a3* b1* d4* e2* n5 + a1* b3* d4* e2* n5 + 
       a4* b2* d1* e3* n5 - a2* b4* d1* e3* n5 - a4* b1* d2* e3* n5 + 
       a1* b4* d2* e3* n5 + a2* b1* d4* e3* n5 - a1* b2* d4* e3* n5 - 
       a3* b2* d1* e4* n5 + a2* b3* d1* e4* n5 + a3* b1* d2* e4* n5 - 
       a1* b3* d2* e4* n5 - a2* b1* d3* e4* n5 + a1* b2* d3* e4* n5) + 
    b6* (a5* c4* d3* e2* n1 - a4* c5* d3* e2* n1 - a5* c3* d4* e2* n1 + 
       a3* c5* d4* e2* n1 + a4* c3* d5* e2* n1 - a3* c4* d5* e2* n1 - 
       a5* c4* d2* e3* n1 + a4* c5* d2* e3* n1 + a5* c2* d4* e3* n1 - 
       a2* c5* d4* e3* n1 - a4* c2* d5* e3* n1 + a2* c4* d5* e3* n1 + 
       a5* c3* d2* e4* n1 - a3* c5* d2* e4* n1 - a5* c2* d3* e4* n1 + 
       a2* c5* d3* e4* n1 + a3* c2* d5* e4* n1 - a2* c3* d5* e4* n1 - 
       a4* c3* d2* e5* n1 + a3* c4* d2* e5* n1 + a4* c2* d3* e5* n1 - 
       a2* c4* d3* e5* n1 - a3* c2* d4* e5* n1 + a2* c3* d4* e5* n1 - 
       a5* c4* d3* e1* n2 + a4* c5* d3* e1* n2 + a5* c3* d4* e1* n2 - 
       a3* c5* d4* e1* n2 - a4* c3* d5* e1* n2 + a3* c4* d5* e1* n2 + 
       a5* c4* d1* e3* n2 - a4* c5* d1* e3* n2 - a5* c1* d4* e3* n2 + 
       a1* c5* d4* e3* n2 + a4* c1* d5* e3* n2 - a1* c4* d5* e3* n2 - 
       a5* c3* d1* e4* n2 + a3* c5* d1* e4* n2 + a5* c1* d3* e4* n2 - 
       a1* c5* d3* e4* n2 - a3* c1* d5* e4* n2 + a1* c3* d5* e4* n2 + 
       a4* c3* d1* e5* n2 - a3* c4* d1* e5* n2 - a4* c1* d3* e5* n2 + 
       a1* c4* d3* e5* n2 + a3* c1* d4* e5* n2 - a1* c3* d4* e5* n2 + 
       a5* c4* d2* e1* n3 - a4* c5* d2* e1* n3 - a5* c2* d4* e1* n3 + 
       a2* c5* d4* e1* n3 + a4* c2* d5* e1* n3 - a2* c4* d5* e1* n3 - 
       a5* c4* d1* e2* n3 + a4* c5* d1* e2* n3 + a5* c1* d4* e2* n3 - 
       a1* c5* d4* e2* n3 - a4* c1* d5* e2* n3 + a1* c4* d5* e2* n3 + 
       a5* c2* d1* e4* n3 - a2* c5* d1* e4* n3 - a5* c1* d2* e4* n3 + 
       a1* c5* d2* e4* n3 + a2* c1* d5* e4* n3 - a1* c2* d5* e4* n3 - 
       a4* c2* d1* e5* n3 + a2* c4* d1* e5* n3 + a4* c1* d2* e5* n3 - 
       a1* c4* d2* e5* n3 - a2* c1* d4* e5* n3 + a1* c2* d4* e5* n3 - 
       a5* c3* d2* e1* n4 + a3* c5* d2* e1* n4 + a5* c2* d3* e1* n4 - 
       a2* c5* d3* e1* n4 - a3* c2* d5* e1* n4 + a2* c3* d5* e1* n4 + 
       a5* c3* d1* e2* n4 - a3* c5* d1* e2* n4 - a5* c1* d3* e2* n4 + 
       a1* c5* d3* e2* n4 + a3* c1* d5* e2* n4 - a1* c3* d5* e2* n4 - 
       a5* c2* d1* e3* n4 + a2* c5* d1* e3* n4 + a5* c1* d2* e3* n4 - 
       a1* c5* d2* e3* n4 - a2* c1* d5* e3* n4 + a1* c2* d5* e3* n4 + 
       a3* c2* d1* e5* n4 - a2* c3* d1* e5* n4 - a3* c1* d2* e5* n4 + 
       a1* c3* d2* e5* n4 + a2* c1* d3* e5* n4 - a1* c2* d3* e5* n4 + 
       a4* c3* d2* e1* n5 - a3* c4* d2* e1* n5 - a4* c2* d3* e1* n5 + 
       a2* c4* d3* e1* n5 + a3* c2* d4* e1* n5 - a2* c3* d4* e1* n5 - 
       a4* c3* d1* e2* n5 + a3* c4* d1* e2* n5 + a4* c1* d3* e2* n5 - 
       a1* c4* d3* e2* n5 - a3* c1* d4* e2* n5 + a1* c3* d4* e2* n5 + 
       a4* c2* d1* e3* n5 - a2* c4* d1* e3* n5 - a4* c1* d2* e3* n5 + 
       a1* c4* d2* e3* n5 + a2* c1* d4* e3* n5 - a1* c2* d4* e3* n5 - 
       a3* c2* d1* e4* n5 + a2* c3* d1* e4* n5 + a3* c1* d2* e4* n5 - 
       a1* c3* d2* e4* n5 - a2* c1* d3* e4* n5 + a1* c2* d3* e4* n5) - 
    a6* (b5* c4* d3* e2* n1 - b4* c5* d3* e2* n1 - b5* c3* d4* e2* n1 + 
       b3* c5* d4* e2* n1 + b4* c3* d5* e2* n1 - b3* c4* d5* e2* n1 - 
       b5* c4* d2* e3* n1 + b4* c5* d2* e3* n1 + b5* c2* d4* e3* n1 - 
       b2* c5* d4* e3* n1 - b4* c2* d5* e3* n1 + b2* c4* d5* e3* n1 + 
       b5* c3* d2* e4* n1 - b3* c5* d2* e4* n1 - b5* c2* d3* e4* n1 + 
       b2* c5* d3* e4* n1 + b3* c2* d5* e4* n1 - b2* c3* d5* e4* n1 - 
       b4* c3* d2* e5* n1 + b3* c4* d2* e5* n1 + b4* c2* d3* e5* n1 - 
       b2* c4* d3* e5* n1 - b3* c2* d4* e5* n1 + b2* c3* d4* e5* n1 - 
       b5* c4* d3* e1* n2 + b4* c5* d3* e1* n2 + b5* c3* d4* e1* n2 - 
       b3* c5* d4* e1* n2 - b4* c3* d5* e1* n2 + b3* c4* d5* e1* n2 + 
       b5* c4* d1* e3* n2 - b4* c5* d1* e3* n2 - b5* c1* d4* e3* n2 + 
       b1* c5* d4* e3* n2 + b4* c1* d5* e3* n2 - b1* c4* d5* e3* n2 - 
       b5* c3* d1* e4* n2 + b3* c5* d1* e4* n2 + b5* c1* d3* e4* n2 - 
       b1* c5* d3* e4* n2 - b3* c1* d5* e4* n2 + b1* c3* d5* e4* n2 + 
       b4* c3* d1* e5* n2 - b3* c4* d1* e5* n2 - b4* c1* d3* e5* n2 + 
       b1* c4* d3* e5* n2 + b3* c1* d4* e5* n2 - b1* c3* d4* e5* n2 + 
       b5* c4* d2* e1* n3 - b4* c5* d2* e1* n3 - b5* c2* d4* e1* n3 + 
       b2* c5* d4* e1* n3 + b4* c2* d5* e1* n3 - b2* c4* d5* e1* n3 - 
       b5* c4* d1* e2* n3 + b4* c5* d1* e2* n3 + b5* c1* d4* e2* n3 - 
       b1* c5* d4* e2* n3 - b4* c1* d5* e2* n3 + b1* c4* d5* e2* n3 + 
       b5* c2* d1* e4* n3 - b2* c5* d1* e4* n3 - b5* c1* d2* e4* n3 + 
       b1* c5* d2* e4* n3 + b2* c1* d5* e4* n3 - b1* c2* d5* e4* n3 - 
       b4* c2* d1* e5* n3 + b2* c4* d1* e5* n3 + b4* c1* d2* e5* n3 - 
       b1* c4* d2* e5* n3 - b2* c1* d4* e5* n3 + b1* c2* d4* e5* n3 - 
       b5* c3* d2* e1* n4 + b3* c5* d2* e1* n4 + b5* c2* d3* e1* n4 - 
       b2* c5* d3* e1* n4 - b3* c2* d5* e1* n4 + b2* c3* d5* e1* n4 + 
       b5* c3* d1* e2* n4 - b3* c5* d1* e2* n4 - b5* c1* d3* e2* n4 + 
       b1* c5* d3* e2* n4 + b3* c1* d5* e2* n4 - b1* c3* d5* e2* n4 - 
       b5* c2* d1* e3* n4 + b2* c5* d1* e3* n4 + b5* c1* d2* e3* n4 - 
       b1* c5* d2* e3* n4 - b2* c1* d5* e3* n4 + b1* c2* d5* e3* n4 + 
       b3* c2* d1* e5* n4 - b2* c3* d1* e5* n4 - b3* c1* d2* e5* n4 + 
       b1* c3* d2* e5* n4 + b2* c1* d3* e5* n4 - b1* c2* d3* e5* n4 + 
       b4* c3* d2* e1* n5 - b3* c4* d2* e1* n5 - b4* c2* d3* e1* n5 + 
       b2* c4* d3* e1* n5 + b3* c2* d4* e1* n5 - b2* c3* d4* e1* n5 - 
       b4* c3* d1* e2* n5 + b3* c4* d1* e2* n5 + b4* c1* d3* e2* n5 - 
       b1* c4* d3* e2* n5 - b3* c1* d4* e2* n5 + b1* c3* d4* e2* n5 + 
       b4* c2* d1* e3* n5 - b2* c4* d1* e3* n5 - b4* c1* d2* e3* n5 + 
       b1* c4* d2* e3* n5 + b2* c1* d4* e3* n5 - b1* c2* d4* e3* n5 - 
       b3* c2* d1* e4* n5 + b2* c3* d1* e4* n5 + b3* c1* d2* e4* n5 - 
       b1* c3* d2* e4* n5 - b2* c1* d3* e4* n5 +
       b1* c2* d3* e4* n5) + (a5* b4* c3* d2* e1 - a4* b5* c3* d2* e1 - 
       a5* b3* c4* d2* e1 + a3* b5* c4* d2* e1 + a4* b3* c5* d2* e1 - 
       a3* b4* c5* d2* e1 - a5* b4* c2* d3* e1 + a4* b5* c2* d3* e1 + 
       a5* b2* c4* d3* e1 - a2* b5* c4* d3* e1 - a4* b2* c5* d3* e1 + 
       a2* b4* c5* d3* e1 + a5* b3* c2* d4* e1 - a3* b5* c2* d4* e1 - 
       a5* b2* c3* d4* e1 + a2* b5* c3* d4* e1 + a3* b2* c5* d4* e1 - 
       a2* b3* c5* d4* e1 - a4* b3* c2* d5* e1 + a3* b4* c2* d5* e1 + 
       a4* b2* c3* d5* e1 - a2* b4* c3* d5* e1 - a3* b2* c4* d5* e1 + 
       a2* b3* c4* d5* e1 - a5* b4* c3* d1* e2 + a4* b5* c3* d1* e2 + 
       a5* b3* c4* d1* e2 - a3* b5* c4* d1* e2 - a4* b3* c5* d1* e2 + 
       a3* b4* c5* d1* e2 + a5* b4* c1* d3* e2 - a4* b5* c1* d3* e2 - 
       a5* b1* c4* d3* e2 + a1* b5* c4* d3* e2 + a4* b1* c5* d3* e2 - 
       a1* b4* c5* d3* e2 - a5* b3* c1* d4* e2 + a3* b5* c1* d4* e2 + 
       a5* b1* c3* d4* e2 - a1* b5* c3* d4* e2 - a3* b1* c5* d4* e2 + 
       a1* b3* c5* d4* e2 + a4* b3* c1* d5* e2 - a3* b4* c1* d5* e2 - 
       a4* b1* c3* d5* e2 + a1* b4* c3* d5* e2 + a3* b1* c4* d5* e2 - 
       a1* b3* c4* d5* e2 + a5* b4* c2* d1* e3 - a4* b5* c2* d1* e3 - 
       a5* b2* c4* d1* e3 + a2* b5* c4* d1* e3 + a4* b2* c5* d1* e3 - 
       a2* b4* c5* d1* e3 - a5* b4* c1* d2* e3 + a4* b5* c1* d2* e3 + 
       a5* b1* c4* d2* e3 - a1* b5* c4* d2* e3 - a4* b1* c5* d2* e3 + 
       a1* b4* c5* d2* e3 + a5* b2* c1* d4* e3 - a2* b5* c1* d4* e3 - 
       a5* b1* c2* d4* e3 + a1* b5* c2* d4* e3 + a2* b1* c5* d4* e3 - 
       a1* b2* c5* d4* e3 - a4* b2* c1* d5* e3 + a2* b4* c1* d5* e3 + 
       a4* b1* c2* d5* e3 - a1* b4* c2* d5* e3 - a2* b1* c4* d5* e3 + 
       a1* b2* c4* d5* e3 - a5* b3* c2* d1* e4 + a3* b5* c2* d1* e4 + 
       a5* b2* c3* d1* e4 - a2* b5* c3* d1* e4 - a3* b2* c5* d1* e4 + 
       a2* b3* c5* d1* e4 + a5* b3* c1* d2* e4 - a3* b5* c1* d2* e4 - 
       a5* b1* c3* d2* e4 + a1* b5* c3* d2* e4 + a3* b1* c5* d2* e4 - 
       a1* b3* c5* d2* e4 - a5* b2* c1* d3* e4 + a2* b5* c1* d3* e4 + 
       a5* b1* c2* d3* e4 - a1* b5* c2* d3* e4 - a2* b1* c5* d3* e4 + 
       a1* b2* c5* d3* e4 + a3* b2* c1* d5* e4 - a2* b3* c1* d5* e4 - 
       a3* b1* c2* d5* e4 + a1* b3* c2* d5* e4 + a2* b1* c3* d5* e4 - 
       a1* b2* c3* d5* e4 + a4* b3* c2* d1* e5 - a3* b4* c2* d1* e5 - 
       a4* b2* c3* d1* e5 + a2* b4* c3* d1* e5 + a3* b2* c4* d1* e5 - 
       a2* b3* c4* d1* e5 - a4* b3* c1* d2* e5 + a3* b4* c1* d2* e5 + 
       a4* b1* c3* d2* e5 - a1* b4* c3* d2* e5 - a3* b1* c4* d2* e5 + 
       a1* b3* c4* d2* e5 + a4* b2* c1* d3* e5 - a2* b4* c1* d3* e5 - 
       a4* b1* c2* d3* e5 + a1* b4* c2* d3* e5 + a2* b1* c4* d3* e5 - 
       a1* b2* c4* d3* e5 - a3* b2* c1* d4* e5 + a2* b3* c1* d4* e5 + 
       a3* b1* c2* d4* e5 - a1* b3* c2* d4* e5 - a2* b1* c3* d4* e5 + 
       a1* b2* c3* d4* e5) *n6) + 
 e7* (-m6* (a5* b4* c3* d2* n1 - a4* b5* c3* d2* n1 - a5* b3* c4* d2* n1 + 
       a3* b5* c4* d2* n1 + a4* b3* c5* d2* n1 - a3* b4* c5* d2* n1 - 
       a5* b4* c2* d3* n1 + a4* b5* c2* d3* n1 + a5* b2* c4* d3* n1 - 
       a2* b5* c4* d3* n1 - a4* b2* c5* d3* n1 + a2* b4* c5* d3* n1 + 
       a5* b3* c2* d4* n1 - a3* b5* c2* d4* n1 - a5* b2* c3* d4* n1 + 
       a2* b5* c3* d4* n1 + a3* b2* c5* d4* n1 - a2* b3* c5* d4* n1 - 
       a4* b3* c2* d5* n1 + a3* b4* c2* d5* n1 + a4* b2* c3* d5* n1 - 
       a2* b4* c3* d5* n1 - a3* b2* c4* d5* n1 + a2* b3* c4* d5* n1 - 
       a5* b4* c3* d1* n2 + a4* b5* c3* d1* n2 + a5* b3* c4* d1* n2 - 
       a3* b5* c4* d1* n2 - a4* b3* c5* d1* n2 + a3* b4* c5* d1* n2 + 
       a5* b4* c1* d3* n2 - a4* b5* c1* d3* n2 - a5* b1* c4* d3* n2 + 
       a1* b5* c4* d3* n2 + a4* b1* c5* d3* n2 - a1* b4* c5* d3* n2 - 
       a5* b3* c1* d4* n2 + a3* b5* c1* d4* n2 + a5* b1* c3* d4* n2 - 
       a1* b5* c3* d4* n2 - a3* b1* c5* d4* n2 + a1* b3* c5* d4* n2 + 
       a4* b3* c1* d5* n2 - a3* b4* c1* d5* n2 - a4* b1* c3* d5* n2 + 
       a1* b4* c3* d5* n2 + a3* b1* c4* d5* n2 - a1* b3* c4* d5* n2 + 
       a5* b4* c2* d1* n3 - a4* b5* c2* d1* n3 - a5* b2* c4* d1* n3 + 
       a2* b5* c4* d1* n3 + a4* b2* c5* d1* n3 - a2* b4* c5* d1* n3 - 
       a5* b4* c1* d2* n3 + a4* b5* c1* d2* n3 + a5* b1* c4* d2* n3 - 
       a1* b5* c4* d2* n3 - a4* b1* c5* d2* n3 + a1* b4* c5* d2* n3 + 
       a5* b2* c1* d4* n3 - a2* b5* c1* d4* n3 - a5* b1* c2* d4* n3 + 
       a1* b5* c2* d4* n3 + a2* b1* c5* d4* n3 - a1* b2* c5* d4* n3 - 
       a4* b2* c1* d5* n3 + a2* b4* c1* d5* n3 + a4* b1* c2* d5* n3 - 
       a1* b4* c2* d5* n3 - a2* b1* c4* d5* n3 + a1* b2* c4* d5* n3 - 
       a5* b3* c2* d1* n4 + a3* b5* c2* d1* n4 + a5* b2* c3* d1* n4 - 
       a2* b5* c3* d1* n4 - a3* b2* c5* d1* n4 + a2* b3* c5* d1* n4 + 
       a5* b3* c1* d2* n4 - a3* b5* c1* d2* n4 - a5* b1* c3* d2* n4 + 
       a1* b5* c3* d2* n4 + a3* b1* c5* d2* n4 - a1* b3* c5* d2* n4 - 
       a5* b2* c1* d3* n4 + a2* b5* c1* d3* n4 + a5* b1* c2* d3* n4 - 
       a1* b5* c2* d3* n4 - a2* b1* c5* d3* n4 + a1* b2* c5* d3* n4 + 
       a3* b2* c1* d5* n4 - a2* b3* c1* d5* n4 - a3* b1* c2* d5* n4 + 
       a1* b3* c2* d5* n4 + a2* b1* c3* d5* n4 - a1* b2* c3* d5* n4 + 
       a4* b3* c2* d1* n5 - a3* b4* c2* d1* n5 - a4* b2* c3* d1* n5 + 
       a2* b4* c3* d1* n5 + a3* b2* c4* d1* n5 - a2* b3* c4* d1* n5 - 
       a4* b3* c1* d2* n5 + a3* b4* c1* d2* n5 + a4* b1* c3* d2* n5 - 
       a1* b4* c3* d2* n5 - a3* b1* c4* d2* n5 + a1* b3* c4* d2* n5 + 
       a4* b2* c1* d3* n5 - a2* b4* c1* d3* n5 - a4* b1* c2* d3* n5 + 
       a1* b4* c2* d3* n5 + a2* b1* c4* d3* n5 - a1* b2* c4* d3* n5 - 
       a3* b2* c1* d4* n5 + a2* b3* c1* d4* n5 + a3* b1* c2* d4* n5 - 
       a1* b3* c2* d4* n5 - a2* b1* c3* d4* n5 + a1* b2* c3* d4* n5) + 
    d6* (a5* b4* c3* m2* n1 - a4* b5* c3* m2* n1 - a5* b3* c4* m2* n1 + 
       a3* b5* c4* m2* n1 + a4* b3* c5* m2* n1 - a3* b4* c5* m2* n1 - 
       a5* b4* c2* m3* n1 + a4* b5* c2* m3* n1 + a5* b2* c4* m3* n1 - 
       a2* b5* c4* m3* n1 - a4* b2* c5* m3* n1 + a2* b4* c5* m3* n1 + 
       a5* b3* c2* m4* n1 - a3* b5* c2* m4* n1 - a5* b2* c3* m4* n1 + 
       a2* b5* c3* m4* n1 + a3* b2* c5* m4* n1 - a2* b3* c5* m4* n1 - 
       a4* b3* c2* m5* n1 + a3* b4* c2* m5* n1 + a4* b2* c3* m5* n1 - 
       a2* b4* c3* m5* n1 - a3* b2* c4* m5* n1 + a2* b3* c4* m5* n1 - 
       a5* b4* c3* m1* n2 + a4* b5* c3* m1* n2 + a5* b3* c4* m1* n2 - 
       a3* b5* c4* m1* n2 - a4* b3* c5* m1* n2 + a3* b4* c5* m1* n2 + 
       a5* b4* c1* m3* n2 - a4* b5* c1* m3* n2 - a5* b1* c4* m3* n2 + 
       a1* b5* c4* m3* n2 + a4* b1* c5* m3* n2 - a1* b4* c5* m3* n2 - 
       a5* b3* c1* m4* n2 + a3* b5* c1* m4* n2 + a5* b1* c3* m4* n2 - 
       a1* b5* c3* m4* n2 - a3* b1* c5* m4* n2 + a1* b3* c5* m4* n2 + 
       a4* b3* c1* m5* n2 - a3* b4* c1* m5* n2 - a4* b1* c3* m5* n2 + 
       a1* b4* c3* m5* n2 + a3* b1* c4* m5* n2 - a1* b3* c4* m5* n2 + 
       a5* b4* c2* m1* n3 - a4* b5* c2* m1* n3 - a5* b2* c4* m1* n3 + 
       a2* b5* c4* m1* n3 + a4* b2* c5* m1* n3 - a2* b4* c5* m1* n3 - 
       a5* b4* c1* m2* n3 + a4* b5* c1* m2* n3 + a5* b1* c4* m2* n3 - 
       a1* b5* c4* m2* n3 - a4* b1* c5* m2* n3 + a1* b4* c5* m2* n3 + 
       a5* b2* c1* m4* n3 - a2* b5* c1* m4* n3 - a5* b1* c2* m4* n3 + 
       a1* b5* c2* m4* n3 + a2* b1* c5* m4* n3 - a1* b2* c5* m4* n3 - 
       a4* b2* c1* m5* n3 + a2* b4* c1* m5* n3 + a4* b1* c2* m5* n3 - 
       a1* b4* c2* m5* n3 - a2* b1* c4* m5* n3 + a1* b2* c4* m5* n3 - 
       a5* b3* c2* m1* n4 + a3* b5* c2* m1* n4 + a5* b2* c3* m1* n4 - 
       a2* b5* c3* m1* n4 - a3* b2* c5* m1* n4 + a2* b3* c5* m1* n4 + 

       a5* b3* c1* m2* n4 - a3* b5* c1* m2* n4 - a5* b1* c3* m2* n4 + 
       a1* b5* c3* m2* n4 + a3* b1* c5* m2* n4 - a1* b3* c5* m2* n4 - 
       a5* b2* c1* m3* n4 + a2* b5* c1* m3* n4 + a5* b1* c2* m3* n4 - 
       a1* b5* c2* m3* n4 - a2* b1* c5* m3* n4 + a1* b2* c5* m3* n4 + 
       a3* b2* c1* m5* n4 - a2* b3* c1* m5* n4 - a3* b1* c2* m5* n4 + 
       a1* b3* c2* m5* n4 + a2* b1* c3* m5* n4 - a1* b2* c3* m5* n4 + 
       a4* b3* c2* m1* n5 - a3* b4* c2* m1* n5 - a4* b2* c3* m1* n5 + 
       a2* b4* c3* m1* n5 + a3* b2* c4* m1* n5 - a2* b3* c4* m1* n5 - 
       a4* b3* c1* m2* n5 + a3* b4* c1* m2* n5 + a4* b1* c3* m2* n5 - 
       a1* b4* c3* m2* n5 - a3* b1* c4* m2* n5 + a1* b3* c4* m2* n5 + 
       a4* b2* c1* m3* n5 - a2* b4* c1* m3* n5 - a4* b1* c2* m3* n5 + 
       a1* b4* c2* m3* n5 + a2* b1* c4* m3* n5 - a1* b2* c4* m3* n5 - 
       a3* b2* c1* m4* n5 + a2* b3* c1* m4* n5 + a3* b1* c2* m4* n5 - 
       a1* b3* c2* m4* n5 - a2* b1* c3* m4* n5 + a1* b2* c3* m4* n5) - 
    c6* (a5* b4* d3* m2* n1 - a4* b5* d3* m2* n1 - a5* b3* d4* m2* n1 + 
       a3* b5* d4* m2* n1 + a4* b3* d5* m2* n1 - a3* b4* d5* m2* n1 - 
       a5* b4* d2* m3* n1 + a4* b5* d2* m3* n1 + a5* b2* d4* m3* n1 - 
       a2* b5* d4* m3* n1 - a4* b2* d5* m3* n1 + a2* b4* d5* m3* n1 + 
       a5* b3* d2* m4* n1 - a3* b5* d2* m4* n1 - a5* b2* d3* m4* n1 + 
       a2* b5* d3* m4* n1 + a3* b2* d5* m4* n1 - a2* b3* d5* m4* n1 - 
       a4* b3* d2* m5* n1 + a3* b4* d2* m5* n1 + a4* b2* d3* m5* n1 - 
       a2* b4* d3* m5* n1 - a3* b2* d4* m5* n1 + a2* b3* d4* m5* n1 - 
       a5* b4* d3* m1* n2 + a4* b5* d3* m1* n2 + a5* b3* d4* m1* n2 - 
       a3* b5* d4* m1* n2 - a4* b3* d5* m1* n2 + a3* b4* d5* m1* n2 + 
       a5* b4* d1* m3* n2 - a4* b5* d1* m3* n2 - a5* b1* d4* m3* n2 + 
       a1* b5* d4* m3* n2 + a4* b1* d5* m3* n2 - a1* b4* d5* m3* n2 - 
       a5* b3* d1* m4* n2 + a3* b5* d1* m4* n2 + a5* b1* d3* m4* n2 - 
       a1* b5* d3* m4* n2 - a3* b1* d5* m4* n2 + a1* b3* d5* m4* n2 + 
       a4* b3* d1* m5* n2 - a3* b4* d1* m5* n2 - a4* b1* d3* m5* n2 + 
       a1* b4* d3* m5* n2 + a3* b1* d4* m5* n2 - a1* b3* d4* m5* n2 + 
       a5* b4* d2* m1* n3 - a4* b5* d2* m1* n3 - a5* b2* d4* m1* n3 + 
       a2* b5* d4* m1* n3 + a4* b2* d5* m1* n3 - a2* b4* d5* m1* n3 - 
       a5* b4* d1* m2* n3 + a4* b5* d1* m2* n3 + a5* b1* d4* m2* n3 - 
       a1* b5* d4* m2* n3 - a4* b1* d5* m2* n3 + a1* b4* d5* m2* n3 + 
       a5* b2* d1* m4* n3 - a2* b5* d1* m4* n3 - a5* b1* d2* m4* n3 + 
       a1* b5* d2* m4* n3 + a2* b1* d5* m4* n3 - a1* b2* d5* m4* n3 - 
       a4* b2* d1* m5* n3 + a2* b4* d1* m5* n3 + a4* b1* d2* m5* n3 - 
       a1* b4* d2* m5* n3 - a2* b1* d4* m5* n3 + a1* b2* d4* m5* n3 - 
       a5* b3* d2* m1* n4 + a3* b5* d2* m1* n4 + a5* b2* d3* m1* n4 - 
       a2* b5* d3* m1* n4 - a3* b2* d5* m1* n4 + a2* b3* d5* m1* n4 + 
       a5* b3* d1* m2* n4 - a3* b5* d1* m2* n4 - a5* b1* d3* m2* n4 + 
       a1* b5* d3* m2* n4 + a3* b1* d5* m2* n4 - a1* b3* d5* m2* n4 - 
       a5* b2* d1* m3* n4 + a2* b5* d1* m3* n4 + a5* b1* d2* m3* n4 - 
       a1* b5* d2* m3* n4 - a2* b1* d5* m3* n4 + a1* b2* d5* m3* n4 + 
       a3* b2* d1* m5* n4 - a2* b3* d1* m5* n4 - a3* b1* d2* m5* n4 + 
       a1* b3* d2* m5* n4 + a2* b1* d3* m5* n4 - a1* b2* d3* m5* n4 + 
       a4* b3* d2* m1* n5 - a3* b4* d2* m1* n5 - a4* b2* d3* m1* n5 + 
       a2* b4* d3* m1* n5 + a3* b2* d4* m1* n5 - a2* b3* d4* m1* n5 - 
       a4* b3* d1* m2* n5 + a3* b4* d1* m2* n5 + a4* b1* d3* m2* n5 - 
       a1* b4* d3* m2* n5 - a3* b1* d4* m2* n5 + a1* b3* d4* m2* n5 + 
       a4* b2* d1* m3* n5 - a2* b4* d1* m3* n5 - a4* b1* d2* m3* n5 + 
       a1* b4* d2* m3* n5 + a2* b1* d4* m3* n5 - a1* b2* d4* m3* n5 - 
       a3* b2* d1* m4* n5 + a2* b3* d1* m4* n5 + a3* b1* d2* m4* n5 - 
       a1* b3* d2* m4* n5 - a2* b1* d3* m4* n5 + a1* b2* d3* m4* n5) + 
    b6* (a5* c4* d3* m2* n1 - a4* c5* d3* m2* n1 - a5* c3* d4* m2* n1 + 
       a3* c5* d4* m2* n1 + a4* c3* d5* m2* n1 - a3* c4* d5* m2* n1 - 
       a5* c4* d2* m3* n1 + a4* c5* d2* m3* n1 + a5* c2* d4* m3* n1 - 
       a2* c5* d4* m3* n1 - a4* c2* d5* m3* n1 + a2* c4* d5* m3* n1 + 
       a5* c3* d2* m4* n1 - a3* c5* d2* m4* n1 - a5* c2* d3* m4* n1 + 
       a2* c5* d3* m4* n1 + a3* c2* d5* m4* n1 - a2* c3* d5* m4* n1 - 
       a4* c3* d2* m5* n1 + a3* c4* d2* m5* n1 + a4* c2* d3* m5* n1 - 
       a2* c4* d3* m5* n1 - a3* c2* d4* m5* n1 + a2* c3* d4* m5* n1 - 
       a5* c4* d3* m1* n2 + a4* c5* d3* m1* n2 + a5* c3* d4* m1* n2 - 
       a3* c5* d4* m1* n2 - a4* c3* d5* m1* n2 + a3* c4* d5* m1* n2 + 
       a5* c4* d1* m3* n2 - a4* c5* d1* m3* n2 - a5* c1* d4* m3* n2 + 
       a1* c5* d4* m3* n2 + a4* c1* d5* m3* n2 - a1* c4* d5* m3* n2 - 
       a5* c3* d1* m4* n2 + a3* c5* d1* m4* n2 + a5* c1* d3* m4* n2 - 
       a1* c5* d3* m4* n2 - a3* c1* d5* m4* n2 + a1* c3* d5* m4* n2 + 
       a4* c3* d1* m5* n2 - a3* c4* d1* m5* n2 - a4* c1* d3* m5* n2 + 
       a1* c4* d3* m5* n2 + a3* c1* d4* m5* n2 - a1* c3* d4* m5* n2 + 
       a5* c4* d2* m1* n3 - a4* c5* d2* m1* n3 - a5* c2* d4* m1* n3 + 
       a2* c5* d4* m1* n3 + a4* c2* d5* m1* n3 - a2* c4* d5* m1* n3 - 
       a5* c4* d1* m2* n3 + a4* c5* d1* m2* n3 + a5* c1* d4* m2* n3 - 
       a1* c5* d4* m2* n3 - a4* c1* d5* m2* n3 + a1* c4* d5* m2* n3 + 
       a5* c2* d1* m4* n3 - a2* c5* d1* m4* n3 - a5* c1* d2* m4* n3 + 
       a1* c5* d2* m4* n3 + a2* c1* d5* m4* n3 - a1* c2* d5* m4* n3 - 
       a4* c2* d1* m5* n3 + a2* c4* d1* m5* n3 + a4* c1* d2* m5* n3 - 
       a1* c4* d2* m5* n3 - a2* c1* d4* m5* n3 + a1* c2* d4* m5* n3 - 
       a5* c3* d2* m1* n4 + a3* c5* d2* m1* n4 + a5* c2* d3* m1* n4 - 
       a2* c5* d3* m1* n4 - a3* c2* d5* m1* n4 + a2* c3* d5* m1* n4 + 
       a5* c3* d1* m2* n4 - a3* c5* d1* m2* n4 - a5* c1* d3* m2* n4 + 
       a1* c5* d3* m2* n4 + a3* c1* d5* m2* n4 - a1* c3* d5* m2* n4 - 
       a5* c2* d1* m3* n4 + a2* c5* d1* m3* n4 + a5* c1* d2* m3* n4 - 
       a1* c5* d2* m3* n4 - a2* c1* d5* m3* n4 + a1* c2* d5* m3* n4 + 
       a3* c2* d1* m5* n4 - a2* c3* d1* m5* n4 - a3* c1* d2* m5* n4 + 
       a1* c3* d2* m5* n4 + a2* c1* d3* m5* n4 - a1* c2* d3* m5* n4 + 
       a4* c3* d2* m1* n5 - a3* c4* d2* m1* n5 - a4* c2* d3* m1* n5 + 
       a2* c4* d3* m1* n5 + a3* c2* d4* m1* n5 - a2* c3* d4* m1* n5 - 
       a4* c3* d1* m2* n5 + a3* c4* d1* m2* n5 + a4* c1* d3* m2* n5 - 
       a1* c4* d3* m2* n5 - a3* c1* d4* m2* n5 + a1* c3* d4* m2* n5 + 
       a4* c2* d1* m3* n5 - a2* c4* d1* m3* n5 - a4* c1* d2* m3* n5 + 
       a1* c4* d2* m3* n5 + a2* c1* d4* m3* n5 - a1* c2* d4* m3* n5 - 
       a3* c2* d1* m4* n5 + a2* c3* d1* m4* n5 + a3* c1* d2* m4* n5 - 
       a1* c3* d2* m4* n5 - a2* c1* d3* m4* n5 + a1* c2* d3* m4* n5) - 
    a6* (b5* c4* d3* m2* n1 - b4* c5* d3* m2* n1 - b5* c3* d4* m2* n1 + 
       b3* c5* d4* m2* n1 + b4* c3* d5* m2* n1* - b3* c4* d5* m2* n1 - 
       b5* c4* d2* m3* n1 + b4* c5* d2* m3* n1* + b5* c2* d4* m3* n1 - 
       b2* c5* d4* m3* n1 - b4* c2* d5* m3* n1* + b2* c4* d5* m3* n1 + 
       b5* c3* d2* m4* n1 - b3* c5* d2* m4* n1* - b5* c2* d3* m4* n1 + 
       b2* c5* d3* m4* n1 + b3* c2* d5* m4* n1* - b2* c3* d5* m4* n1 - 
       b4* c3* d2* m5* n1 + b3* c4* d2* m5* n1* + b4* c2* d3* m5* n1 - 
       b2* c4* d3* m5* n1 - b3* c2* d4* m5* n1* + b2* c3* d4* m5* n1 - 
       b5* c4* d3* m1* n2 + b4* c5* d3* m1* n2* + b5* c3* d4* m1* n2 - 
       b3* c5* d4* m1* n2 - b4* c3* d5* m1* n2* + b3* c4* d5* m1* n2 + 
       b5* c4* d1* m3* n2 - b4* c5* d1* m3* n2* - b5* c1* d4* m3* n2 + 
       b1* c5* d4* m3* n2 + b4* c1* d5* m3* n2* - b1* c4* d5* m3* n2 - 
       b5* c3* d1* m4* n2 + b3* c5* d1* m4* n2* + b5* c1* d3* m4* n2 - 
       b1* c5* d3* m4* n2 - b3* c1* d5* m4* n2* + b1* c3* d5* m4* n2 + 
       b4* c3* d1* m5* n2 - b3* c4* d1* m5* n2* - b4* c1* d3* m5* n2 + 
       b1* c4* d3* m5* n2 + b3* c1* d4* m5* n2* - b1* c3* d4* m5* n2 + 
       b5* c4* d2* m1* n3 - b4* c5* d2* m1* n3* - b5* c2* d4* m1* n3 + 
       b2* c5* d4* m1* n3 + b4* c2* d5* m1* n3* - b2* c4* d5* m1* n3 - 
       b5* c4* d1* m2* n3 + b4* c5* d1* m2* n3* + b5* c1* d4* m2* n3 - 
       b1* c5* d4* m2* n3 - b4* c1* d5* m2* n3* + b1* c4* d5* m2* n3 + 
       b5* c2* d1* m4* n3 - b2* c5* d1* m4* n3* - b5* c1* d2* m4* n3 + 
       b1* c5* d2* m4* n3 + b2* c1* d5* m4* n3* - b1* c2* d5* m4* n3 - 
       b4* c2* d1* m5* n3 + b2* c4* d1* m5* n3* + b4* c1* d2* m5* n3 - 
       b1* c4* d2* m5* n3 - b2* c1* d4* m5* n3* + b1* c2* d4* m5* n3 - 
       b5* c3* d2* m1* n4 + b3* c5* d2* m1* n4* + b5* c2* d3* m1* n4 - 
       b2* c5* d3* m1* n4 - b3* c2* d5* m1* n4* + b2* c3* d5* m1* n4 + 
       b5* c3* d1* m2* n4 - b3* c5* d1* m2* n4* - b5* c1* d3* m2* n4 + 
       b1* c5* d3* m2* n4 + b3* c1* d5* m2* n4* - b1* c3* d5* m2* n4 - 
       b5* c2* d1* m3* n4 + b2* c5* d1* m3* n4* + b5* c1* d2* m3* n4 - 
       b1* c5* d2* m3* n4 - b2* c1* d5* m3* n4* + b1* c2* d5* m3* n4 + 
       b3* c2* d1* m5* n4 - b2* c3* d1* m5* n4* - b3* c1* d2* m5* n4 + 
       b1* c3* d2* m5* n4 + b2* c1* d3* m5* n4* - b1* c2* d3* m5* n4 + 
       b4* c3* d2* m1* n5 - b3* c4* d2* m1* n5* - b4* c2* d3* m1* n5 + 
       b2* c4* d3* m1* n5 + b3* c2* d4* m1* n5* - b2* c3* d4* m1* n5 - 
       b4* c3* d1* m2* n5 + b3* c4* d1* m2* n5* + b4* c1* d3* m2* n5 - 
       b1* c4* d3* m2* n5 - b3* c1* d4* m2* n5* + b1* c3* d4* m2* n5 + 
       b4* c2* d1* m3* n5 - b2* c4* d1* m3* n5* - b4* c1* d2* m3* n5 + 
       b1* c4* d2* m3* n5 + b2* c1* d4* m3* n5* - b1* c2* d4* m3* n5 - 
       b3* c2* d1* m4* n5 + b2* c3* d1* m4* n5* + b3* c1* d2* m4* n5 - 
       b1* c3* d2* m4* n5 - b2* c1* d3* m4* n5* +
       b1* c2* d3* m4* n5) + (a5* b4* c3* d2* m1 - a4* b5* c3* d2* m1 - 
       a5* b3* c4* d2* m1 + a3* b5* c4* d2* m1 + a4* b3* c5* d2* m1 - 
       a3* b4* c5* d2* m1 - a5* b4* c2* d3* m1 + a4* b5* c2* d3* m1 + 
       a5* b2* c4* d3* m1 - a2* b5* c4* d3* m1 - a4* b2* c5* d3* m1 + 
       a2* b4* c5* d3* m1 + a5* b3* c2* d4* m1 - a3* b5* c2* d4* m1 - 
       a5* b2* c3* d4* m1 + a2* b5* c3* d4* m1 + a3* b2* c5* d4* m1 - 
       a2* b3* c5* d4* m1 - a4* b3* c2* d5* m1 + a3* b4* c2* d5* m1 + 
       a4* b2* c3* d5* m1 - a2* b4* c3* d5* m1 - a3* b2* c4* d5* m1 + 
       a2* b3* c4* d5* m1 - a5* b4* c3* d1* m2 + a4* b5* c3* d1* m2 + 
       a5* b3* c4* d1* m2 - a3* b5* c4* d1* m2 - a4* b3* c5* d1* m2 + 
       a3* b4* c5* d1* m2 + a5* b4* c1* d3* m2 - a4* b5* c1* d3* m2 - 
       a5* b1* c4* d3* m2 + a1* b5* c4* d3* m2 + a4* b1* c5* d3* m2 - 
       a1* b4* c5* d3* m2 - a5* b3* c1* d4* m2 + a3* b5* c1* d4* m2 + 
       a5* b1* c3* d4* m2 - a1* b5* c3* d4* m2 - a3* b1* c5* d4* m2 + 
       a1* b3* c5* d4* m2 + a4* b3* c1* d5* m2 - a3* b4* c1* d5* m2 - 
       a4* b1* c3* d5* m2 + a1* b4* c3* d5* m2 + a3* b1* c4* d5* m2 - 
       a1* b3* c4* d5* m2 + a5* b4* c2* d1* m3 - a4* b5* c2* d1* m3 - 
       a5* b2* c4* d1* m3 + a2* b5* c4* d1* m3 + a4* b2* c5* d1* m3 - 
       a2* b4* c5* d1* m3 - a5* b4* c1* d2* m3 + a4* b5* c1* d2* m3 + 
       a5* b1* c4* d2* m3 - a1* b5* c4* d2* m3 - a4* b1* c5* d2* m3 + 
       a1* b4* c5* d2* m3 + a5* b2* c1* d4* m3 - a2* b5* c1* d4* m3 - 
       a5* b1* c2* d4* m3 + a1* b5* c2* d4* m3 + a2* b1* c5* d4* m3 - 
       a1* b2* c5* d4* m3 - a4* b2* c1* d5* m3 + a2* b4* c1* d5* m3 + 
       a4* b1* c2* d5* m3 - a1* b4* c2* d5* m3 - a2* b1* c4* d5* m3 + 
       a1* b2* c4* d5* m3 - a5* b3* c2* d1* m4 + a3* b5* c2* d1* m4 + 
       a5* b2* c3* d1* m4 - a2* b5* c3* d1* m4 - a3* b2* c5* d1* m4 + 
       a2* b3* c5* d1* m4 + a5* b3* c1* d2* m4 - a3* b5* c1* d2* m4 - 
       a5* b1* c3* d2* m4 + a1* b5* c3* d2* m4 + a3* b1* c5* d2* m4 - 
       a1* b3* c5* d2* m4 - a5* b2* c1* d3* m4 + a2* b5* c1* d3* m4 + 
       a5* b1* c2* d3* m4 - a1* b5* c2* d3* m4 - a2* b1* c5* d3* m4 + 
       a1* b2* c5* d3* m4 + a3* b2* c1* d5* m4 - a2* b3* c1* d5* m4 - 
       a3* b1* c2* d5* m4 + a1* b3* c2* d5* m4 + a2* b1* c3* d5* m4 - 
       a1* b2* c3* d5* m4 + a4* b3* c2* d1* m5 - a3* b4* c2* d1* m5 - 
       a4* b2* c3* d1* m5 + a2* b4* c3* d1* m5 + a3* b2* c4* d1* m5 - 
       a2* b3* c4* d1* m5 - a4* b3* c1* d2* m5 + a3* b4* c1* d2* m5 + 
       a4* b1* c3* d2* m5 - a1* b4* c3* d2* m5 - a3* b1* c4* d2* m5 + 
       a1* b3* c4* d2* m5 + a4* b2* c1* d3* m5 - a2* b4* c1* d3* m5 - 
       a4* b1* c2* d3* m5 + a1* b4* c2* d3* m5 + a2* b1* c4* d3* m5 - 
       a1* b2* c4* d3* m5 - a3* b2* c1* d4* m5 + a2* b3* c1* d4* m5 + 
       a3* b1* c2* d4* m5 - a1* b3* c2* d4* m5 - a2* b1* c3* d4* m5 + 
       a1* b2* c3* d4* m5) *n6) - 
 d7* (-m6* (a5* b4* c3* e2* n1 - a4* b5* c3* e2* n1 - a5* b3* c4* e2* n1 + 
       a3* b5* c4* e2* n1 + a4* b3* c5* e2* n1 - a3* b4* c5* e2* n1 - 
       a5* b4* c2* e3* n1 + a4* b5* c2* e3* n1 + a5* b2* c4* e3* n1 - 
       a2* b5* c4* e3* n1 - a4* b2* c5* e3* n1 + a2* b4* c5* e3* n1 + 
       a5* b3* c2* e4* n1 - a3* b5* c2* e4* n1 - a5* b2* c3* e4* n1 + 
       a2* b5* c3* e4* n1 + a3* b2* c5* e4* n1 - a2* b3* c5* e4* n1 - 
       a4* b3* c2* e5* n1 + a3* b4* c2* e5* n1 + a4* b2* c3* e5* n1 - 
       a2* b4* c3* e5* n1 - a3* b2* c4* e5* n1 + a2* b3* c4* e5* n1 - 
       a5* b4* c3* e1* n2 + a4* b5* c3* e1* n2 + a5* b3* c4* e1* n2 - 
       a3* b5* c4* e1* n2 - a4* b3* c5* e1* n2 + a3* b4* c5* e1* n2 + 
       a5* b4* c1* e3* n2 - a4* b5* c1* e3* n2 - a5* b1* c4* e3* n2 + 
       a1* b5* c4* e3* n2 + a4* b1* c5* e3* n2 - a1* b4* c5* e3* n2 - 
       a5* b3* c1* e4* n2 + a3* b5* c1* e4* n2 + a5* b1* c3* e4* n2 - 
       a1* b5* c3* e4* n2 - a3* b1* c5* e4* n2 + a1* b3* c5* e4* n2 + 
       a4* b3* c1* e5* n2 - a3* b4* c1* e5* n2 - a4* b1* c3* e5* n2 + 
       a1* b4* c3* e5* n2 + a3* b1* c4* e5* n2 - a1* b3* c4* e5* n2 + 
       a5* b4* c2* e1* n3 - a4* b5* c2* e1* n3 - a5* b2* c4* e1* n3 + 
       a2* b5* c4* e1* n3 + a4* b2* c5* e1* n3 - a2* b4* c5* e1* n3 - 
       a5* b4* c1* e2* n3 + a4* b5* c1* e2* n3 + a5* b1* c4* e2* n3 - 
       a1* b5* c4* e2* n3 - a4* b1* c5* e2* n3 + a1* b4* c5* e2* n3 + 
       a5* b2* c1* e4* n3 - a2* b5* c1* e4* n3 - a5* b1* c2* e4* n3 + 
       a1* b5* c2* e4* n3 + a2* b1* c5* e4* n3 - a1* b2* c5* e4* n3 - 
       a4* b2* c1* e5* n3 + a2* b4* c1* e5* n3 + a4* b1* c2* e5* n3 - 
       a1* b4* c2* e5* n3 - a2* b1* c4* e5* n3 + a1* b2* c4* e5* n3 - 
       a5* b3* c2* e1* n4 + a3* b5* c2* e1* n4 + a5* b2* c3* e1* n4 - 
       a2* b5* c3* e1* n4 - a3* b2* c5* e1* n4 + a2* b3* c5* e1* n4 + 
       a5* b3* c1* e2* n4 - a3* b5* c1* e2* n4 - a5* b1* c3* e2* n4 + 
       a1* b5* c3* e2* n4 + a3* b1* c5* e2* n4 - a1* b3* c5* e2* n4 - 
       a5* b2* c1* e3* n4 + a2* b5* c1* e3* n4 + a5* b1* c2* e3* n4 - 
       a1* b5* c2* e3* n4 - a2* b1* c5* e3* n4 + a1* b2* c5* e3* n4 + 
       a3* b2* c1* e5* n4 - a2* b3* c1* e5* n4 - a3* b1* c2* e5* n4 + 
       a1* b3* c2* e5* n4 + a2* b1* c3* e5* n4 - a1* b2* c3* e5* n4 + 
       a4* b3* c2* e1* n5 - a3* b4* c2* e1* n5 - a4* b2* c3* e1* n5 + 
       a2* b4* c3* e1* n5 + a3* b2* c4* e1* n5 - a2* b3* c4* e1* n5 - 
       a4* b3* c1* e2* n5 + a3* b4* c1* e2* n5 + a4* b1* c3* e2* n5 - 
       a1* b4* c3* e2* n5 - a3* b1* c4* e2* n5 + a1* b3* c4* e2* n5 + 
       a4* b2* c1* e3* n5 - a2* b4* c1* e3* n5 - a4* b1* c2* e3* n5 + 
       a1* b4* c2* e3* n5 + a2* b1* c4* e3* n5 - a1* b2* c4* e3* n5 - 
       a3* b2* c1* e4* n5 + a2* b3* c1* e4* n5 + a3* b1* c2* e4* n5 - 
       a1* b3* c2* e4* n5 - a2* b1* c3* e4* n5 + a1* b2* c3* e4* n5) + 
    e6* (a5* b4* c3* m2* n1 - a4* b5* c3* m2* n1 - a5* b3* c4* m2* n1 + 
       a3* b5* c4* m2* n1 + a4* b3* c5* m2* n1 - a3* b4* c5* m2* n1 - 
       a5* b4* c2* m3* n1 + a4* b5* c2* m3* n1 + a5* b2* c4* m3* n1 - 
       a2* b5* c4* m3* n1 - a4* b2* c5* m3* n1 + a2* b4* c5* m3* n1 + 
       a5* b3* c2* m4* n1 - a3* b5* c2* m4* n1 - a5* b2* c3* m4* n1 + 
       a2* b5* c3* m4* n1 + a3* b2* c5* m4* n1 - a2* b3* c5* m4* n1 - 
       a4* b3* c2* m5* n1 + a3* b4* c2* m5* n1 + a4* b2* c3* m5* n1 - 
       a2* b4* c3* m5* n1 - a3* b2* c4* m5* n1 + a2* b3* c4* m5* n1 - 
       a5* b4* c3* m1* n2 + a4* b5* c3* m1* n2 + a5* b3* c4* m1* n2 - 
       a3* b5* c4* m1* n2 - a4* b3* c5* m1* n2 + a3* b4* c5* m1* n2 + 
       a5* b4* c1* m3* n2 - a4* b5* c1* m3* n2 - a5* b1* c4* m3* n2 + 
       a1* b5* c4* m3* n2 + a4* b1* c5* m3* n2 - a1* b4* c5* m3* n2 - 
       a5* b3* c1* m4* n2 + a3* b5* c1* m4* n2 + a5* b1* c3* m4* n2 - 
       a1* b5* c3* m4* n2 - a3* b1* c5* m4* n2 + a1* b3* c5* m4* n2 + 
       a4* b3* c1* m5* n2 - a3* b4* c1* m5* n2 - a4* b1* c3* m5* n2 + 
       a1* b4* c3* m5* n2 + a3* b1* c4* m5* n2 - a1* b3* c4* m5* n2 + 
       a5* b4* c2* m1* n3 - a4* b5* c2* m1* n3 - a5* b2* c4* m1* n3 + 
       a2* b5* c4* m1* n3 + a4* b2* c5* m1* n3 - a2* b4* c5* m1* n3 - 
       a5* b4* c1* m2* n3 + a4* b5* c1* m2* n3 + a5* b1* c4* m2* n3 - 
       a1* b5* c4* m2* n3 - a4* b1* c5* m2* n3 + a1* b4* c5* m2* n3 + 
       a5* b2* c1* m4* n3 - a2* b5* c1* m4* n3 - a5* b1* c2* m4* n3 + 
       a1* b5* c2* m4* n3 + a2* b1* c5* m4* n3 - a1* b2* c5* m4* n3 - 
       a4* b2* c1* m5* n3 + a2* b4* c1* m5* n3 + a4* b1* c2* m5* n3 - 
       a1* b4* c2* m5* n3 - a2* b1* c4* m5* n3 + a1* b2* c4* m5* n3 - 
       a5* b3* c2* m1* n4 + a3* b5* c2* m1* n4 + a5* b2* c3* m1* n4 - 
       a2* b5* c3* m1* n4 - a3* b2* c5* m1* n4 + a2* b3* c5* m1* n4 + 
       a5* b3* c1* m2* n4 - a3* b5* c1* m2* n4 - a5* b1* c3* m2* n4 + 
       a1* b5* c3* m2* n4 + a3* b1* c5* m2* n4 - a1* b3* c5* m2* n4 - 
       a5* b2* c1* m3* n4 + a2* b5* c1* m3* n4 + a5* b1* c2* m3* n4 - 
       a1* b5* c2* m3* n4 - a2* b1* c5* m3* n4 + a1* b2* c5* m3* n4 + 
       a3* b2* c1* m5* n4 - a2* b3* c1* m5* n4 - a3* b1* c2* m5* n4 + 
       a1* b3* c2* m5* n4 + a2* b1* c3* m5* n4 - a1* b2* c3* m5* n4 + 
       a4* b3* c2* m1* n5 - a3* b4* c2* m1* n5 - a4* b2* c3* m1* n5 + 
       a2* b4* c3* m1* n5 + a3* b2* c4* m1* n5 - a2* b3* c4* m1* n5 - 
       a4* b3* c1* m2* n5 + a3* b4* c1* m2* n5 + a4* b1* c3* m2* n5 - 
       a1* b4* c3* m2* n5 - a3* b1* c4* m2* n5 + a1* b3* c4* m2* n5 + 
       a4* b2* c1* m3* n5 - a2* b4* c1* m3* n5 - a4* b1* c2* m3* n5 + 
       a1* b4* c2* m3* n5 + a2* b1* c4* m3* n5 - a1* b2* c4* m3* n5 - 
       a3* b2* c1* m4* n5 + a2* b3* c1* m4* n5 + a3* b1* c2* m4* n5 - 
       a1* b3* c2* m4* n5 - a2* b1* c3* m4* n5 + a1* b2* c3* m4* n5) - 
    c6* (a5* b4* e3* m2* n1 - a4* b5* e3* m2* n1 - a5* b3* e4* m2* n1 + 
       a3* b5* e4* m2* n1 + a4* b3* e5* m2* n1 - a3* b4* e5* m2* n1 - 
       a5* b4* e2* m3* n1 + a4* b5* e2* m3* n1 + a5* b2* e4* m3* n1 - 
       a2* b5* e4* m3* n1 - a4* b2* e5* m3* n1 + a2* b4* e5* m3* n1 + 
       a5* b3* e2* m4* n1 - a3* b5* e2* m4* n1 - a5* b2* e3* m4* n1 + 
       a2* b5* e3* m4* n1 + a3* b2* e5* m4* n1 - a2* b3* e5* m4* n1 - 
       a4* b3* e2* m5* n1 + a3* b4* e2* m5* n1 + a4* b2* e3* m5* n1 - 
       a2* b4* e3* m5* n1 - a3* b2* e4* m5* n1 + a2* b3* e4* m5* n1 - 
       a5* b4* e3* m1* n2 + a4* b5* e3* m1* n2 + a5* b3* e4* m1* n2 - 
       a3* b5* e4* m1* n2 - a4* b3* e5* m1* n2 + a3* b4* e5* m1* n2 + 
       a5* b4* e1* m3* n2 - a4* b5* e1* m3* n2 - a5* b1* e4* m3* n2 + 
       a1* b5* e4* m3* n2 + a4* b1* e5* m3* n2 - a1* b4* e5* m3* n2 - 
       a5* b3* e1* m4* n2 + a3* b5* e1* m4* n2 + a5* b1* e3* m4* n2 - 
       a1* b5* e3* m4* n2 - a3* b1* e5* m4* n2 + a1* b3* e5* m4* n2 + 
       a4* b3* e1* m5* n2 - a3* b4* e1* m5* n2 - a4* b1* e3* m5* n2 + 
       a1* b4* e3* m5* n2 + a3* b1* e4* m5* n2 - a1* b3* e4* m5* n2 + 
       a5* b4* e2* m1* n3 - a4* b5* e2* m1* n3 - a5* b2* e4* m1* n3 + 
       a2* b5* e4* m1* n3 + a4* b2* e5* m1* n3 - a2* b4* e5* m1* n3 - 
       a5* b4* e1* m2* n3 + a4* b5* e1* m2* n3 + a5* b1* e4* m2* n3 - 
       a1* b5* e4* m2* n3 - a4* b1* e5* m2* n3 + a1* b4* e5* m2* n3 + 
       a5* b2* e1* m4* n3 - a2* b5* e1* m4* n3 - a5* b1* e2* m4* n3 + 
       a1* b5* e2* m4* n3 + a2* b1* e5* m4* n3 - a1* b2* e5* m4* n3 - 
       a4* b2* e1* m5* n3 + a2* b4* e1* m5* n3 + a4* b1* e2* m5* n3 - 
       a1* b4* e2* m5* n3 - a2* b1* e4* m5* n3 + a1* b2* e4* m5* n3 - 
       a5* b3* e2* m1* n4 + a3* b5* e2* m1* n4 + a5* b2* e3* m1* n4 - 
       a2* b5* e3* m1* n4 - a3* b2* e5* m1* n4 + a2* b3* e5* m1* n4 + 
       a5* b3* e1* m2* n4 - a3* b5* e1* m2* n4 - a5* b1* e3* m2* n4 + 
       a1* b5* e3* m2* n4 + a3* b1* e5* m2* n4 - a1* b3* e5* m2* n4 - 
       a5* b2* e1* m3* n4 + a2* b5* e1* m3* n4 + a5* b1* e2* m3* n4 - 
       a1* b5* e2* m3* n4 - a2* b1* e5* m3* n4 + a1* b2* e5* m3* n4 + 
       a3* b2* e1* m5* n4 - a2* b3* e1* m5* n4 - a3* b1* e2* m5* n4 + 
       a1* b3* e2* m5* n4 + a2* b1* e3* m5* n4 - a1* b2* e3* m5* n4 + 
       a4* b3* e2* m1* n5 - a3* b4* e2* m1* n5 - a4* b2* e3* m1* n5 + 
       a2* b4* e3* m1* n5 + a3* b2* e4* m1* n5 - a2* b3* e4* m1* n5 - 
       a4* b3* e1* m2* n5 + a3* b4* e1* m2* n5 + a4* b1* e3* m2* n5 - 
       a1* b4* e3* m2* n5 - a3* b1* e4* m2* n5 + a1* b3* e4* m2* n5 + 
       a4* b2* e1* m3* n5 - a2* b4* e1* m3* n5 - a4* b1* e2* m3* n5 + 
       a1* b4* e2* m3* n5 + a2* b1* e4* m3* n5 - a1* b2* e4* m3* n5 - 
       a3* b2* e1* m4* n5 + a2* b3* e1* m4* n5 + a3* b1* e2* m4* n5 - 
       a1* b3* e2* m4* n5 - a2* b1* e3* m4* n5 + a1* b2* e3* m4* n5) + 
    b6* (a5* c4* e3* m2* n1 - a4* c5* e3* m2* n1 - a5* c3* e4* m2* n1 + 
       a3* c5* e4* m2* n1 + a4* c3* e5* m2* n1 - a3* c4* e5* m2* n1 - 
       a5* c4* e2* m3* n1 + a4* c5* e2* m3* n1 + a5* c2* e4* m3* n1 - 
       a2* c5* e4* m3* n1 - a4* c2* e5* m3* n1 + a2* c4* e5* m3* n1 + 
       a5* c3* e2* m4* n1 - a3* c5* e2* m4* n1 - a5* c2* e3* m4* n1 + 
       a2* c5* e3* m4* n1 + a3* c2* e5* m4* n1 - a2* c3* e5* m4* n1 - 
       a4* c3* e2* m5* n1 + a3* c4* e2* m5* n1 + a4* c2* e3* m5* n1 - 
       a2* c4* e3* m5* n1 - a3* c2* e4* m5* n1 + a2* c3* e4* m5* n1 - 
       a5* c4* e3* m1* n2 + a4* c5* e3* m1* n2 + a5* c3* e4* m1* n2 - 
       a3* c5* e4* m1* n2 - a4* c3* e5* m1* n2 + a3* c4* e5* m1* n2 + 
       a5* c4* e1* m3* n2 - a4* c5* e1* m3* n2 - a5* c1* e4* m3* n2 + 
       a1* c5* e4* m3* n2 + a4* c1* e5* m3* n2 - a1* c4* e5* m3* n2 - 
       a5* c3* e1* m4* n2 + a3* c5* e1* m4* n2 + a5* c1* e3* m4* n2 - 
       a1* c5* e3* m4* n2 - a3* c1* e5* m4* n2 + a1* c3* e5* m4* n2 + 
       a4* c3* e1* m5* n2 - a3* c4* e1* m5* n2 - a4* c1* e3* m5* n2 + 
       a1* c4* e3* m5* n2 + a3* c1* e4* m5* n2 - a1* c3* e4* m5* n2 + 
       a5* c4* e2* m1* n3 - a4* c5* e2* m1* n3 - a5* c2* e4* m1* n3 + 
       a2* c5* e4* m1* n3 + a4* c2* e5* m1* n3 - a2* c4* e5* m1* n3 - 
       a5* c4* e1* m2* n3 + a4* c5* e1* m2* n3 + a5* c1* e4* m2* n3 - 
       a1* c5* e4* m2* n3 - a4* c1* e5* m2* n3 + a1* c4* e5* m2* n3 + 
       a5* c2* e1* m4* n3 - a2* c5* e1* m4* n3 - a5* c1* e2* m4* n3 + 
       a1* c5* e2* m4* n3 + a2* c1* e5* m4* n3 - a1* c2* e5* m4* n3 - 
       a4* c2* e1* m5* n3 + a2* c4* e1* m5* n3 + a4* c1* e2* m5* n3 - 
       a1* c4* e2* m5* n3 - a2* c1* e4* m5* n3 + a1* c2* e4* m5* n3 - 
       a5* c3* e2* m1* n4 + a3* c5* e2* m1* n4 + a5* c2* e3* m1* n4 - 
       a2* c5* e3* m1* n4 - a3* c2* e5* m1* n4 + a2* c3* e5* m1* n4 + 
       a5* c3* e1* m2* n4 - a3* c5* e1* m2* n4 - a5* c1* e3* m2* n4 + 
       a1* c5* e3* m2* n4 + a3* c1* e5* m2* n4 - a1* c3* e5* m2* n4 - 
       a5* c2* e1* m3* n4 + a2* c5* e1* m3* n4 + a5* c1* e2* m3* n4 - 
       a1* c5* e2* m3* n4 - a2* c1* e5* m3* n4 + a1* c2* e5* m3* n4 + 
       a3* c2* e1* m5* n4 - a2* c3* e1* m5* n4 - a3* c1* e2* m5* n4 + 
       a1* c3* e2* m5* n4 + a2* c1* e3* m5* n4 - a1* c2* e3* m5* n4 + 
       a4* c3* e2* m1* n5 - a3* c4* e2* m1* n5 - a4* c2* e3* m1* n5 + 
       a2* c4* e3* m1* n5 + a3* c2* e4* m1* n5 - a2* c3* e4* m1* n5 - 
       a4* c3* e1* m2* n5 + a3* c4* e1* m2* n5 + a4* c1* e3* m2* n5 - 
       a1* c4* e3* m2* n5 - a3* c1* e4* m2* n5 + a1* c3* e4* m2* n5 + 
       a4* c2* e1* m3* n5 - a2* c4* e1* m3* n5 - a4* c1* e2* m3* n5 + 
       a1* c4* e2* m3* n5 + a2* c1* e4* m3* n5 - a1* c2* e4* m3* n5 - 
       a3* c2* e1* m4* n5 + a2* c3* e1* m4* n5 + a3* c1* e2* m4* n5 - 
       a1* c3* e2* m4* n5 - a2* c1* e3* m4* n5 + a1* c2* e3* m4* n5) - 
    a6* (b5* c4* e3* m2* n1 - b4* c5* e3* m2* n1 - b5* c3* e4* m2* n1 + 
       b3* c5* e4* m2* n1 + b4* c3* e5* m2* n1 - b3* c4* e5* m2* n1 - 
       b5* c4* e2* m3* n1 + b4* c5* e2* m3* n1 + b5* c2* e4* m3* n1 - 
       b2* c5* e4* m3* n1 - b4* c2* e5* m3* n1 + b2* c4* e5* m3* n1 + 
       b5* c3* e2* m4* n1 - b3* c5* e2* m4* n1 - b5* c2* e3* m4* n1 + 
       b2* c5* e3* m4* n1 + b3* c2* e5* m4* n1 - b2* c3* e5* m4* n1 - 
       b4* c3* e2* m5* n1 + b3* c4* e2* m5* n1 + b4* c2* e3* m5* n1 - 
       b2* c4* e3* m5* n1 - b3* c2* e4* m5* n1 + b2* c3* e4* m5* n1 - 
       b5* c4* e3* m1* n2 + b4* c5* e3* m1* n2 + b5* c3* e4* m1* n2 - 
       b3* c5* e4* m1* n2 - b4* c3* e5* m1* n2 + b3* c4* e5* m1* n2 + 
       b5* c4* e1* m3* n2 - b4* c5* e1* m3* n2 - b5* c1* e4* m3* n2 + 
       b1* c5* e4* m3* n2 + b4* c1* e5* m3* n2 - b1* c4* e5* m3* n2 - 
       b5* c3* e1* m4* n2 + b3* c5* e1* m4* n2 + b5* c1* e3* m4* n2 - 
       b1* c5* e3* m4* n2 - b3* c1* e5* m4* n2 + b1* c3* e5* m4* n2 + 
       b4* c3* e1* m5* n2 - b3* c4* e1* m5* n2 - b4* c1* e3* m5* n2 + 
       b1* c4* e3* m5* n2 + b3* c1* e4* m5* n2 - b1* c3* e4* m5* n2 + 
       b5* c4* e2* m1* n3 - b4* c5* e2* m1* n3 - b5* c2* e4* m1* n3 + 
       b2* c5* e4* m1* n3 + b4* c2* e5* m1* n3 - b2* c4* e5* m1* n3 - 
       b5* c4* e1* m2* n3 + b4* c5* e1* m2* n3 + b5* c1* e4* m2* n3 - 
       b1* c5* e4* m2* n3 - b4* c1* e5* m2* n3 + b1* c4* e5* m2* n3 + 
       b5* c2* e1* m4* n3 - b2* c5* e1* m4* n3 - b5* c1* e2* m4* n3 + 
       b1* c5* e2* m4* n3 + b2* c1* e5* m4* n3 - b1* c2* e5* m4* n3 - 
       b4* c2* e1* m5* n3 + b2* c4* e1* m5* n3 + b4* c1* e2* m5* n3 - 
       b1* c4* e2* m5* n3 - b2* c1* e4* m5* n3 + b1* c2* e4* m5* n3 - 
       b5* c3* e2* m1* n4 + b3* c5* e2* m1* n4 + b5* c2* e3* m1* n4 - 
       b2* c5* e3* m1* n4 - b3* c2* e5* m1* n4 + b2* c3* e5* m1* n4 + 
       b5* c3* e1* m2* n4 - b3* c5* e1* m2* n4 - b5* c1* e3* m2* n4 + 
       b1* c5* e3* m2* n4 + b3* c1* e5* m2* n4 - b1* c3* e5* m2* n4 - 
       b5* c2* e1* m3* n4 + b2* c5* e1* m3* n4 + b5* c1* e2* m3* n4 - 
       b1* c5* e2* m3* n4 - b2* c1* e5* m3* n4 + b1* c2* e5* m3* n4 + 
       b3* c2* e1* m5* n4 - b2* c3* e1* m5* n4 - b3* c1* e2* m5* n4 + 
       b1* c3* e2* m5* n4 + b2* c1* e3* m5* n4 - b1* c2* e3* m5* n4 + 
       b4* c3* e2* m1* n5 - b3* c4* e2* m1* n5 - b4* c2* e3* m1* n5 + 
       b2* c4* e3* m1* n5 + b3* c2* e4* m1* n5 - b2* c3* e4* m1* n5 - 
       b4* c3* e1* m2* n5 + b3* c4* e1* m2* n5 + b4* c1* e3* m2* n5 - 
       b1* c4* e3* m2* n5 - b3* c1* e4* m2* n5 + b1* c3* e4* m2* n5 + 
       b4* c2* e1* m3* n5 - b2* c4* e1* m3* n5 - b4* c1* e2* m3* n5 + 
       b1* c4* e2* m3* n5 + b2* c1* e4* m3* n5 - b1* c2* e4* m3* n5 - 
       b3* c2* e1* m4* n5 + b2* c3* e1* m4* n5 + b3* c1* e2* m4* n5 - 
       b1* c3* e2* m4* n5 - b2* c1* e3* m4* n5 + 
       b1* c2* e3* m4* n5) + (a5* b4* c3* e2* m1 - a4* b5* c3* e2* m1 - 
       a5* b3* c4* e2* m1 + a3* b5* c4* e2* m1 + a4* b3* c5* e2* m1 - 
       a3* b4* c5* e2* m1 - a5* b4* c2* e3* m1 + a4* b5* c2* e3* m1 + 
       a5* b2* c4* e3* m1 - a2* b5* c4* e3* m1 - a4* b2* c5* e3* m1 + 
       a2* b4* c5* e3* m1 + a5* b3* c2* e4* m1 - a3* b5* c2* e4* m1 - 
       a5* b2* c3* e4* m1 + a2* b5* c3* e4* m1 + a3* b2* c5* e4* m1 - 

       a2* b3* c5* e4* m1 - a4* b3* c2* e5* m1 + a3* b4* c2* e5* m1 + 
       a4* b2* c3* e5* m1 - a2* b4* c3* e5* m1 - a3* b2* c4* e5* m1 + 
       a2* b3* c4* e5* m1 - a5* b4* c3* e1* m2 + a4* b5* c3* e1* m2 + 
       a5* b3* c4* e1* m2 - a3* b5* c4* e1* m2 - a4* b3* c5* e1* m2 + 
       a3* b4* c5* e1* m2 + a5* b4* c1* e3* m2 - a4* b5* c1* e3* m2 - 
       a5* b1* c4* e3* m2 + a1* b5* c4* e3* m2 + a4* b1* c5* e3* m2 - 
       a1* b4* c5* e3* m2 - a5* b3* c1* e4* m2 + a3* b5* c1* e4* m2 + 
       a5* b1* c3* e4* m2 - a1* b5* c3* e4* m2 - a3* b1* c5* e4* m2 + 
       a1* b3* c5* e4* m2 + a4* b3* c1* e5* m2 - a3* b4* c1* e5* m2 - 
       a4* b1* c3* e5* m2 + a1* b4* c3* e5* m2 + a3* b1* c4* e5* m2 - 
       a1* b3* c4* e5* m2 + a5* b4* c2* e1* m3 - a4* b5* c2* e1* m3 - 
       a5* b2* c4* e1* m3 + a2* b5* c4* e1* m3 + a4* b2* c5* e1* m3 - 
       a2* b4* c5* e1* m3 - a5* b4* c1* e2* m3 + a4* b5* c1* e2* m3 + 
       a5* b1* c4* e2* m3 - a1* b5* c4* e2* m3 - a4* b1* c5* e2* m3 + 
       a1* b4* c5* e2* m3 + a5* b2* c1* e4* m3 - a2* b5* c1* e4* m3 - 
       a5* b1* c2* e4* m3 + a1* b5* c2* e4* m3 + a2* b1* c5* e4* m3 - 
       a1* b2* c5* e4* m3 - a4* b2* c1* e5* m3 + a2* b4* c1* e5* m3 + 
       a4* b1* c2* e5* m3 - a1* b4* c2* e5* m3 - a2* b1* c4* e5* m3 + 
       a1* b2* c4* e5* m3 - a5* b3* c2* e1* m4 + a3* b5* c2* e1* m4 + 
       a5* b2* c3* e1* m4 - a2* b5* c3* e1* m4 - a3* b2* c5* e1* m4 + 
       a2* b3* c5* e1* m4 + a5* b3* c1* e2* m4 - a3* b5* c1* e2* m4 - 
       a5* b1* c3* e2* m4 + a1* b5* c3* e2* m4 + a3* b1* c5* e2* m4 - 
       a1* b3* c5* e2* m4 - a5* b2* c1* e3* m4 + a2* b5* c1* e3* m4 + 
       a5* b1* c2* e3* m4 - a1* b5* c2* e3* m4 - a2* b1* c5* e3* m4 + 
       a1* b2* c5* e3* m4 + a3* b2* c1* e5* m4 - a2* b3* c1* e5* m4 - 
       a3* b1* c2* e5* m4 + a1* b3* c2* e5* m4 + a2* b1* c3* e5* m4 - 
       a1* b2* c3* e5* m4 + a4* b3* c2* e1* m5 - a3* b4* c2* e1* m5 - 
       a4* b2* c3* e1* m5 + a2* b4* c3* e1* m5 + a3* b2* c4* e1* m5 - 
       a2* b3* c4* e1* m5 - a4* b3* c1* e2* m5 + a3* b4* c1* e2* m5 + 
       a4* b1* c3* e2* m5 - a1* b4* c3* e2* m5 - a3* b1* c4* e2* m5 + 
       a1* b3* c4* e2* m5 + a4* b2* c1* e3* m5 - a2* b4* c1* e3* m5 - 
       a4* b1* c2* e3* m5 + a1* b4* c2* e3* m5 + a2* b1* c4* e3* m5 - 
       a1* b2* c4* e3* m5 - a3* b2* c1* e4* m5 + a2* b3* c1* e4* m5 + 
       a3* b1* c2* e4* m5 - a1* b3* c2* e4* m5 - a2* b1* c3* e4* m5 + 
       a1* b2* c3* e4* m5) *n6) + 
 c7* (-m6* (a5* b4* d3* e2* n1 - a4* b5* d3* e2* n1 - a5* b3* d4* e2* n1 + 
       a3* b5* d4* e2* n1 + a4* b3* d5* e2* n1 - a3* b4* d5* e2* n1 - 
       a5* b4* d2* e3* n1 + a4* b5* d2* e3* n1 + a5* b2* d4* e3* n1 - 
       a2* b5* d4* e3* n1 - a4* b2* d5* e3* n1 + a2* b4* d5* e3* n1 + 
       a5* b3* d2* e4* n1 - a3* b5* d2* e4* n1 - a5* b2* d3* e4* n1 + 
       a2* b5* d3* e4* n1 + a3* b2* d5* e4* n1 - a2* b3* d5* e4* n1 - 
       a4* b3* d2* e5* n1 + a3* b4* d2* e5* n1 + a4* b2* d3* e5* n1 - 
       a2* b4* d3* e5* n1 - a3* b2* d4* e5* n1 + a2* b3* d4* e5* n1 - 
       a5* b4* d3* e1* n2 + a4* b5* d3* e1* n2 + a5* b3* d4* e1* n2 - 
       a3* b5* d4* e1* n2 - a4* b3* d5* e1* n2 + a3* b4* d5* e1* n2 + 
       a5* b4* d1* e3* n2 - a4* b5* d1* e3* n2 - a5* b1* d4* e3* n2 + 
       a1* b5* d4* e3* n2 + a4* b1* d5* e3* n2 - a1* b4* d5* e3* n2 - 
       a5* b3* d1* e4* n2 + a3* b5* d1* e4* n2 + a5* b1* d3* e4* n2 - 
       a1* b5* d3* e4* n2 - a3* b1* d5* e4* n2 + a1* b3* d5* e4* n2 + 
       a4* b3* d1* e5* n2 - a3* b4* d1* e5* n2 - a4* b1* d3* e5* n2 + 
       a1* b4* d3* e5* n2 + a3* b1* d4* e5* n2 - a1* b3* d4* e5* n2 + 
       a5* b4* d2* e1* n3 - a4* b5* d2* e1* n3 - a5* b2* d4* e1* n3 + 
       a2* b5* d4* e1* n3 + a4* b2* d5* e1* n3 - a2* b4* d5* e1* n3 - 
       a5* b4* d1* e2* n3 + a4* b5* d1* e2* n3 + a5* b1* d4* e2* n3 - 
       a1* b5* d4* e2* n3 - a4* b1* d5* e2* n3 + a1* b4* d5* e2* n3 + 
       a5* b2* d1* e4* n3 - a2* b5* d1* e4* n3 - a5* b1* d2* e4* n3 + 
       a1* b5* d2* e4* n3 + a2* b1* d5* e4* n3 - a1* b2* d5* e4* n3 - 
       a4* b2* d1* e5* n3 + a2* b4* d1* e5* n3 + a4* b1* d2* e5* n3 - 
       a1* b4* d2* e5* n3 - a2* b1* d4* e5* n3 + a1* b2* d4* e5* n3 - 
       a5* b3* d2* e1* n4 + a3* b5* d2* e1* n4 + a5* b2* d3* e1* n4 - 
       a2* b5* d3* e1* n4 - a3* b2* d5* e1* n4 + a2* b3* d5* e1* n4 + 
       a5* b3* d1* e2* n4 - a3* b5* d1* e2* n4 - a5* b1* d3* e2* n4 + 
       a1* b5* d3* e2* n4 + a3* b1* d5* e2* n4 - a1* b3* d5* e2* n4 - 
       a5* b2* d1* e3* n4 + a2* b5* d1* e3* n4 + a5* b1* d2* e3* n4 - 
       a1* b5* d2* e3* n4 - a2* b1* d5* e3* n4 + a1* b2* d5* e3* n4 + 
       a3* b2* d1* e5* n4 - a2* b3* d1* e5* n4 - a3* b1* d2* e5* n4 + 
       a1* b3* d2* e5* n4 + a2* b1* d3* e5* n4 - a1* b2* d3* e5* n4 + 
       a4* b3* d2* e1* n5 - a3* b4* d2* e1* n5 - a4* b2* d3* e1* n5 + 
       a2* b4* d3* e1* n5 + a3* b2* d4* e1* n5 - a2* b3* d4* e1* n5 - 
       a4* b3* d1* e2* n5 + a3* b4* d1* e2* n5 + a4* b1* d3* e2* n5 - 
       a1* b4* d3* e2* n5 - a3* b1* d4* e2* n5 + a1* b3* d4* e2* n5 + 
       a4* b2* d1* e3* n5 - a2* b4* d1* e3* n5 - a4* b1* d2* e3* n5 + 
       a1* b4* d2* e3* n5 + a2* b1* d4* e3* n5 - a1* b2* d4* e3* n5 - 
       a3* b2* d1* e4* n5 + a2* b3* d1* e4* n5 + a3* b1* d2* e4* n5 - 
       a1* b3* d2* e4* n5 - a2* b1* d3* e4* n5 + a1* b2* d3* e4* n5) + 
    e6* (a5* b4* d3* m2* n1 - a4* b5* d3* m2* n1 - a5* b3* d4* m2* n1 + 
       a3* b5* d4* m2* n1 + a4* b3* d5* m2* n1 - a3* b4* d5* m2* n1 - 
       a5* b4* d2* m3* n1 + a4* b5* d2* m3* n1 + a5* b2* d4* m3* n1 - 
       a2* b5* d4* m3* n1 - a4* b2* d5* m3* n1 + a2* b4* d5* m3* n1 + 
       a5* b3* d2* m4* n1 - a3* b5* d2* m4* n1 - a5* b2* d3* m4* n1 + 
       a2* b5* d3* m4* n1 + a3* b2* d5* m4* n1 - a2* b3* d5* m4* n1 - 
       a4* b3* d2* m5* n1 + a3* b4* d2* m5* n1 + a4* b2* d3* m5* n1 - 
       a2* b4* d3* m5* n1 - a3* b2* d4* m5* n1 + a2* b3* d4* m5* n1 - 
       a5* b4* d3* m1* n2 + a4* b5* d3* m1* n2 + a5* b3* d4* m1* n2 - 
       a3* b5* d4* m1* n2 - a4* b3* d5* m1* n2 + a3* b4* d5* m1* n2 + 
       a5* b4* d1* m3* n2 - a4* b5* d1* m3* n2 - a5* b1* d4* m3* n2 + 
       a1* b5* d4* m3* n2 + a4* b1* d5* m3* n2 - a1* b4* d5* m3* n2 - 
       a5* b3* d1* m4* n2 + a3* b5* d1* m4* n2 + a5* b1* d3* m4* n2 - 
       a1* b5* d3* m4* n2 - a3* b1* d5* m4* n2 + a1* b3* d5* m4* n2 + 
       a4* b3* d1* m5* n2 - a3* b4* d1* m5* n2 - a4* b1* d3* m5* n2 + 
       a1* b4* d3* m5* n2 + a3* b1* d4* m5* n2 - a1* b3* d4* m5* n2 + 
       a5* b4* d2* m1* n3 - a4* b5* d2* m1* n3 - a5* b2* d4* m1* n3 + 
       a2* b5* d4* m1* n3 + a4* b2* d5* m1* n3 - a2* b4* d5* m1* n3 - 
       a5* b4* d1* m2* n3 + a4* b5* d1* m2* n3 + a5* b1* d4* m2* n3 - 
       a1* b5* d4* m2* n3 - a4* b1* d5* m2* n3 + a1* b4* d5* m2* n3 + 
       a5* b2* d1* m4* n3 - a2* b5* d1* m4* n3 - a5* b1* d2* m4* n3 + 
       a1* b5* d2* m4* n3 + a2* b1* d5* m4* n3 - a1* b2* d5* m4* n3 - 
       a4* b2* d1* m5* n3 + a2* b4* d1* m5* n3 + a4* b1* d2* m5* n3 - 
       a1* b4* d2* m5* n3 - a2* b1* d4* m5* n3 + a1* b2* d4* m5* n3 - 
       a5* b3* d2* m1* n4 + a3* b5* d2* m1* n4 + a5* b2* d3* m1* n4 - 
       a2* b5* d3* m1* n4 - a3* b2* d5* m1* n4 + a2* b3* d5* m1* n4 + 
       a5* b3* d1* m2* n4 - a3* b5* d1* m2* n4 - a5* b1* d3* m2* n4 + 
       a1* b5* d3* m2* n4 + a3* b1* d5* m2* n4 - a1* b3* d5* m2* n4 - 
       a5* b2* d1* m3* n4 + a2* b5* d1* m3* n4 + a5* b1* d2* m3* n4 - 
       a1* b5* d2* m3* n4 - a2* b1* d5* m3* n4 + a1* b2* d5* m3* n4 + 
       a3* b2* d1* m5* n4 - a2* b3* d1* m5* n4 - a3* b1* d2* m5* n4 + 
       a1* b3* d2* m5* n4 + a2* b1* d3* m5* n4 - a1* b2* d3* m5* n4 + 
       a4* b3* d2* m1* n5 - a3* b4* d2* m1* n5 - a4* b2* d3* m1* n5 + 
       a2* b4* d3* m1* n5 + a3* b2* d4* m1* n5 - a2* b3* d4* m1* n5 - 
       a4* b3* d1* m2* n5 + a3* b4* d1* m2* n5 + a4* b1* d3* m2* n5 - 
       a1* b4* d3* m2* n5 - a3* b1* d4* m2* n5 + a1* b3* d4* m2* n5 + 
       a4* b2* d1* m3* n5 - a2* b4* d1* m3* n5 - a4* b1* d2* m3* n5 + 
       a1* b4* d2* m3* n5 + a2* b1* d4* m3* n5 - a1* b2* d4* m3* n5 - 
       a3* b2* d1* m4* n5 + a2* b3* d1* m4* n5 + a3* b1* d2* m4* n5 - 
       a1* b3* d2* m4* n5 - a2* b1* d3* m4* n5 + a1* b2* d3* m4* n5) - 
    d6* (a5* b4* e3* m2* n1 - a4* b5* e3* m2* n1 - a5* b3* e4* m2* n1 + 
       a3* b5* e4* m2* n1 + a4* b3* e5* m2* n1 - a3* b4* e5* m2* n1 - 
       a5* b4* e2* m3* n1 + a4* b5* e2* m3* n1 + a5* b2* e4* m3* n1 - 
       a2* b5* e4* m3* n1 - a4* b2* e5* m3* n1 + a2* b4* e5* m3* n1 + 
       a5* b3* e2* m4* n1 - a3* b5* e2* m4* n1 - a5* b2* e3* m4* n1 + 
       a2* b5* e3* m4* n1 + a3* b2* e5* m4* n1 - a2* b3* e5* m4* n1 - 
       a4* b3* e2* m5* n1 + a3* b4* e2* m5* n1 + a4* b2* e3* m5* n1 - 
       a2* b4* e3* m5* n1 - a3* b2* e4* m5* n1 + a2* b3* e4* m5* n1 - 
       a5* b4* e3* m1* n2 + a4* b5* e3* m1* n2 + a5* b3* e4* m1* n2 - 
       a3* b5* e4* m1* n2 - a4* b3* e5* m1* n2 + a3* b4* e5* m1* n2 + 
       a5* b4* e1* m3* n2 - a4* b5* e1* m3* n2 - a5* b1* e4* m3* n2 + 
       a1* b5* e4* m3* n2 + a4* b1* e5* m3* n2 - a1* b4* e5* m3* n2 - 
       a5* b3* e1* m4* n2 + a3* b5* e1* m4* n2 + a5* b1* e3* m4* n2 - 
       a1* b5* e3* m4* n2 - a3* b1* e5* m4* n2 + a1* b3* e5* m4* n2 + 
       a4* b3* e1* m5* n2 - a3* b4* e1* m5* n2 - a4* b1* e3* m5* n2 + 
       a1* b4* e3* m5* n2 + a3* b1* e4* m5* n2 - a1* b3* e4* m5* n2 + 
       a5* b4* e2* m1* n3 - a4* b5* e2* m1* n3 - a5* b2* e4* m1* n3 + 
       a2* b5* e4* m1* n3 + a4* b2* e5* m1* n3 - a2* b4* e5* m1* n3 - 
       a5* b4* e1* m2* n3 + a4* b5* e1* m2* n3 + a5* b1* e4* m2* n3 - 
       a1* b5* e4* m2* n3 - a4* b1* e5* m2* n3 + a1* b4* e5* m2* n3 + 
       a5* b2* e1* m4* n3 - a2* b5* e1* m4* n3 - a5* b1* e2* m4* n3 + 
       a1* b5* e2* m4* n3 + a2* b1* e5* m4* n3 - a1* b2* e5* m4* n3 - 
       a4* b2* e1* m5* n3 + a2* b4* e1* m5* n3 + a4* b1* e2* m5* n3 - 
       a1* b4* e2* m5* n3 - a2* b1* e4* m5* n3 + a1* b2* e4* m5* n3 - 
       a5* b3* e2* m1* n4 + a3* b5* e2* m1* n4 + a5* b2* e3* m1* n4 - 
       a2* b5* e3* m1* n4 - a3* b2* e5* m1* n4 + a2* b3* e5* m1* n4 + 
       a5* b3* e1* m2* n4 - a3* b5* e1* m2* n4 - a5* b1* e3* m2* n4 + 
       a1* b5* e3* m2* n4 + a3* b1* e5* m2* n4 - a1* b3* e5* m2* n4 - 
       a5* b2* e1* m3* n4 + a2* b5* e1* m3* n4 + a5* b1* e2* m3* n4 - 
       a1* b5* e2* m3* n4 - a2* b1* e5* m3* n4 + a1* b2* e5* m3* n4 + 
       a3* b2* e1* m5* n4 - a2* b3* e1* m5* n4 - a3* b1* e2* m5* n4 + 
       a1* b3* e2* m5* n4 + a2* b1* e3* m5* n4 - a1* b2* e3* m5* n4 + 
       a4* b3* e2* m1* n5 - a3* b4* e2* m1* n5 - a4* b2* e3* m1* n5 + 
       a2* b4* e3* m1* n5 + a3* b2* e4* m1* n5 - a2* b3* e4* m1* n5 - 
       a4* b3* e1* m2* n5 + a3* b4* e1* m2* n5 + a4* b1* e3* m2* n5 - 
       a1* b4* e3* m2* n5 - a3* b1* e4* m2* n5 + a1* b3* e4* m2* n5 + 
       a4* b2* e1* m3* n5 - a2* b4* e1* m3* n5 - a4* b1* e2* m3* n5 + 
       a1* b4* e2* m3* n5 + a2* b1* e4* m3* n5 - a1* b2* e4* m3* n5 - 
       a3* b2* e1* m4* n5 + a2* b3* e1* m4* n5 + a3* b1* e2* m4* n5 - 
       a1* b3* e2* m4* n5 - a2* b1* e3* m4* n5 + a1* b2* e3* m4* n5) + 
    b6* (a5* d4* e3* m2* n1 - a4* d5* e3* m2* n1 - a5* d3* e4* m2* n1 + 
       a3* d5* e4* m2* n1 + a4* d3* e5* m2* n1 - a3* d4* e5* m2* n1 - 
       a5* d4* e2* m3* n1 + a4* d5* e2* m3* n1 + a5* d2* e4* m3* n1 - 
       a2* d5* e4* m3* n1 - a4* d2* e5* m3* n1 + a2* d4* e5* m3* n1 + 
       a5* d3* e2* m4* n1 - a3* d5* e2* m4* n1 - a5* d2* e3* m4* n1 + 
       a2* d5* e3* m4* n1 + a3* d2* e5* m4* n1 - a2* d3* e5* m4* n1 - 
       a4* d3* e2* m5* n1 + a3* d4* e2* m5* n1 + a4* d2* e3* m5* n1 - 
       a2* d4* e3* m5* n1 - a3* d2* e4* m5* n1 + a2* d3* e4* m5* n1 - 
       a5* d4* e3* m1* n2 + a4* d5* e3* m1* n2 + a5* d3* e4* m1* n2 - 
       a3* d5* e4* m1* n2 - a4* d3* e5* m1* n2 + a3* d4* e5* m1* n2 + 
       a5* d4* e1* m3* n2 - a4* d5* e1* m3* n2 - a5* d1* e4* m3* n2 + 
       a1* d5* e4* m3* n2 + a4* d1* e5* m3* n2 - a1* d4* e5* m3* n2 - 
       a5* d3* e1* m4* n2 + a3* d5* e1* m4* n2 + a5* d1* e3* m4* n2 - 
       a1* d5* e3* m4* n2 - a3* d1* e5* m4* n2 + a1* d3* e5* m4* n2 + 
       a4* d3* e1* m5* n2 - a3* d4* e1* m5* n2 - a4* d1* e3* m5* n2 + 
       a1* d4* e3* m5* n2 + a3* d1* e4* m5* n2 - a1* d3* e4* m5* n2 + 
       a5* d4* e2* m1* n3 - a4* d5* e2* m1* n3 - a5* d2* e4* m1* n3 + 
       a2* d5* e4* m1* n3 + a4* d2* e5* m1* n3 - a2* d4* e5* m1* n3 - 
       a5* d4* e1* m2* n3 + a4* d5* e1* m2* n3 + a5* d1* e4* m2* n3 - 
       a1* d5* e4* m2* n3 - a4* d1* e5* m2* n3 + a1* d4* e5* m2* n3 + 
       a5* d2* e1* m4* n3 - a2* d5* e1* m4* n3 - a5* d1* e2* m4* n3 + 
       a1* d5* e2* m4* n3 + a2* d1* e5* m4* n3 - a1* d2* e5* m4* n3 - 
       a4* d2* e1* m5* n3 + a2* d4* e1* m5* n3 + a4* d1* e2* m5* n3 - 
       a1* d4* e2* m5* n3 - a2* d1* e4* m5* n3 + a1* d2* e4* m5* n3 - 
       a5* d3* e2* m1* n4 + a3* d5* e2* m1* n4 + a5* d2* e3* m1* n4 - 
       a2* d5* e3* m1* n4 - a3* d2* e5* m1* n4 + a2* d3* e5* m1* n4 + 
       a5* d3* e1* m2* n4 - a3* d5* e1* m2* n4 - a5* d1* e3* m2* n4 + 
       a1* d5* e3* m2* n4 + a3* d1* e5* m2* n4 - a1* d3* e5* m2* n4 - 
       a5* d2* e1* m3* n4 + a2* d5* e1* m3* n4 + a5* d1* e2* m3* n4 - 
       a1* d5* e2* m3* n4 - a2* d1* e5* m3* n4 + a1* d2* e5* m3* n4 + 
       a3* d2* e1* m5* n4 - a2* d3* e1* m5* n4 - a3* d1* e2* m5* n4 + 
       a1* d3* e2* m5* n4 + a2* d1* e3* m5* n4 - a1* d2* e3* m5* n4 + 
       a4* d3* e2* m1* n5 - a3* d4* e2* m1* n5 - a4* d2* e3* m1* n5 + 
       a2* d4* e3* m1* n5 + a3* d2* e4* m1* n5 - a2* d3* e4* m1* n5 - 
       a4* d3* e1* m2* n5 + a3* d4* e1* m2* n5 + a4* d1* e3* m2* n5 - 
       a1* d4* e3* m2* n5 - a3* d1* e4* m2* n5 + a1* d3* e4* m2* n5 + 
       a4* d2* e1* m3* n5 - a2* d4* e1* m3* n5 - a4* d1* e2* m3* n5 + 
       a1* d4* e2* m3* n5 + a2* d1* e4* m3* n5 - a1* d2* e4* m3* n5 - 
       a3* d2* e1* m4* n5 + a2* d3* e1* m4* n5 + a3* d1* e2* m4* n5 - 
       a1* d3* e2* m4* n5 - a2* d1* e3* m4* n5 + a1* d2* e3* m4* n5) - 
    a6* (b5* d4* e3* m2* n1 - b4* d5* e3* m2* n1 - b5* d3* e4* m2* n1 + 
       b3* d5* e4* m2* n1 + b4* d3* e5* m2* n1 - b3* d4* e5* m2* n1 - 
       b5* d4* e2* m3* n1 + b4* d5* e2* m3* n1 + b5* d2* e4* m3* n1 - 
       b2* d5* e4* m3* n1 - b4* d2* e5* m3* n1 + b2* d4* e5* m3* n1 + 
       b5* d3* e2* m4* n1 - b3* d5* e2* m4* n1 - b5* d2* e3* m4* n1 + 
       b2* d5* e3* m4* n1 + b3* d2* e5* m4* n1 - b2* d3* e5* m4* n1 - 
       b4* d3* e2* m5* n1 + b3* d4* e2* m5* n1 + b4* d2* e3* m5* n1 - 
       b2* d4* e3* m5* n1 - b3* d2* e4* m5* n1 + b2* d3* e4* m5* n1 - 
       b5* d4* e3* m1* n2 + b4* d5* e3* m1* n2 + b5* d3* e4* m1* n2 - 
       b3* d5* e4* m1* n2 - b4* d3* e5* m1* n2 + b3* d4* e5* m1* n2 + 
       b5* d4* e1* m3* n2 - b4* d5* e1* m3* n2 - b5* d1* e4* m3* n2 + 
       b1* d5* e4* m3* n2 + b4* d1* e5* m3* n2 - b1* d4* e5* m3* n2 - 
       b5* d3* e1* m4* n2 + b3* d5* e1* m4* n2 + b5* d1* e3* m4* n2 - 
       b1* d5* e3* m4* n2 - b3* d1* e5* m4* n2 + b1* d3* e5* m4* n2 + 
       b4* d3* e1* m5* n2 - b3* d4* e1* m5* n2 - b4* d1* e3* m5* n2 + 
       b1* d4* e3* m5* n2 + b3* d1* e4* m5* n2 - b1* d3* e4* m5* n2 + 
       b5* d4* e2* m1* n3 - b4* d5* e2* m1* n3 - b5* d2* e4* m1* n3 + 
       b2* d5* e4* m1* n3 + b4* d2* e5* m1* n3 - b2* d4* e5* m1* n3 - 
       b5* d4* e1* m2* n3 + b4* d5* e1* m2* n3 + b5* d1* e4* m2* n3 - 
       b1* d5* e4* m2* n3 - b4* d1* e5* m2* n3 + b1* d4* e5* m2* n3 + 
       b5* d2* e1* m4* n3 - b2* d5* e1* m4* n3 - b5* d1* e2* m4* n3 + 
       b1* d5* e2* m4* n3 + b2* d1* e5* m4* n3 - b1* d2* e5* m4* n3 - 
       b4* d2* e1* m5* n3 + b2* d4* e1* m5* n3 + b4* d1* e2* m5* n3 - 
       b1* d4* e2* m5* n3 - b2* d1* e4* m5* n3 + b1* d2* e4* m5* n3 - 
       b5* d3* e2* m1* n4 + b3* d5* e2* m1* n4 + b5* d2* e3* m1* n4 - 
       b2* d5* e3* m1* n4 - b3* d2* e5* m1* n4 + b2* d3* e5* m1* n4 + 
       b5* d3* e1* m2* n4 - b3* d5* e1* m2* n4 - b5* d1* e3* m2* n4 + 
       b1* d5* e3* m2* n4 + b3* d1* e5* m2* n4 - b1* d3* e5* m2* n4 - 
       b5* d2* e1* m3* n4 + b2* d5* e1* m3* n4 + b5* d1* e2* m3* n4 - 
       b1* d5* e2* m3* n4 - b2* d1* e5* m3* n4 + b1* d2* e5* m3* n4 + 
       b3* d2* e1* m5* n4 - b2* d3* e1* m5* n4 - b3* d1* e2* m5* n4 + 
       b1* d3* e2* m5* n4 + b2* d1* e3* m5* n4 - b1* d2* e3* m5* n4 + 
       b4* d3* e2* m1* n5 - b3* d4* e2* m1* n5 - b4* d2* e3* m1* n5 + 
       b2* d4* e3* m1* n5 + b3* d2* e4* m1* n5 - b2* d3* e4* m1* n5 - 
       b4* d3* e1* m2* n5 + b3* d4* e1* m2* n5 + b4* d1* e3* m2* n5 - 
       b1* d4* e3* m2* n5 - b3* d1* e4* m2* n5 + b1* d3* e4* m2* n5 + 
       b4* d2* e1* m3* n5 - b2* d4* e1* m3* n5 - b4* d1* e2* m3* n5 + 
       b1* d4* e2* m3* n5 + b2* d1* e4* m3* n5 - b1* d2* e4* m3* n5 - 
       b3* d2* e1* m4* n5 + b2* d3* e1* m4* n5 + b3* d1* e2* m4* n5 - 
       b1* d3* e2* m4* n5 - b2* d1* e3* m4* n5 + 
       b1* d2* e3* m4* n5) + (a5* b4* d3* e2* m1 - a4* b5* d3* e2* m1 - 
       a5* b3* d4* e2* m1 + a3* b5* d4* e2* m1 + a4* b3* d5* e2* m1 - 
       a3* b4* d5* e2* m1 - a5* b4* d2* e3* m1 + a4* b5* d2* e3* m1 + 
       a5* b2* d4* e3* m1 - a2* b5* d4* e3* m1 - a4* b2* d5* e3* m1 + 
       a2* b4* d5* e3* m1 + a5* b3* d2* e4* m1 - a3* b5* d2* e4* m1 - 
       a5* b2* d3* e4* m1 + a2* b5* d3* e4* m1 + a3* b2* d5* e4* m1 - 
       a2* b3* d5* e4* m1 - a4* b3* d2* e5* m1 + a3* b4* d2* e5* m1 + 
       a4* b2* d3* e5* m1 - a2* b4* d3* e5* m1 - a3* b2* d4* e5* m1 + 
       a2* b3* d4* e5* m1 - a5* b4* d3* e1* m2 + a4* b5* d3* e1* m2 + 
       a5* b3* d4* e1* m2 - a3* b5* d4* e1* m2 - a4* b3* d5* e1* m2 + 
       a3* b4* d5* e1* m2 + a5* b4* d1* e3* m2 - a4* b5* d1* e3* m2 - 
       a5* b1* d4* e3* m2 + a1* b5* d4* e3* m2 + a4* b1* d5* e3* m2 - 
       a1* b4* d5* e3* m2 - a5* b3* d1* e4* m2 + a3* b5* d1* e4* m2 + 
       a5* b1* d3* e4* m2 - a1* b5* d3* e4* m2 - a3* b1* d5* e4* m2 + 
       a1* b3* d5* e4* m2 + a4* b3* d1* e5* m2 - a3* b4* d1* e5* m2 - 
       a4* b1* d3* e5* m2 + a1* b4* d3* e5* m2 + a3* b1* d4* e5* m2 - 
       a1* b3* d4* e5* m2 + a5* b4* d2* e1* m3 - a4* b5* d2* e1* m3 - 
       a5* b2* d4* e1* m3 + a2* b5* d4* e1* m3 + a4* b2* d5* e1* m3 - 
       a2* b4* d5* e1* m3 - a5* b4* d1* e2* m3 + a4* b5* d1* e2* m3 + 
       a5* b1* d4* e2* m3 - a1* b5* d4* e2* m3 - a4* b1* d5* e2* m3 + 
       a1* b4* d5* e2* m3 + a5* b2* d1* e4* m3 - a2* b5* d1* e4* m3 - 
       a5* b1* d2* e4* m3 + a1* b5* d2* e4* m3 + a2* b1* d5* e4* m3 - 
       a1* b2* d5* e4* m3 - a4* b2* d1* e5* m3 + a2* b4* d1* e5* m3 + 
       a4* b1* d2* e5* m3 - a1* b4* d2* e5* m3 - a2* b1* d4* e5* m3 + 
       a1* b2* d4* e5* m3 - a5* b3* d2* e1* m4 + a3* b5* d2* e1* m4 + 
       a5* b2* d3* e1* m4 - a2* b5* d3* e1* m4 - a3* b2* d5* e1* m4 + 
       a2* b3* d5* e1* m4 + a5* b3* d1* e2* m4 - a3* b5* d1* e2* m4 - 
       a5* b1* d3* e2* m4 + a1* b5* d3* e2* m4 + a3* b1* d5* e2* m4 - 
       a1* b3* d5* e2* m4 - a5* b2* d1* e3* m4 + a2* b5* d1* e3* m4 + 
       a5* b1* d2* e3* m4 - a1* b5* d2* e3* m4 - a2* b1* d5* e3* m4 + 
       a1* b2* d5* e3* m4 + a3* b2* d1* e5* m4 - a2* b3* d1* e5* m4 - 
       a3* b1* d2* e5* m4 + a1* b3* d2* e5* m4 + a2* b1* d3* e5* m4 - 
       a1* b2* d3* e5* m4 + a4* b3* d2* e1* m5 - a3* b4* d2* e1* m5 - 
       a4* b2* d3* e1* m5 + a2* b4* d3* e1* m5 + a3* b2* d4* e1* m5 - 
       a2* b3* d4* e1* m5 - a4* b3* d1* e2* m5 + a3* b4* d1* e2* m5 + 
       a4* b1* d3* e2* m5 - a1* b4* d3* e2* m5 - a3* b1* d4* e2* m5 + 
       a1* b3* d4* e2* m5 + a4* b2* d1* e3* m5 - a2* b4* d1* e3* m5 - 
       a4* b1* d2* e3* m5 + a1* b4* d2* e3* m5 + a2* b1* d4* e3* m5 - 
       a1* b2* d4* e3* m5 - a3* b2* d1* e4* m5 + a2* b3* d1* e4* m5 + 
       a3* b1* d2* e4* m5 - a1* b3* d2* e4* m5 - a2* b1* d3* e4* m5 + 
       a1* b2* d3* e4* m5) *n6) - 
 b7* (-m6* (a5* c4* d3* e2* n1 - a4* c5* d3* e2* n1 - a5* c3* d4* e2* n1 + 
       a3* c5* d4* e2* n1 + a4* c3* d5* e2* n1 - a3* c4* d5* e2* n1 - 
       a5* c4* d2* e3* n1 + a4* c5* d2* e3* n1 + a5* c2* d4* e3* n1 - 
       a2* c5* d4* e3* n1 - a4* c2* d5* e3* n1 + a2* c4* d5* e3* n1 + 
       a5* c3* d2* e4* n1 - a3* c5* d2* e4* n1 - a5* c2* d3* e4* n1 + 
       a2* c5* d3* e4* n1 + a3* c2* d5* e4* n1 - a2* c3* d5* e4* n1 - 
       a4* c3* d2* e5* n1 + a3* c4* d2* e5* n1 + a4* c2* d3* e5* n1 - 
       a2* c4* d3* e5* n1 - a3* c2* d4* e5* n1 + a2* c3* d4* e5* n1 - 
       a5* c4* d3* e1* n2 + a4* c5* d3* e1* n2 + a5* c3* d4* e1* n2 - 
       a3* c5* d4* e1* n2 - a4* c3* d5* e1* n2 + a3* c4* d5* e1* n2 + 
       a5* c4* d1* e3* n2 - a4* c5* d1* e3* n2 - a5* c1* d4* e3* n2 + 
       a1* c5* d4* e3* n2 + a4* c1* d5* e3* n2 - a1* c4* d5* e3* n2 - 
       a5* c3* d1* e4* n2 + a3* c5* d1* e4* n2 + a5* c1* d3* e4* n2 - 
       a1* c5* d3* e4* n2 - a3* c1* d5* e4* n2 + a1* c3* d5* e4* n2 + 
       a4* c3* d1* e5* n2 - a3* c4* d1* e5* n2 - a4* c1* d3* e5* n2 + 
       a1* c4* d3* e5* n2 + a3* c1* d4* e5* n2 - a1* c3* d4* e5* n2 + 
       a5* c4* d2* e1* n3 - a4* c5* d2* e1* n3 - a5* c2* d4* e1* n3 + 
       a2* c5* d4* e1* n3 + a4* c2* d5* e1* n3 - a2* c4* d5* e1* n3 - 
       a5* c4* d1* e2* n3 + a4* c5* d1* e2* n3 + a5* c1* d4* e2* n3 - 
       a1* c5* d4* e2* n3 - a4* c1* d5* e2* n3 + a1* c4* d5* e2* n3 + 
       a5* c2* d1* e4* n3 - a2* c5* d1* e4* n3 - a5* c1* d2* e4* n3 + 
       a1* c5* d2* e4* n3 + a2* c1* d5* e4* n3 - a1* c2* d5* e4* n3 - 
       a4* c2* d1* e5* n3 + a2* c4* d1* e5* n3 + a4* c1* d2* e5* n3 - 
       a1* c4* d2* e5* n3 - a2* c1* d4* e5* n3 + a1* c2* d4* e5* n3 - 
       a5* c3* d2* e1* n4 + a3* c5* d2* e1* n4 + a5* c2* d3* e1* n4 - 
       a2* c5* d3* e1* n4 - a3* c2* d5* e1* n4 + a2* c3* d5* e1* n4 + 
       a5* c3* d1* e2* n4 - a3* c5* d1* e2* n4 - a5* c1* d3* e2* n4 + 
       a1* c5* d3* e2* n4 + a3* c1* d5* e2* n4 - a1* c3* d5* e2* n4 - 
       a5* c2* d1* e3* n4 + a2* c5* d1* e3* n4 + a5* c1* d2* e3* n4 - 
       a1* c5* d2* e3* n4 - a2* c1* d5* e3* n4 + a1* c2* d5* e3* n4 + 
       a3* c2* d1* e5* n4 - a2* c3* d1* e5* n4 - a3* c1* d2* e5* n4 + 
       a1* c3* d2* e5* n4 + a2* c1* d3* e5* n4 - a1* c2* d3* e5* n4 + 
       a4* c3* d2* e1* n5 - a3* c4* d2* e1* n5 - a4* c2* d3* e1* n5 + 
       a2* c4* d3* e1* n5 + a3* c2* d4* e1* n5 - a2* c3* d4* e1* n5 - 
       a4* c3* d1* e2* n5 + a3* c4* d1* e2* n5 + a4* c1* d3* e2* n5 - 
       a1* c4* d3* e2* n5 - a3* c1* d4* e2* n5 + a1* c3* d4* e2* n5 + 
       a4* c2* d1* e3* n5 - a2* c4* d1* e3* n5 - a4* c1* d2* e3* n5 + 
       a1* c4* d2* e3* n5 + a2* c1* d4* e3* n5 - a1* c2* d4* e3* n5 - 
       a3* c2* d1* e4* n5 + a2* c3* d1* e4* n5 + a3* c1* d2* e4* n5 - 
       a1* c3* d2* e4* n5 - a2* c1* d3* e4* n5 + a1* c2* d3* e4* n5) + 
    e6* (a5* c4* d3* m2* n1 - a4* c5* d3* m2* n1 - a5* c3* d4* m2* n1 + 
       a3* c5* d4* m2* n1 + a4* c3* d5* m2* n1 - a3* c4* d5* m2* n1 - 
       a5* c4* d2* m3* n1 + a4* c5* d2* m3* n1 + a5* c2* d4* m3* n1 - 
       a2* c5* d4* m3* n1 - a4* c2* d5* m3* n1 + a2* c4* d5* m3* n1 + 
       a5* c3* d2* m4* n1 - a3* c5* d2* m4* n1 - a5* c2* d3* m4* n1 + 
       a2* c5* d3* m4* n1 + a3* c2* d5* m4* n1 - a2* c3* d5* m4* n1 - 
       a4* c3* d2* m5* n1 + a3* c4* d2* m5* n1 + a4* c2* d3* m5* n1 - 
       a2* c4* d3* m5* n1 - a3* c2* d4* m5* n1 + a2* c3* d4* m5* n1 - 
       a5* c4* d3* m1* n2 + a4* c5* d3* m1* n2 + a5* c3* d4* m1* n2 - 
       a3* c5* d4* m1* n2 - a4* c3* d5* m1* n2 + a3* c4* d5* m1* n2 + 
       a5* c4* d1* m3* n2 - a4* c5* d1* m3* n2 - a5* c1* d4* m3* n2 + 
       a1* c5* d4* m3* n2 + a4* c1* d5* m3* n2 - a1* c4* d5* m3* n2 - 
       a5* c3* d1* m4* n2 + a3* c5* d1* m4* n2 + a5* c1* d3* m4* n2 - 
       a1* c5* d3* m4* n2 - a3* c1* d5* m4* n2 + a1* c3* d5* m4* n2 + 
       a4* c3* d1* m5* n2 - a3* c4* d1* m5* n2 - a4* c1* d3* m5* n2 + 
       a1* c4* d3* m5* n2 + a3* c1* d4* m5* n2 - a1* c3* d4* m5* n2 + 
       a5* c4* d2* m1* n3 - a4* c5* d2* m1* n3 - a5* c2* d4* m1* n3 + 
       a2* c5* d4* m1* n3 + a4* c2* d5* m1* n3 - a2* c4* d5* m1* n3 - 
       a5* c4* d1* m2* n3 + a4* c5* d1* m2* n3 + a5* c1* d4* m2* n3 - 
       a1* c5* d4* m2* n3 - a4* c1* d5* m2* n3 + a1* c4* d5* m2* n3 + 
       a5* c2* d1* m4* n3 - a2* c5* d1* m4* n3 - a5* c1* d2* m4* n3 + 
       a1* c5* d2* m4* n3 + a2* c1* d5* m4* n3 - a1* c2* d5* m4* n3 - 
       a4* c2* d1* m5* n3 + a2* c4* d1* m5* n3 + a4* c1* d2* m5* n3 - 
       a1* c4* d2* m5* n3 - a2* c1* d4* m5* n3 + a1* c2* d4* m5* n3 - 
       a5* c3* d2* m1* n4 + a3* c5* d2* m1* n4 + a5* c2* d3* m1* n4 - 
       a2* c5* d3* m1* n4 - a3* c2* d5* m1* n4 + a2* c3* d5* m1* n4 + 
       a5* c3* d1* m2* n4 - a3* c5* d1* m2* n4 - a5* c1* d3* m2* n4 + 
       a1* c5* d3* m2* n4 + a3* c1* d5* m2* n4 - a1* c3* d5* m2* n4 - 
       a5* c2* d1* m3* n4 + a2* c5* d1* m3* n4 + a5* c1* d2* m3* n4 - 
       a1* c5* d2* m3* n4 - a2* c1* d5* m3* n4 + a1* c2* d5* m3* n4 + 
       a3* c2* d1* m5* n4 - a2* c3* d1* m5* n4 - a3* c1* d2* m5* n4 + 
       a1* c3* d2* m5* n4 + a2* c1* d3* m5* n4 - a1* c2* d3* m5* n4 + 
       a4* c3* d2* m1* n5 - a3* c4* d2* m1* n5 - a4* c2* d3* m1* n5 + 
       a2* c4* d3* m1* n5 + a3* c2* d4* m1* n5 - a2* c3* d4* m1* n5 - 
       a4* c3* d1* m2* n5 + a3* c4* d1* m2* n5 + a4* c1* d3* m2* n5 - 
       a1* c4* d3* m2* n5 - a3* c1* d4* m2* n5 + a1* c3* d4* m2* n5 + 
       a4* c2* d1* m3* n5 - a2* c4* d1* m3* n5 - a4* c1* d2* m3* n5 + 
       a1* c4* d2* m3* n5 + a2* c1* d4* m3* n5 - a1* c2* d4* m3* n5 - 
       a3* c2* d1* m4* n5 + a2* c3* d1* m4* n5 + a3* c1* d2* m4* n5 - 
       a1* c3* d2* m4* n5 - a2* c1* d3* m4* n5 + a1* c2* d3* m4* n5) - 
    d6* (a5* c4* e3* m2* n1 - a4* c5* e3* m2* n1 - a5* c3* e4* m2* n1 + 
       a3* c5* e4* m2* n1 + a4* c3* e5* m2* n1 - a3* c4* e5* m2* n1 - 
       a5* c4* e2* m3* n1 + a4* c5* e2* m3* n1 + a5* c2* e4* m3* n1 - 
       a2* c5* e4* m3* n1 - a4* c2* e5* m3* n1 + a2* c4* e5* m3* n1 + 
       a5* c3* e2* m4* n1 - a3* c5* e2* m4* n1 - a5* c2* e3* m4* n1 + 
       a2* c5* e3* m4* n1 + a3* c2* e5* m4* n1 - a2* c3* e5* m4* n1 - 
       a4* c3* e2* m5* n1 + a3* c4* e2* m5* n1 + a4* c2* e3* m5* n1 - 
       a2* c4* e3* m5* n1 - a3* c2* e4* m5* n1 + a2* c3* e4* m5* n1 - 
       a5* c4* e3* m1* n2 + a4* c5* e3* m1* n2 + a5* c3* e4* m1* n2 - 
       a3* c5* e4* m1* n2 - a4* c3* e5* m1* n2 + a3* c4* e5* m1* n2 + 
       a5* c4* e1* m3* n2 - a4* c5* e1* m3* n2 - a5* c1* e4* m3* n2 + 
       a1* c5* e4* m3* n2 + a4* c1* e5* m3* n2 - a1* c4* e5* m3* n2 - 
       a5* c3* e1* m4* n2 + a3* c5* e1* m4* n2 + a5* c1* e3* m4* n2 - 
       a1* c5* e3* m4* n2 - a3* c1* e5* m4* n2 + a1* c3* e5* m4* n2 + 
       a4* c3* e1* m5* n2 - a3* c4* e1* m5* n2 - a4* c1* e3* m5* n2 + 
       a1* c4* e3* m5* n2 + a3* c1* e4* m5* n2 - a1* c3* e4* m5* n2 + 
       a5* c4* e2* m1* n3 - a4* c5* e2* m1* n3 - a5* c2* e4* m1* n3 + 
       a2* c5* e4* m1* n3 + a4* c2* e5* m1* n3 - a2* c4* e5* m1* n3 - 
       a5* c4* e1* m2* n3 + a4* c5* e1* m2* n3 + a5* c1* e4* m2* n3 - 
       a1* c5* e4* m2* n3 - a4* c1* e5* m2* n3 + a1* c4* e5* m2* n3 + 
       a5* c2* e1* m4* n3 - a2* c5* e1* m4* n3 - a5* c1* e2* m4* n3 + 
       a1* c5* e2* m4* n3 + a2* c1* e5* m4* n3 - a1* c2* e5* m4* n3 - 
       a4* c2* e1* m5* n3 + a2* c4* e1* m5* n3 + a4* c1* e2* m5* n3 - 
       a1* c4* e2* m5* n3 - a2* c1* e4* m5* n3 + a1* c2* e4* m5* n3 - 
       a5* c3* e2* m1* n4 + a3* c5* e2* m1* n4 + a5* c2* e3* m1* n4 - 
       a2* c5* e3* m1* n4 - a3* c2* e5* m1* n4 + a2* c3* e5* m1* n4 + 
       a5* c3* e1* m2* n4 - a3* c5* e1* m2* n4 - a5* c1* e3* m2* n4 + 
       a1* c5* e3* m2* n4 + a3* c1* e5* m2* n4 - a1* c3* e5* m2* n4 - 
       a5* c2* e1* m3* n4 + a2* c5* e1* m3* n4 + a5* c1* e2* m3* n4 - 
       a1* c5* e2* m3* n4 - a2* c1* e5* m3* n4 + a1* c2* e5* m3* n4 + 
       a3* c2* e1* m5* n4 - a2* c3* e1* m5* n4 - a3* c1* e2* m5* n4 + 
       a1* c3* e2* m5* n4 + a2* c1* e3* m5* n4 - a1* c2* e3* m5* n4 + 
       a4* c3* e2* m1* n5 - a3* c4* e2* m1* n5 - a4* c2* e3* m1* n5 + 
       a2* c4* e3* m1* n5 + a3* c2* e4* m1* n5 - a2* c3* e4* m1* n5 - 
       a4* c3* e1* m2* n5 + a3* c4* e1* m2* n5 + a4* c1* e3* m2* n5 - 
       a1* c4* e3* m2* n5 - a3* c1* e4* m2* n5 + a1* c3* e4* m2* n5 + 
       a4* c2* e1* m3* n5 - a2* c4* e1* m3* n5 - a4* c1* e2* m3* n5 + 
       a1* c4* e2* m3* n5 + a2* c1* e4* m3* n5 - a1* c2* e4* m3* n5 - 
       a3* c2* e1* m4* n5 + a2* c3* e1* m4* n5 + a3* c1* e2* m4* n5 - 
       a1* c3* e2* m4* n5 - a2* c1* e3* m4* n5 + a1* c2* e3* m4* n5) + 
    c6* (a5* d4* e3* m2* n1 - a4* d5* e3* m2* n1 - a5* d3* e4* m2* n1 + 
       a3* d5* e4* m2* n1 + a4* d3* e5* m2* n1 - a3* d4* e5* m2* n1 - 
       a5* d4* e2* m3* n1 + a4* d5* e2* m3* n1 + a5* d2* e4* m3* n1 - 
       a2* d5* e4* m3* n1 - a4* d2* e5* m3* n1 + a2* d4* e5* m3* n1 + 
       a5* d3* e2* m4* n1 - a3* d5* e2* m4* n1 - a5* d2* e3* m4* n1 + 
       a2* d5* e3* m4* n1 + a3* d2* e5* m4* n1 - a2* d3* e5* m4* n1 - 
       a4* d3* e2* m5* n1 + a3* d4* e2* m5* n1 + a4* d2* e3* m5* n1 - 
       a2* d4* e3* m5* n1 - a3* d2* e4* m5* n1 + a2* d3* e4* m5* n1 - 
       a5* d4* e3* m1* n2 + a4* d5* e3* m1* n2 + a5* d3* e4* m1* n2 - 
       a3* d5* e4* m1* n2 - a4* d3* e5* m1* n2 + a3* d4* e5* m1* n2 + 
       a5* d4* e1* m3* n2 - a4* d5* e1* m3* n2 - a5* d1* e4* m3* n2 + 
       a1* d5* e4* m3* n2 + a4* d1* e5* m3* n2 - a1* d4* e5* m3* n2 - 
       a5* d3* e1* m4* n2 + a3* d5* e1* m4* n2 + a5* d1* e3* m4* n2 - 
       a1* d5* e3* m4* n2 - a3* d1* e5* m4* n2 + a1* d3* e5* m4* n2 + 
       a4* d3* e1* m5* n2 - a3* d4* e1* m5* n2 - a4* d1* e3* m5* n2 + 
       a1* d4* e3* m5* n2 + a3* d1* e4* m5* n2 - a1* d3* e4* m5* n2 + 
       a5* d4* e2* m1* n3 - a4* d5* e2* m1* n3 - a5* d2* e4* m1* n3 + 
       a2* d5* e4* m1* n3 + a4* d2* e5* m1* n3 - a2* d4* e5* m1* n3 - 
       a5* d4* e1* m2* n3 + a4* d5* e1* m2* n3 + a5* d1* e4* m2* n3 - 
       a1* d5* e4* m2* n3 - a4* d1* e5* m2* n3 + a1* d4* e5* m2* n3 + 
       a5* d2* e1* m4* n3 - a2* d5* e1* m4* n3 - a5* d1* e2* m4* n3 + 
       a1* d5* e2* m4* n3 + a2* d1* e5* m4* n3 - a1* d2* e5* m4* n3 - 
       a4* d2* e1* m5* n3 + a2* d4* e1* m5* n3 + a4* d1* e2* m5* n3 - 
       a1* d4* e2* m5* n3 - a2* d1* e4* m5* n3 + a1* d2* e4* m5* n3 - 
       a5* d3* e2* m1* n4 + a3* d5* e2* m1* n4 + a5* d2* e3* m1* n4 - 
       a2* d5* e3* m1* n4 - a3* d2* e5* m1* n4 + a2* d3* e5* m1* n4 + 
       a5* d3* e1* m2* n4 - a3* d5* e1* m2* n4 - a5* d1* e3* m2* n4 + 
       a1* d5* e3* m2* n4 + a3* d1* e5* m2* n4 - a1* d3* e5* m2* n4 - 
       a5* d2* e1* m3* n4 + a2* d5* e1* m3* n4 + a5* d1* e2* m3* n4 - 
       a1* d5* e2* m3* n4 - a2* d1* e5* m3* n4 + a1* d2* e5* m3* n4 + 
       a3* d2* e1* m5* n4 - a2* d3* e1* m5* n4 - a3* d1* e2* m5* n4 + 
       a1* d3* e2* m5* n4 + a2* d1* e3* m5* n4 - a1* d2* e3* m5* n4 + 
       a4* d3* e2* m1* n5 - a3* d4* e2* m1* n5 - a4* d2* e3* m1* n5 + 
       a2* d4* e3* m1* n5 + a3* d2* e4* m1* n5 - a2* d3* e4* m1* n5 - 
       a4* d3* e1* m2* n5 + a3* d4* e1* m2* n5 + a4* d1* e3* m2* n5 - 
       a1* d4* e3* m2* n5 - a3* d1* e4* m2* n5 + a1* d3* e4* m2* n5 + 
       a4* d2* e1* m3* n5 - a2* d4* e1* m3* n5 - a4* d1* e2* m3* n5 + 
       a1* d4* e2* m3* n5 + a2* d1* e4* m3* n5 - a1* d2* e4* m3* n5 - 
       a3* d2* e1* m4* n5 + a2* d3* e1* m4* n5 + a3* d1* e2* m4* n5 - 
       a1* d3* e2* m4* n5 - a2* d1* e3* m4* n5 + a1* d2* e3* m4* n5) - 
    a6* (c5* d4* e3* m2* n1 - c4* d5* e3* m2* n1 - c5* d3* e4* m2* n1 + 
       c3* d5* e4* m2* n1 + c4* d3* e5* m2* n1 - c3* d4* e5* m2* n1 - 
       c5* d4* e2* m3* n1 + c4* d5* e2* m3* n1 + c5* d2* e4* m3* n1 - 
       c2* d5* e4* m3* n1 - c4* d2* e5* m3* n1 + c2* d4* e5* m3* n1 + 
       c5* d3* e2* m4* n1 - c3* d5* e2* m4* n1 - c5* d2* e3* m4* n1 + 
       c2* d5* e3* m4* n1 + c3* d2* e5* m4* n1 - c2* d3* e5* m4* n1 - 
       c4* d3* e2* m5* n1 + c3* d4* e2* m5* n1 + c4* d2* e3* m5* n1 - 
       c2* d4* e3* m5* n1 - c3* d2* e4* m5* n1 + c2* d3* e4* m5* n1 - 
       c5* d4* e3* m1* n2 + c4* d5* e3* m1* n2 + c5* d3* e4* m1* n2 - 
       c3* d5* e4* m1* n2 - c4* d3* e5* m1* n2 + c3* d4* e5* m1* n2 + 
       c5* d4* e1* m3* n2 - c4* d5* e1* m3* n2 - c5* d1* e4* m3* n2 + 
       c1* d5* e4* m3* n2 + c4* d1* e5* m3* n2 - c1* d4* e5* m3* n2 - 
       c5* d3* e1* m4* n2 + c3* d5* e1* m4* n2 + c5* d1* e3* m4* n2 - 
       c1* d5* e3* m4* n2 - c3* d1* e5* m4* n2 + c1* d3* e5* m4* n2 + 
       c4* d3* e1* m5* n2 - c3* d4* e1* m5* n2 - c4* d1* e3* m5* n2 + 
       c1* d4* e3* m5* n2 + c3* d1* e4* m5* n2 - c1* d3* e4* m5* n2 + 
       c5* d4* e2* m1* n3 - c4* d5* e2* m1* n3 - c5* d2* e4* m1* n3 + 
       c2* d5* e4* m1* n3 + c4* d2* e5* m1* n3 - c2* d4* e5* m1* n3 - 
       c5* d4* e1* m2* n3 + c4* d5* e1* m2* n3 + c5* d1* e4* m2* n3 - 
       c1* d5* e4* m2* n3 - c4* d1* e5* m2* n3 + c1* d4* e5* m2* n3 + 
       c5* d2* e1* m4* n3 - c2* d5* e1* m4* n3 - c5* d1* e2* m4* n3 + 
       c1* d5* e2* m4* n3 + c2* d1* e5* m4* n3 - c1* d2* e5* m4* n3 - 
       c4* d2* e1* m5* n3 + c2* d4* e1* m5* n3 + c4* d1* e2* m5* n3 - 
       c1* d4* e2* m5* n3 - c2* d1* e4* m5* n3 + c1* d2* e4* m5* n3 - 
       c5* d3* e2* m1* n4 + c3* d5* e2* m1* n4 + c5* d2* e3* m1* n4 - 
       c2* d5* e3* m1* n4 - c3* d2* e5* m1* n4 + c2* d3* e5* m1* n4 + 
       c5* d3* e1* m2* n4 - c3* d5* e1* m2* n4 - c5* d1* e3* m2* n4 + 
       c1* d5* e3* m2* n4 + c3* d1* e5* m2* n4 - c1* d3* e5* m2* n4 - 
       c5* d2* e1* m3* n4 + c2* d5* e1* m3* n4 + c5* d1* e2* m3* n4 - 
       c1* d5* e2* m3* n4 - c2* d1* e5* m3* n4 + c1* d2* e5* m3* n4 + 
       c3* d2* e1* m5* n4 - c2* d3* e1* m5* n4 - c3* d1* e2* m5* n4 + 
       c1* d3* e2* m5* n4 + c2* d1* e3* m5* n4 - c1* d2* e3* m5* n4 + 
       c4* d3* e2* m1* n5 - c3* d4* e2* m1* n5 - c4* d2* e3* m1* n5 + 
       c2* d4* e3* m1* n5 + c3* d2* e4* m1* n5 - c2* d3* e4* m1* n5 - 
       c4* d3* e1* m2* n5 + c3* d4* e1* m2* n5 + c4* d1* e3* m2* n5 - 
       c1* d4* e3* m2* n5 - c3* d1* e4* m2* n5 + c1* d3* e4* m2* n5 + 
       c4* d2* e1* m3* n5 - c2* d4* e1* m3* n5 - c4* d1* e2* m3* n5 + 
       c1* d4* e2* m3* n5 + c2* d1* e4* m3* n5 - c1* d2* e4* m3* n5 - 
       c3* d2* e1* m4* n5 + c2* d3* e1* m4* n5 + c3* d1* e2* m4* n5 - 
       c1* d3* e2* m4* n5 - c2* d1* e3* m4* n5 + 
       c1* d2* e3* m4* n5) + (a5* c4* d3* e2* m1 - a4* c5* d3* e2* m1 - 
       a5* c3* d4* e2* m1 + a3* c5* d4* e2* m1 + a4* c3* d5* e2* m1 - 
       a3* c4* d5* e2* m1 - a5* c4* d2* e3* m1 + a4* c5* d2* e3* m1 + 
       a5* c2* d4* e3* m1 - a2* c5* d4* e3* m1 - a4* c2* d5* e3* m1 + 
       a2* c4* d5* e3* m1 + a5* c3* d2* e4* m1 - a3* c5* d2* e4* m1 - 
       a5* c2* d3* e4* m1 + a2* c5* d3* e4* m1 + a3* c2* d5* e4* m1 - 
       a2* c3* d5* e4* m1 - a4* c3* d2* e5* m1 + a3* c4* d2* e5* m1 + 
       a4* c2* d3* e5* m1 - a2* c4* d3* e5* m1 - a3* c2* d4* e5* m1 + 
       a2* c3* d4* e5* m1 - a5* c4* d3* e1* m2 + a4* c5* d3* e1* m2 + 
       a5* c3* d4* e1* m2 - a3* c5* d4* e1* m2 - a4* c3* d5* e1* m2 + 
       a3* c4* d5* e1* m2 + a5* c4* d1* e3* m2 - a4* c5* d1* e3* m2 - 
       a5* c1* d4* e3* m2 + a1* c5* d4* e3* m2 + a4* c1* d5* e3* m2 - 
       a1* c4* d5* e3* m2 - a5* c3* d1* e4* m2 + a3* c5* d1* e4* m2 + 
       a5* c1* d3* e4* m2 - a1* c5* d3* e4* m2 - a3* c1* d5* e4* m2 + 
       a1* c3* d5* e4* m2 + a4* c3* d1* e5* m2 - a3* c4* d1* e5* m2 - 
       a4* c1* d3* e5* m2 + a1* c4* d3* e5* m2 + a3* c1* d4* e5* m2 - 
       a1* c3* d4* e5* m2 + a5* c4* d2* e1* m3 - a4* c5* d2* e1* m3 - 
       a5* c2* d4* e1* m3 + a2* c5* d4* e1* m3 + a4* c2* d5* e1* m3 - 
       a2* c4* d5* e1* m3 - a5* c4* d1* e2* m3 + a4* c5* d1* e2* m3 + 
       a5* c1* d4* e2* m3 - a1* c5* d4* e2* m3 - a4* c1* d5* e2* m3 + 
       a1* c4* d5* e2* m3 + a5* c2* d1* e4* m3 - a2* c5* d1* e4* m3 - 
       a5* c1* d2* e4* m3 + a1* c5* d2* e4* m3 + a2* c1* d5* e4* m3 - 
       a1* c2* d5* e4* m3 - a4* c2* d1* e5* m3 + a2* c4* d1* e5* m3 + 
       a4* c1* d2* e5* m3 - a1* c4* d2* e5* m3 - a2* c1* d4* e5* m3 + 
       a1* c2* d4* e5* m3 - a5* c3* d2* e1* m4 + a3* c5* d2* e1* m4 + 
       a5* c2* d3* e1* m4 - a2* c5* d3* e1* m4 - a3* c2* d5* e1* m4 + 
       a2* c3* d5* e1* m4 + a5* c3* d1* e2* m4 - a3* c5* d1* e2* m4 - 
       a5* c1* d3* e2* m4 + a1* c5* d3* e2* m4 + a3* c1* d5* e2* m4 - 
       a1* c3* d5* e2* m4 - a5* c2* d1* e3* m4 + a2* c5* d1* e3* m4 + 
       a5* c1* d2* e3* m4 - a1* c5* d2* e3* m4 - a2* c1* d5* e3* m4 + 
       a1* c2* d5* e3* m4 + a3* c2* d1* e5* m4 - a2* c3* d1* e5* m4 - 
       a3* c1* d2* e5* m4 + a1* c3* d2* e5* m4 + a2* c1* d3* e5* m4 - 
       a1* c2* d3* e5* m4 + a4* c3* d2* e1* m5 - a3* c4* d2* e1* m5 - 
       a4* c2* d3* e1* m5 + a2* c4* d3* e1* m5 + a3* c2* d4* e1* m5 - 
       a2* c3* d4* e1* m5 - a4* c3* d1* e2* m5 + a3* c4* d1* e2* m5 + 
       a4* c1* d3* e2* m5 - a1* c4* d3* e2* m5 - a3* c1* d4* e2* m5 + 
       a1* c3* d4* e2* m5 + a4* c2* d1* e3* m5 - a2* c4* d1* e3* m5 - 
       a4* c1* d2* e3* m5 + a1* c4* d2* e3* m5 + a2* c1* d4* e3* m5 - 
       a1* c2* d4* e3* m5 - a3* c2* d1* e4* m5 + a2* c3* d1* e4* m5 + 
       a3* c1* d2* e4* m5 - a1* c3* d2* e4* m5 - a2* c1* d3* e4* m5 + 
       a1* c2* d3* e4* m5) *n6) + 
 a7* (-m6* (b5* c4* d3* e2* n1 - b4* c5* d3* e2* n1 - b5* c3* d4* e2* n1 + 
       b3* c5* d4* e2* n1 + b4* c3* d5* e2* n1 - b3* c4* d5* e2* n1 - 
       b5* c4* d2* e3* n1 + b4* c5* d2* e3* n1 + b5* c2* d4* e3* n1 - 
       b2* c5* d4* e3* n1 - b4* c2* d5* e3* n1 + b2* c4* d5* e3* n1 + 
       b5* c3* d2* e4* n1 - b3* c5* d2* e4* n1 - b5* c2* d3* e4* n1 + 
       b2* c5* d3* e4* n1 + b3* c2* d5* e4* n1 - b2* c3* d5* e4* n1 - 
       b4* c3* d2* e5* n1 + b3* c4* d2* e5* n1 + b4* c2* d3* e5* n1 - 
       b2* c4* d3* e5* n1 - b3* c2* d4* e5* n1 + b2* c3* d4* e5* n1 - 
       b5* c4* d3* e1* n2 + b4* c5* d3* e1* n2 + b5* c3* d4* e1* n2 - 
       b3* c5* d4* e1* n2 - b4* c3* d5* e1* n2 + b3* c4* d5* e1* n2 + 
       b5* c4* d1* e3* n2 - b4* c5* d1* e3* n2 - b5* c1* d4* e3* n2 + 
       b1* c5* d4* e3* n2 + b4* c1* d5* e3* n2 - b1* c4* d5* e3* n2 - 
       b5* c3* d1* e4* n2 + b3* c5* d1* e4* n2 + b5* c1* d3* e4* n2 - 
       b1* c5* d3* e4* n2 - b3* c1* d5* e4* n2 + b1* c3* d5* e4* n2 + 
       b4* c3* d1* e5* n2 - b3* c4* d1* e5* n2 - b4* c1* d3* e5* n2 + 
       b1* c4* d3* e5* n2 + b3* c1* d4* e5* n2 - b1* c3* d4* e5* n2 + 
       b5* c4* d2* e1* n3 - b4* c5* d2* e1* n3 - b5* c2* d4* e1* n3 + 
       b2* c5* d4* e1* n3 + b4* c2* d5* e1* n3 - b2* c4* d5* e1* n3 - 
       b5* c4* d1* e2* n3 + b4* c5* d1* e2* n3 + b5* c1* d4* e2* n3 - 
       b1* c5* d4* e2* n3 - b4* c1* d5* e2* n3 + b1* c4* d5* e2* n3 + 
       b5* c2* d1* e4* n3 - b2* c5* d1* e4* n3 - b5* c1* d2* e4* n3 + 
       b1* c5* d2* e4* n3 + b2* c1* d5* e4* n3 - b1* c2* d5* e4* n3 - 
       b4* c2* d1* e5* n3 + b2* c4* d1* e5* n3 + b4* c1* d2* e5* n3 - 
       b1* c4* d2* e5* n3 - b2* c1* d4* e5* n3 + b1* c2* d4* e5* n3 - 
       b5* c3* d2* e1* n4 + b3* c5* d2* e1* n4 + b5* c2* d3* e1* n4 - 
       b2* c5* d3* e1* n4 - b3* c2* d5* e1* n4 + b2* c3* d5* e1* n4 + 
       b5* c3* d1* e2* n4 - b3* c5* d1* e2* n4 - b5* c1* d3* e2* n4 + 
       b1* c5* d3* e2* n4 + b3* c1* d5* e2* n4 - b1* c3* d5* e2* n4 - 
       b5* c2* d1* e3* n4 + b2* c5* d1* e3* n4 + b5* c1* d2* e3* n4 - 
       b1* c5* d2* e3* n4 - b2* c1* d5* e3* n4 + b1* c2* d5* e3* n4 + 
       b3* c2* d1* e5* n4 - b2* c3* d1* e5* n4 - b3* c1* d2* e5* n4 + 
       b1* c3* d2* e5* n4 + b2* c1* d3* e5* n4 - b1* c2* d3* e5* n4 + 
       b4* c3* d2* e1* n5 - b3* c4* d2* e1* n5 - b4* c2* d3* e1* n5 + 
       b2* c4* d3* e1* n5 + b3* c2* d4* e1* n5 - b2* c3* d4* e1* n5 - 
       b4* c3* d1* e2* n5 + b3* c4* d1* e2* n5 + b4* c1* d3* e2* n5 - 
       b1* c4* d3* e2* n5 - b3* c1* d4* e2* n5 + b1* c3* d4* e2* n5 + 
       b4* c2* d1* e3* n5 - b2* c4* d1* e3* n5 - b4* c1* d2* e3* n5 + 
       b1* c4* d2* e3* n5 + b2* c1* d4* e3* n5 - b1* c2* d4* e3* n5 - 
       b3* c2* d1* e4* n5 + b2* c3* d1* e4* n5 + b3* c1* d2* e4* n5 - 
       b1* c3* d2* e4* n5 - b2* c1* d3* e4* n5 + b1* c2* d3* e4* n5) + 
    e6* (b5* c4* d3* m2* n1 - b4* c5* d3* m2* n1 - b5* c3* d4* m2* n1 + 
       b3* c5* d4* m2* n1 + b4* c3* d5* m2* n1 - b3* c4* d5* m2* n1 - 
       b5* c4* d2* m3* n1 + b4* c5* d2* m3* n1 + b5* c2* d4* m3* n1 - 
       b2* c5* d4* m3* n1 - b4* c2* d5* m3* n1 + b2* c4* d5* m3* n1 + 
       b5* c3* d2* m4* n1 - b3* c5* d2* m4* n1 - b5* c2* d3* m4* n1 + 
       b2* c5* d3* m4* n1 + b3* c2* d5* m4* n1 - b2* c3* d5* m4* n1 - 
       b4* c3* d2* m5* n1 + b3* c4* d2* m5* n1 + b4* c2* d3* m5* n1 - 
       b2* c4* d3* m5* n1 - b3* c2* d4* m5* n1 + b2* c3* d4* m5* n1 - 
       b5* c4* d3* m1* n2 + b4* c5* d3* m1* n2 + b5* c3* d4* m1* n2 - 
       b3* c5* d4* m1* n2 - b4* c3* d5* m1* n2 + b3* c4* d5* m1* n2 + 
       b5* c4* d1* m3* n2 - b4* c5* d1* m3* n2 - b5* c1* d4* m3* n2 + 
       b1* c5* d4* m3* n2 + b4* c1* d5* m3* n2 - b1* c4* d5* m3* n2 - 
       b5* c3* d1* m4* n2 + b3* c5* d1* m4* n2 + b5* c1* d3* m4* n2 - 
       b1* c5* d3* m4* n2 - b3* c1* d5* m4* n2 + b1* c3* d5* m4* n2 + 
       b4* c3* d1* m5* n2 - b3* c4* d1* m5* n2 - b4* c1* d3* m5* n2 + 
       b1* c4* d3* m5* n2 + b3* c1* d4* m5* n2 - b1* c3* d4* m5* n2 + 
       b5* c4* d2* m1* n3 - b4* c5* d2* m1* n3 - b5* c2* d4* m1* n3 + 
       b2* c5* d4* m1* n3 + b4* c2* d5* m1* n3 - b2* c4* d5* m1* n3 - 
       b5* c4* d1* m2* n3 + b4* c5* d1* m2* n3 + b5* c1* d4* m2* n3 - 
       b1* c5* d4* m2* n3 - b4* c1* d5* m2* n3 + b1* c4* d5* m2* n3 + 
       b5* c2* d1* m4* n3 - b2* c5* d1* m4* n3 - b5* c1* d2* m4* n3 + 
       b1* c5* d2* m4* n3 + b2* c1* d5* m4* n3 - b1* c2* d5* m4* n3 - 
       b4* c2* d1* m5* n3 + b2* c4* d1* m5* n3 + b4* c1* d2* m5* n3 - 
       b1* c4* d2* m5* n3 - b2* c1* d4* m5* n3 + b1* c2* d4* m5* n3 - 
       b5* c3* d2* m1* n4 + b3* c5* d2* m1* n4 + b5* c2* d3* m1* n4 - 
       b2* c5* d3* m1* n4 - b3* c2* d5* m1* n4 + b2* c3* d5* m1* n4 + 
       b5* c3* d1* m2* n4 - b3* c5* d1* m2* n4 - b5* c1* d3* m2* n4 + 
       b1* c5* d3* m2* n4 + b3* c1* d5* m2* n4 - b1* c3* d5* m2* n4 - 
       b5* c2* d1* m3* n4 + b2* c5* d1* m3* n4 + b5* c1* d2* m3* n4 - 
       b1* c5* d2* m3* n4 - b2* c1* d5* m3* n4 + b1* c2* d5* m3* n4 + 
       b3* c2* d1* m5* n4 - b2* c3* d1* m5* n4 - b3* c1* d2* m5* n4 + 
       b1* c3* d2* m5* n4 + b2* c1* d3* m5* n4 - b1* c2* d3* m5* n4 + 
       b4* c3* d2* m1* n5 - b3* c4* d2* m1* n5 - b4* c2* d3* m1* n5 + 
       b2* c4* d3* m1* n5 + b3* c2* d4* m1* n5 - b2* c3* d4* m1* n5 - 
       b4* c3* d1* m2* n5 + b3* c4* d1* m2* n5 + b4* c1* d3* m2* n5 - 
       b1* c4* d3* m2* n5 - b3* c1* d4* m2* n5 + b1* c3* d4* m2* n5 + 
       b4* c2* d1* m3* n5 - b2* c4* d1* m3* n5 - b4* c1* d2* m3* n5 + 
       b1* c4* d2* m3* n5 + b2* c1* d4* m3* n5 - b1* c2* d4* m3* n5 - 
       b3* c2* d1* m4* n5 + b2* c3* d1* m4* n5 + b3* c1* d2* m4* n5 - 
       b1* c3* d2* m4* n5 - b2* c1* d3* m4* n5 + b1* c2* d3* m4* n5) - 
    d6* (b5* c4* e3* m2* n1 - b4* c5* e3* m2* n1 - b5* c3* e4* m2* n1 + 
       b3* c5* e4* m2* n1 + b4* c3* e5* m2* n1 - b3* c4* e5* m2* n1 - 
       b5* c4* e2* m3* n1 + b4* c5* e2* m3* n1 + b5* c2* e4* m3* n1 - 
       b2* c5* e4* m3* n1 - b4* c2* e5* m3* n1 + b2* c4* e5* m3* n1 + 
       b5* c3* e2* m4* n1 - b3* c5* e2* m4* n1 - b5* c2* e3* m4* n1 + 
       b2* c5* e3* m4* n1 + b3* c2* e5* m4* n1 - b2* c3* e5* m4* n1 - 
       b4* c3* e2* m5* n1 + b3* c4* e2* m5* n1 + b4* c2* e3* m5* n1 - 
       b2* c4* e3* m5* n1 - b3* c2* e4* m5* n1 + b2* c3* e4* m5* n1 - 
       b5* c4* e3* m1* n2 + b4* c5* e3* m1* n2 + b5* c3* e4* m1* n2 - 
       b3* c5* e4* m1* n2 - b4* c3* e5* m1* n2 + b3* c4* e5* m1* n2 + 
       b5* c4* e1* m3* n2 - b4* c5* e1* m3* n2 - b5* c1* e4* m3* n2 + 
       b1* c5* e4* m3* n2 + b4* c1* e5* m3* n2 - b1* c4* e5* m3* n2 - 
       b5* c3* e1* m4* n2 + b3* c5* e1* m4* n2 + b5* c1* e3* m4* n2 - 
       b1* c5* e3* m4* n2 - b3* c1* e5* m4* n2 + b1* c3* e5* m4* n2 + 
       b4* c3* e1* m5* n2 - b3* c4* e1* m5* n2 - b4* c1* e3* m5* n2 + 
       b1* c4* e3* m5* n2 + b3* c1* e4* m5* n2 - b1* c3* e4* m5* n2 + 
       b5* c4* e2* m1* n3 - b4* c5* e2* m1* n3 - b5* c2* e4* m1* n3 + 
       b2* c5* e4* m1* n3 + b4* c2* e5* m1* n3 - b2* c4* e5* m1* n3 - 
       b5* c4* e1* m2* n3 + b4* c5* e1* m2* n3 + b5* c1* e4* m2* n3 - 
       b1* c5* e4* m2* n3 - b4* c1* e5* m2* n3 + b1* c4* e5* m2* n3 + 
       b5* c2* e1* m4* n3 - b2* c5* e1* m4* n3 - b5* c1* e2* m4* n3 + 
       b1* c5* e2* m4* n3 + b2* c1* e5* m4* n3 - b1* c2* e5* m4* n3 - 
       b4* c2* e1* m5* n3 + b2* c4* e1* m5* n3 + b4* c1* e2* m5* n3 - 
       b1* c4* e2* m5* n3 - b2* c1* e4* m5* n3 + b1* c2* e4* m5* n3 - 
       b5* c3* e2* m1* n4 + b3* c5* e2* m1* n4 + b5* c2* e3* m1* n4 - 
       b2* c5* e3* m1* n4 - b3* c2* e5* m1* n4 + b2* c3* e5* m1* n4 + 
       b5* c3* e1* m2* n4 - b3* c5* e1* m2* n4 - b5* c1* e3* m2* n4 + 
       b1* c5* e3* m2* n4 + b3* c1* e5* m2* n4 - b1* c3* e5* m2* n4 - 
       b5* c2* e1* m3* n4 + b2* c5* e1* m3* n4 + b5* c1* e2* m3* n4 - 
       b1* c5* e2* m3* n4 - b2* c1* e5* m3* n4 + b1* c2* e5* m3* n4 + 
       b3* c2* e1* m5* n4 - b2* c3* e1* m5* n4 - b3* c1* e2* m5* n4 + 
       b1* c3* e2* m5* n4 + b2* c1* e3* m5* n4 - b1* c2* e3* m5* n4 + 
       b4* c3* e2* m1* n5 - b3* c4* e2* m1* n5 - b4* c2* e3* m1* n5 + 
       b2* c4* e3* m1* n5 + b3* c2* e4* m1* n5 - b2* c3* e4* m1* n5 - 
       b4* c3* e1* m2* n5 + b3* c4* e1* m2* n5 + b4* c1* e3* m2* n5 - 
       b1* c4* e3* m2* n5 - b3* c1* e4* m2* n5 + b1* c3* e4* m2* n5 + 
       b4* c2* e1* m3* n5 - b2* c4* e1* m3* n5 - b4* c1* e2* m3* n5 + 
       b1* c4* e2* m3* n5 + b2* c1* e4* m3* n5 - b1* c2* e4* m3* n5 - 
       b3* c2* e1* m4* n5 + b2* c3* e1* m4* n5 + b3* c1* e2* m4* n5 - 
       b1* c3* e2* m4* n5 - b2* c1* e3* m4* n5 + b1* c2* e3* m4* n5) + 
    c6* (b5* d4* e3* m2* n1 - b4* d5* e3* m2* n1 - b5* d3* e4* m2* n1 + 
       b3* d5* e4* m2* n1 + b4* d3* e5* m2* n1 - b3* d4* e5* m2* n1 - 
       b5* d4* e2* m3* n1 + b4* d5* e2* m3* n1 + b5* d2* e4* m3* n1 - 
       b2* d5* e4* m3* n1 - b4* d2* e5* m3* n1 + b2* d4* e5* m3* n1 + 
       b5* d3* e2* m4* n1 - b3* d5* e2* m4* n1 - b5* d2* e3* m4* n1 + 
       b2* d5* e3* m4* n1 + b3* d2* e5* m4* n1 - b2* d3* e5* m4* n1 - 
       b4* d3* e2* m5* n1 + b3* d4* e2* m5* n1 + b4* d2* e3* m5* n1 - 
       b2* d4* e3* m5* n1 - b3* d2* e4* m5* n1 + b2* d3* e4* m5* n1 - 
       b5* d4* e3* m1* n2 + b4* d5* e3* m1* n2 + b5* d3* e4* m1* n2 - 
       b3* d5* e4* m1* n2 - b4* d3* e5* m1* n2 + b3* d4* e5* m1* n2 + 
       b5* d4* e1* m3* n2 - b4* d5* e1* m3* n2 - b5* d1* e4* m3* n2 + 
       b1* d5* e4* m3* n2 + b4* d1* e5* m3* n2 - b1* d4* e5* m3* n2 - 
       b5* d3* e1* m4* n2 + b3* d5* e1* m4* n2 + b5* d1* e3* m4* n2 - 
       b1* d5* e3* m4* n2 - b3* d1* e5* m4* n2 + b1* d3* e5* m4* n2 + 
       b4* d3* e1* m5* n2 - b3* d4* e1* m5* n2 - b4* d1* e3* m5* n2 + 
       b1* d4* e3* m5* n2 + b3* d1* e4* m5* n2 - b1* d3* e4* m5* n2 + 
       b5* d4* e2* m1* n3 - b4* d5* e2* m1* n3 - b5* d2* e4* m1* n3 + 
       b2* d5* e4* m1* n3 + b4* d2* e5* m1* n3 - b2* d4* e5* m1* n3 - 
       b5* d4* e1* m2* n3 + b4* d5* e1* m2* n3 + b5* d1* e4* m2* n3 - 
       b1* d5* e4* m2* n3 - b4* d1* e5* m2* n3 + b1* d4* e5* m2* n3 + 
       b5* d2* e1* m4* n3 - b2* d5* e1* m4* n3 - b5* d1* e2* m4* n3 + 
       b1* d5* e2* m4* n3 + b2* d1* e5* m4* n3 - b1* d2* e5* m4* n3 - 
       b4* d2* e1* m5* n3 + b2* d4* e1* m5* n3 + b4* d1* e2* m5* n3 - 
       b1* d4* e2* m5* n3 - b2* d1* e4* m5* n3 + b1* d2* e4* m5* n3 - 
       b5* d3* e2* m1* n4 + b3* d5* e2* m1* n4 + b5* d2* e3* m1* n4 - 
       b2* d5* e3* m1* n4 - b3* d2* e5* m1* n4 + b2* d3* e5* m1* n4 + 
       b5* d3* e1* m2* n4 - b3* d5* e1* m2* n4 - b5* d1* e3* m2* n4 + 
       b1* d5* e3* m2* n4 + b3* d1* e5* m2* n4 - b1* d3* e5* m2* n4 - 
       b5* d2* e1* m3* n4 + b2* d5* e1* m3* n4 + b5* d1* e2* m3* n4 - 
       b1* d5* e2* m3* n4 - b2* d1* e5* m3* n4 + b1* d2* e5* m3* n4 + 
       b3* d2* e1* m5* n4 - b2* d3* e1* m5* n4 - b3* d1* e2* m5* n4 + 
       b1* d3* e2* m5* n4 + b2* d1* e3* m5* n4 - b1* d2* e3* m5* n4 + 
       b4* d3* e2* m1* n5 - b3* d4* e2* m1* n5 - b4* d2* e3* m1* n5 + 
       b2* d4* e3* m1* n5 + b3* d2* e4* m1* n5 - b2* d3* e4* m1* n5 - 
       b4* d3* e1* m2* n5 + b3* d4* e1* m2* n5 + b4* d1* e3* m2* n5 - 
       b1* d4* e3* m2* n5 - b3* d1* e4* m2* n5 + b1* d3* e4* m2* n5 + 
       b4* d2* e1* m3* n5 - b2* d4* e1* m3* n5 - b4* d1* e2* m3* n5 + 
       b1* d4* e2* m3* n5 + b2* d1* e4* m3* n5 - b1* d2* e4* m3* n5 - 
       b3* d2* e1* m4* n5 + b2* d3* e1* m4* n5 + b3* d1* e2* m4* n5 - 
       b1* d3* e2* m4* n5 - b2* d1* e3* m4* n5 + b1* d2* e3* m4* n5) - 
    b6* (c5* d4* e3* m2* n1 - c4* d5* e3* m2* n1 - c5* d3* e4* m2* n1 + 
       c3* d5* e4* m2* n1 + c4* d3* e5* m2* n1 - c3* d4* e5* m2* n1 - 
       c5* d4* e2* m3* n1 + c4* d5* e2* m3* n1 + c5* d2* e4* m3* n1 - 
       c2* d5* e4* m3* n1 - c4* d2* e5* m3* n1 + c2* d4* e5* m3* n1 + 
       c5* d3* e2* m4* n1 - c3* d5* e2* m4* n1 - c5* d2* e3* m4* n1 + 
       c2* d5* e3* m4* n1 + c3* d2* e5* m4* n1 - c2* d3* e5* m4* n1 - 
       c4* d3* e2* m5* n1 + c3* d4* e2* m5* n1 + c4* d2* e3* m5* n1 - 
       c2* d4* e3* m5* n1 - c3* d2* e4* m5* n1 + c2* d3* e4* m5* n1 - 
       c5* d4* e3* m1* n2 + c4* d5* e3* m1* n2 + c5* d3* e4* m1* n2 - 
       c3* d5* e4* m1* n2 - c4* d3* e5* m1* n2 + c3* d4* e5* m1* n2 + 
       c5* d4* e1* m3* n2 - c4* d5* e1* m3* n2 - c5* d1* e4* m3* n2 + 
       c1* d5* e4* m3* n2 + c4* d1* e5* m3* n2 - c1* d4* e5* m3* n2 - 
       c5* d3* e1* m4* n2 + c3* d5* e1* m4* n2 + c5* d1* e3* m4* n2 - 
       c1* d5* e3* m4* n2 - c3* d1* e5* m4* n2 + c1* d3* e5* m4* n2 + 
       c4* d3* e1* m5* n2 - c3* d4* e1* m5* n2 - c4* d1* e3* m5* n2 + 
       c1* d4* e3* m5* n2 + c3* d1* e4* m5* n2 - c1* d3* e4* m5* n2 + 
       c5* d4* e2* m1* n3 - c4* d5* e2* m1* n3 - c5* d2* e4* m1* n3 + 
       c2* d5* e4* m1* n3 + c4* d2* e5* m1* n3 - c2* d4* e5* m1* n3 - 
       c5* d4* e1* m2* n3 + c4* d5* e1* m2* n3 + c5* d1* e4* m2* n3 - 
       c1* d5* e4* m2* n3 - c4* d1* e5* m2* n3 + c1* d4* e5* m2* n3 + 
       c5* d2* e1* m4* n3 - c2* d5* e1* m4* n3 - c5* d1* e2* m4* n3 + 
       c1* d5* e2* m4* n3 + c2* d1* e5* m4* n3 - c1* d2* e5* m4* n3 - 
       c4* d2* e1* m5* n3 + c2* d4* e1* m5* n3 + c4* d1* e2* m5* n3 - 
       c1* d4* e2* m5* n3 - c2* d1* e4* m5* n3 + c1* d2* e4* m5* n3 - 
       c5* d3* e2* m1* n4 + c3* d5* e2* m1* n4 + c5* d2* e3* m1* n4 - 
       c2* d5* e3* m1* n4 - c3* d2* e5* m1* n4 + c2* d3* e5* m1* n4 + 
       c5* d3* e1* m2* n4 - c3* d5* e1* m2* n4 - c5* d1* e3* m2* n4 + 
       c1* d5* e3* m2* n4 + c3* d1* e5* m2* n4 - c1* d3* e5* m2* n4 - 
       c5* d2* e1* m3* n4 + c2* d5* e1* m3* n4 + c5* d1* e2* m3* n4 - 
       c1* d5* e2* m3* n4 - c2* d1* e5* m3* n4 + c1* d2* e5* m3* n4 + 
       c3* d2* e1* m5* n4 - c2* d3* e1* m5* n4 - c3* d1* e2* m5* n4 + 
       c1* d3* e2* m5* n4 + c2* d1* e3* m5* n4 - c1* d2* e3* m5* n4 + 
       c4* d3* e2* m1* n5 - c3* d4* e2* m1* n5 - c4* d2* e3* m1* n5 + 
       c2* d4* e3* m1* n5 + c3* d2* e4* m1* n5 - c2* d3* e4* m1* n5 - 
       c4* d3* e1* m2* n5 + c3* d4* e1* m2* n5 + c4* d1* e3* m2* n5 - 
       c1* d4* e3* m2* n5 - c3* d1* e4* m2* n5 + c1* d3* e4* m2* n5 + 
       c4* d2* e1* m3* n5 - c2* d4* e1* m3* n5 - c4* d1* e2* m3* n5 + 
       c1* d4* e2* m3* n5 + c2* d1* e4* m3* n5 - c1* d2* e4* m3* n5 - 
       c3* d2* e1* m4* n5 + c2* d3* e1* m4* n5 + c3* d1* e2* m4* n5 - 
       c1* d3* e2* m4* n5 - c2* d1* e3* m4* n5 + 
       c1* d2* e3* m4* n5) + (b5* c4* d3* e2* m1 - b4* c5* d3* e2* m1 - 
       b5* c3* d4* e2* m1 + b3* c5* d4* e2* m1 + b4* c3* d5* e2* m1 - 
       b3* c4* d5* e2* m1 - b5* c4* d2* e3* m1 + b4* c5* d2* e3* m1 + 
       b5* c2* d4* e3* m1 - b2* c5* d4* e3* m1 - b4* c2* d5* e3* m1 + 
       b2* c4* d5* e3* m1 + b5* c3* d2* e4* m1 - b3* c5* d2* e4* m1 - 
       b5* c2* d3* e4* m1 + b2* c5* d3* e4* m1 + b3* c2* d5* e4* m1 - 
       b2* c3* d5* e4* m1 - b4* c3* d2* e5* m1 + b3* c4* d2* e5* m1 + 
       b4* c2* d3* e5* m1 - b2* c4* d3* e5* m1 - b3* c2* d4* e5* m1 + 
       b2* c3* d4* e5* m1 - b5* c4* d3* e1* m2 + b4* c5* d3* e1* m2 + 
       b5* c3* d4* e1* m2 - b3* c5* d4* e1* m2 - b4* c3* d5* e1* m2 + 
       b3* c4* d5* e1* m2 + b5* c4* d1* e3* m2 - b4* c5* d1* e3* m2 - 
       b5* c1* d4* e3* m2 + b1* c5* d4* e3* m2 + b4* c1* d5* e3* m2 - 
       b1* c4* d5* e3* m2 - b5* c3* d1* e4* m2 + b3* c5* d1* e4* m2 + 
       b5* c1* d3* e4* m2 - b1* c5* d3* e4* m2 - b3* c1* d5* e4* m2 + 
       b1* c3* d5* e4* m2 + b4* c3* d1* e5* m2 - b3* c4* d1* e5* m2 - 
       b4* c1* d3* e5* m2 + b1* c4* d3* e5* m2 + b3* c1* d4* e5* m2 - 
       b1* c3* d4* e5* m2 + b5* c4* d2* e1* m3 - b4* c5* d2* e1* m3 - 
       b5* c2* d4* e1* m3 + b2* c5* d4* e1* m3 + b4* c2* d5* e1* m3 - 
       b2* c4* d5* e1* m3 - b5* c4* d1* e2* m3 + b4* c5* d1* e2* m3 + 
       b5* c1* d4* e2* m3 - b1* c5* d4* e2* m3 - b4* c1* d5* e2* m3 + 
       b1* c4* d5* e2* m3 + b5* c2* d1* e4* m3 - b2* c5* d1* e4* m3 - 
       b5* c1* d2* e4* m3 + b1* c5* d2* e4* m3 + b2* c1* d5* e4* m3 - 
       b1* c2* d5* e4* m3 - b4* c2* d1* e5* m3 + b2* c4* d1* e5* m3 + 
       b4* c1* d2* e5* m3 - b1* c4* d2* e5* m3 - b2* c1* d4* e5* m3 + 
       b1* c2* d4* e5* m3 - b5* c3* d2* e1* m4 + b3* c5* d2* e1* m4 + 
       b5* c2* d3* e1* m4 - b2* c5* d3* e1* m4 - b3* c2* d5* e1* m4 + 
       b2* c3* d5* e1* m4 + b5* c3* d1* e2* m4 - b3* c5* d1* e2* m4 - 
       b5* c1* d3* e2* m4 + b1* c5* d3* e2* m4 + b3* c1* d5* e2* m4 - 
       b1* c3* d5* e2* m4 - b5* c2* d1* e3* m4 + b2* c5* d1* e3* m4 + 
       b5* c1* d2* e3* m4 - b1* c5* d2* e3* m4 - b2* c1* d5* e3* m4 + 
       b1* c2* d5* e3* m4 + b3* c2* d1* e5* m4 - b2* c3* d1* e5* m4 - 
       b3* c1* d2* e5* m4 + b1* c3* d2* e5* m4 + b2* c1* d3* e5* m4 - 
       b1* c2* d3* e5* m4 + b4* c3* d2* e1* m5 - b3* c4* d2* e1* m5 - 
       b4* c2* d3* e1* m5 + b2* c4* d3* e1* m5 + b3* c2* d4* e1* m5 - 
       b2* c3* d4* e1* m5 - b4* c3* d1* e2* m5 + b3* c4* d1* e2* m5 + 
       b4* c1* d3* e2* m5 - b1* c4* d3* e2* m5 - b3* c1* d4* e2* m5 + 
       b1* c3* d4* e2* m5 + b4* c2* d1* e3* m5 - b2* c4* d1* e3* m5 - 
       b4* c1* d2* e3* m5 + b1* c4* d2* e3* m5 + b2* c1* d4* e3* m5 - 
       b1* c2* d4* e3* m5 - b3* c2* d1* e4* m5 + b2* c3* d1* e4* m5 + 
       b3* c1* d2* e4* m5 - b1* c3* d2* e4* m5 - b2* c1* d3* e4* m5 + 
       b1* c2* d3* e4* m5) *n6) + (-e6* (a5* b4* c3* d2* m1 - a4* b5* c3* d2* m1 - 
       a5* b3* c4* d2* m1 + a3* b5* c4* d2* m1 + a4* b3* c5* d2* m1 - 
       a3* b4* c5* d2* m1 - a5* b4* c2* d3* m1 + a4* b5* c2* d3* m1 + 
       a5* b2* c4* d3* m1 - a2* b5* c4* d3* m1 - a4* b2* c5* d3* m1 + 
       a2* b4* c5* d3* m1 + a5* b3* c2* d4* m1 - a3* b5* c2* d4* m1 - 
       a5* b2* c3* d4* m1 + a2* b5* c3* d4* m1 + a3* b2* c5* d4* m1 - 
       a2* b3* c5* d4* m1 - a4* b3* c2* d5* m1 + a3* b4* c2* d5* m1 + 
       a4* b2* c3* d5* m1 - a2* b4* c3* d5* m1 - a3* b2* c4* d5* m1 + 
       a2* b3* c4* d5* m1 - a5* b4* c3* d1* m2 + a4* b5* c3* d1* m2 + 
       a5* b3* c4* d1* m2 - a3* b5* c4* d1* m2 - a4* b3* c5* d1* m2 + 
       a3* b4* c5* d1* m2 + a5* b4* c1* d3* m2 - a4* b5* c1* d3* m2 - 
       a5* b1* c4* d3* m2 + a1* b5* c4* d3* m2 + a4* b1* c5* d3* m2 - 
       a1* b4* c5* d3* m2 - a5* b3* c1* d4* m2 + a3* b5* c1* d4* m2 + 
       a5* b1* c3* d4* m2 - a1* b5* c3* d4* m2 - a3* b1* c5* d4* m2 + 
       a1* b3* c5* d4* m2 + a4* b3* c1* d5* m2 - a3* b4* c1* d5* m2 - 
       a4* b1* c3* d5* m2 + a1* b4* c3* d5* m2 + a3* b1* c4* d5* m2 - 
       a1* b3* c4* d5* m2 + a5* b4* c2* d1* m3 - a4* b5* c2* d1* m3 - 
       a5* b2* c4* d1* m3 + a2* b5* c4* d1* m3 + a4* b2* c5* d1* m3 - 
       a2* b4* c5* d1* m3 - a5* b4* c1* d2* m3 + a4* b5* c1* d2* m3 + 
       a5* b1* c4* d2* m3 - a1* b5* c4* d2* m3 - a4* b1* c5* d2* m3 + 
       a1* b4* c5* d2* m3 + a5* b2* c1* d4* m3 - a2* b5* c1* d4* m3 - 
       a5* b1* c2* d4* m3 + a1* b5* c2* d4* m3 + a2* b1* c5* d4* m3 - 
       a1* b2* c5* d4* m3 - a4* b2* c1* d5* m3 + a2* b4* c1* d5* m3 + 
       a4* b1* c2* d5* m3 - a1* b4* c2* d5* m3 - a2* b1* c4* d5* m3 + 
       a1* b2* c4* d5* m3 - a5* b3* c2* d1* m4 + a3* b5* c2* d1* m4 + 
       a5* b2* c3* d1* m4 - a2* b5* c3* d1* m4 - a3* b2* c5* d1* m4 + 
       a2* b3* c5* d1* m4 + a5* b3* c1* d2* m4 - a3* b5* c1* d2* m4 - 
       a5* b1* c3* d2* m4 + a1* b5* c3* d2* m4 + a3* b1* c5* d2* m4 - 
       a1* b3* c5* d2* m4 - a5* b2* c1* d3* m4 + a2* b5* c1* d3* m4 + 
       a5* b1* c2* d3* m4 - a1* b5* c2* d3* m4 - a2* b1* c5* d3* m4 + 
       a1* b2* c5* d3* m4 + a3* b2* c1* d5* m4 - a2* b3* c1* d5* m4 - 
       a3* b1* c2* d5* m4 + a1* b3* c2* d5* m4 + a2* b1* c3* d5* m4 - 
       a1* b2* c3* d5* m4 + a4* b3* c2* d1* m5 - a3* b4* c2* d1* m5 - 
       a4* b2* c3* d1* m5 + a2* b4* c3* d1* m5 + a3* b2* c4* d1* m5 - 
       a2* b3* c4* d1* m5 - a4* b3* c1* d2* m5 + a3* b4* c1* d2* m5 + 
       a4* b1* c3* d2* m5 - a1* b4* c3* d2* m5 - a3* b1* c4* d2* m5 + 
       a1* b3* c4* d2* m5 + a4* b2* c1* d3* m5 - a2* b4* c1* d3* m5 - 
       a4* b1* c2* d3* m5 + a1* b4* c2* d3* m5 + a2* b1* c4* d3* m5 - 
       a1* b2* c4* d3* m5 - a3* b2* c1* d4* m5 + a2* b3* c1* d4* m5 + 
       a3* b1* c2* d4* m5 - a1* b3* c2* d4* m5 - a2* b1* c3* d4* m5 + 
       a1* b2* c3* d4* m5) + 
    d6* (a5* b4* c3* e2* m1 - a4* b5* c3* e2* m1 - a5* b3* c4* e2* m1 + 
       a3* b5* c4* e2* m1 + a4* b3* c5* e2* m1 - a3* b4* c5* e2* m1 - 
       a5* b4* c2* e3* m1 + a4* b5* c2* e3* m1 + a5* b2* c4* e3* m1 - 
       a2* b5* c4* e3* m1 - a4* b2* c5* e3* m1 + a2* b4* c5* e3* m1 + 
       a5* b3* c2* e4* m1 - a3* b5* c2* e4* m1 - a5* b2* c3* e4* m1 + 
       a2* b5* c3* e4* m1 + a3* b2* c5* e4* m1 - a2* b3* c5* e4* m1 - 
       a4* b3* c2* e5* m1 + a3* b4* c2* e5* m1 + a4* b2* c3* e5* m1 - 
       a2* b4* c3* e5* m1 - a3* b2* c4* e5* m1 + a2* b3* c4* e5* m1 - 
       a5* b4* c3* e1* m2 + a4* b5* c3* e1* m2 + a5* b3* c4* e1* m2 - 
       a3* b5* c4* e1* m2 - a4* b3* c5* e1* m2 + a3* b4* c5* e1* m2 + 
       a5* b4* c1* e3* m2 - a4* b5* c1* e3* m2 - a5* b1* c4* e3* m2 + 
       a1* b5* c4* e3* m2 + a4* b1* c5* e3* m2 - a1* b4* c5* e3* m2 - 
       a5* b3* c1* e4* m2 + a3* b5* c1* e4* m2 + a5* b1* c3* e4* m2 - 
       a1* b5* c3* e4* m2 - a3* b1* c5* e4* m2 + a1* b3* c5* e4* m2 + 
       a4* b3* c1* e5* m2 - a3* b4* c1* e5* m2 - a4* b1* c3* e5* m2 + 
       a1* b4* c3* e5* m2 + a3* b1* c4* e5* m2 - a1* b3* c4* e5* m2 + 
       a5* b4* c2* e1* m3 - a4* b5* c2* e1* m3 - a5* b2* c4* e1* m3 + 
       a2* b5* c4* e1* m3 + a4* b2* c5* e1* m3 - a2* b4* c5* e1* m3 - 
       a5* b4* c1* e2* m3 + a4* b5* c1* e2* m3 + a5* b1* c4* e2* m3 - 
       a1* b5* c4* e2* m3 - a4* b1* c5* e2* m3 + a1* b4* c5* e2* m3 + 
       a5* b2* c1* e4* m3 - a2* b5* c1* e4* m3 - a5* b1* c2* e4* m3 + 
       a1* b5* c2* e4* m3 + a2* b1* c5* e4* m3 - a1* b2* c5* e4* m3 - 
       a4* b2* c1* e5* m3 + a2* b4* c1* e5* m3 + a4* b1* c2* e5* m3 - 
       a1* b4* c2* e5* m3 - a2* b1* c4* e5* m3 + a1* b2* c4* e5* m3 - 
       a5* b3* c2* e1* m4 + a3* b5* c2* e1* m4 + a5* b2* c3* e1* m4 - 
       a2* b5* c3* e1* m4 - a3* b2* c5* e1* m4 + a2* b3* c5* e1* m4 + 
       a5* b3* c1* e2* m4 - a3* b5* c1* e2* m4 - a5* b1* c3* e2* m4 + 
       a1* b5* c3* e2* m4 + a3* b1* c5* e2* m4 - a1* b3* c5* e2* m4 - 
       a5* b2* c1* e3* m4 + a2* b5* c1* e3* m4 + a5* b1* c2* e3* m4 - 
       a1* b5* c2* e3* m4 - a2* b1* c5* e3* m4 + a1* b2* c5* e3* m4 + 
       a3* b2* c1* e5* m4 - a2* b3* c1* e5* m4 - a3* b1* c2* e5* m4 + 
       a1* b3* c2* e5* m4 + a2* b1* c3* e5* m4 - a1* b2* c3* e5* m4 + 
       a4* b3* c2* e1* m5 - a3* b4* c2* e1* m5 - a4* b2* c3* e1* m5 + 
       a2* b4* c3* e1* m5 + a3* b2* c4* e1* m5 - a2* b3* c4* e1* m5 - 
       a4* b3* c1* e2* m5 + a3* b4* c1* e2* m5 + a4* b1* c3* e2* m5 - 
       a1* b4* c3* e2* m5 - a3* b1* c4* e2* m5 + a1* b3* c4* e2* m5 + 
       a4* b2* c1* e3* m5 - a2* b4* c1* e3* m5 - a4* b1* c2* e3* m5 + 
       a1* b4* c2* e3* m5 + a2* b1* c4* e3* m5 - a1* b2* c4* e3* m5 - 
       a3* b2* c1* e4* m5 + a2* b3* c1* e4* m5 + a3* b1* c2* e4* m5 - 
       a1* b3* c2* e4* m5 - a2* b1* c3* e4* m5 + a1* b2* c3* e4* m5) - 
    c6* (a5* b4* d3* e2* m1 - a4* b5* d3* e2* m1 - a5* b3* d4* e2* m1 + 
       a3* b5* d4* e2* m1 + a4* b3* d5* e2* m1 - a3* b4* d5* e2* m1 - 
       a5* b4* d2* e3* m1 + a4* b5* d2* e3* m1 + a5* b2* d4* e3* m1 - 
       a2* b5* d4* e3* m1 - a4* b2* d5* e3* m1 + a2* b4* d5* e3* m1 + 
       a5* b3* d2* e4* m1 - a3* b5* d2* e4* m1 - a5* b2* d3* e4* m1 + 
       a2* b5* d3* e4* m1 + a3* b2* d5* e4* m1 - a2* b3* d5* e4* m1 - 
       a4* b3* d2* e5* m1 + a3* b4* d2* e5* m1 + a4* b2* d3* e5* m1 - 
       a2* b4* d3* e5* m1 - a3* b2* d4* e5* m1 + a2* b3* d4* e5* m1 - 
       a5* b4* d3* e1* m2 + a4* b5* d3* e1* m2 + a5* b3* d4* e1* m2 - 
       a3* b5* d4* e1* m2 - a4* b3* d5* e1* m2 + a3* b4* d5* e1* m2 + 
       a5* b4* d1* e3* m2 - a4* b5* d1* e3* m2 - a5* b1* d4* e3* m2 + 
       a1* b5* d4* e3* m2 + a4* b1* d5* e3* m2 - a1* b4* d5* e3* m2 - 
       a5* b3* d1* e4* m2 + a3* b5* d1* e4* m2 + a5* b1* d3* e4* m2 - 
       a1* b5* d3* e4* m2 - a3* b1* d5* e4* m2 + a1* b3* d5* e4* m2 + 
       a4* b3* d1* e5* m2 - a3* b4* d1* e5* m2 - a4* b1* d3* e5* m2 + 
       a1* b4* d3* e5* m2 + a3* b1* d4* e5* m2 - a1* b3* d4* e5* m2 + 
       a5* b4* d2* e1* m3 - a4* b5* d2* e1* m3 - a5* b2* d4* e1* m3 + 
       a2* b5* d4* e1* m3 + a4* b2* d5* e1* m3 - a2* b4* d5* e1* m3 - 
       a5* b4* d1* e2* m3 + a4* b5* d1* e2* m3 + a5* b1* d4* e2* m3 - 
       a1* b5* d4* e2* m3 - a4* b1* d5* e2* m3 + a1* b4* d5* e2* m3 + 
       a5* b2* d1* e4* m3 - a2* b5* d1* e4* m3 - a5* b1* d2* e4* m3 + 
       a1* b5* d2* e4* m3 + a2* b1* d5* e4* m3 - a1* b2* d5* e4* m3 - 
       a4* b2* d1* e5* m3 + a2* b4* d1* e5* m3 + a4* b1* d2* e5* m3 - 
       a1* b4* d2* e5* m3 - a2* b1* d4* e5* m3 + a1* b2* d4* e5* m3 - 
       a5* b3* d2* e1* m4 + a3* b5* d2* e1* m4 + a5* b2* d3* e1* m4 - 
       a2* b5* d3* e1* m4 - a3* b2* d5* e1* m4 + a2* b3* d5* e1* m4 + 
       a5* b3* d1* e2* m4 - a3* b5* d1* e2* m4 - a5* b1* d3* e2* m4 + 
       a1* b5* d3* e2* m4 + a3* b1* d5* e2* m4 - a1* b3* d5* e2* m4 - 
       a5* b2* d1* e3* m4 + a2* b5* d1* e3* m4 + a5* b1* d2* e3* m4 - 
       a1* b5* d2* e3* m4 - a2* b1* d5* e3* m4 + a1* b2* d5* e3* m4 + 
       a3* b2* d1* e5* m4 - a2* b3* d1* e5* m4 - a3* b1* d2* e5* m4 + 
       a1* b3* d2* e5* m4 + a2* b1* d3* e5* m4 - a1* b2* d3* e5* m4 + 
       a4* b3* d2* e1* m5 - a3* b4* d2* e1* m5 - a4* b2* d3* e1* m5 + 
       a2* b4* d3* e1* m5 + a3* b2* d4* e1* m5 - a2* b3* d4* e1* m5 - 
       a4* b3* d1* e2* m5 + a3* b4* d1* e2* m5 + a4* b1* d3* e2* m5 - 
       a1* b4* d3* e2* m5 - a3* b1* d4* e2* m5 + a1* b3* d4* e2* m5 + 
       a4* b2* d1* e3* m5 - a2* b4* d1* e3* m5 - a4* b1* d2* e3* m5 + 
       a1* b4* d2* e3* m5 + a2* b1* d4* e3* m5 - a1* b2* d4* e3* m5 - 
       a3* b2* d1* e4* m5 + a2* b3* d1* e4* m5 + a3* b1* d2* e4* m5 - 
       a1* b3* d2* e4* m5 - a2* b1* d3* e4* m5 + a1* b2* d3* e4* m5) + 
    b6* (a5* c4* d3* e2* m1 - a4* c5* d3* e2* m1 - a5* c3* d4* e2* m1 + 
       a3* c5* d4* e2* m1 + a4* c3* d5* e2* m1 - a3* c4* d5* e2* m1 - 
       a5* c4* d2* e3* m1 + a4* c5* d2* e3* m1 + a5* c2* d4* e3* m1 - 
       a2* c5* d4* e3* m1 - a4* c2* d5* e3* m1 + a2* c4* d5* e3* m1 + 
       a5* c3* d2* e4* m1 - a3* c5* d2* e4* m1 - a5* c2* d3* e4* m1 + 
       a2* c5* d3* e4* m1 + a3* c2* d5* e4* m1 - a2* c3* d5* e4* m1 - 
       a4* c3* d2* e5* m1 + a3* c4* d2* e5* m1 + a4* c2* d3* e5* m1 - 
       a2* c4* d3* e5* m1 - a3* c2* d4* e5* m1 + a2* c3* d4* e5* m1 - 
       a5* c4* d3* e1* m2 + a4* c5* d3* e1* m2 + a5* c3* d4* e1* m2 - 
       a3* c5* d4* e1* m2 - a4* c3* d5* e1* m2 + a3* c4* d5* e1* m2 + 
       a5* c4* d1* e3* m2 - a4* c5* d1* e3* m2 - a5* c1* d4* e3* m2 + 
       a1* c5* d4* e3* m2 + a4* c1* d5* e3* m2 - a1* c4* d5* e3* m2 - 
       a5* c3* d1* e4* m2 + a3* c5* d1* e4* m2 + a5* c1* d3* e4* m2 - 
       a1* c5* d3* e4* m2 - a3* c1* d5* e4* m2 + a1* c3* d5* e4* m2 + 
       a4* c3* d1* e5* m2 - a3* c4* d1* e5* m2 - a4* c1* d3* e5* m2 + 
       a1* c4* d3* e5* m2 + a3* c1* d4* e5* m2 - a1* c3* d4* e5* m2 + 
       a5* c4* d2* e1* m3 - a4* c5* d2* e1* m3 - a5* c2* d4* e1* m3 + 
       a2* c5* d4* e1* m3 + a4* c2* d5* e1* m3 - a2* c4* d5* e1* m3 - 
       a5* c4* d1* e2* m3 + a4* c5* d1* e2* m3 + a5* c1* d4* e2* m3 - 
       a1* c5* d4* e2* m3 - a4* c1* d5* e2* m3 + a1* c4* d5* e2* m3 + 
       a5* c2* d1* e4* m3 - a2* c5* d1* e4* m3 - a5* c1* d2* e4* m3 + 
       a1* c5* d2* e4* m3 + a2* c1* d5* e4* m3 - a1* c2* d5* e4* m3 - 
       a4* c2* d1* e5* m3 + a2* c4* d1* e5* m3 + a4* c1* d2* e5* m3 - 
       a1* c4* d2* e5* m3 - a2* c1* d4* e5* m3 + a1* c2* d4* e5* m3 - 
       a5* c3* d2* e1* m4 + a3* c5* d2* e1* m4 + a5* c2* d3* e1* m4 - 
       a2* c5* d3* e1* m4 - a3* c2* d5* e1* m4 + a2* c3* d5* e1* m4 + 
       a5* c3* d1* e2* m4 - a3* c5* d1* e2* m4 - a5* c1* d3* e2* m4 + 
       a1* c5* d3* e2* m4 + a3* c1* d5* e2* m4 - a1* c3* d5* e2* m4 - 
       a5* c2* d1* e3* m4 + a2* c5* d1* e3* m4 + a5* c1* d2* e3* m4 - 
       a1* c5* d2* e3* m4 - a2* c1* d5* e3* m4 + a1* c2* d5* e3* m4 + 
       a3* c2* d1* e5* m4 - a2* c3* d1* e5* m4 - a3* c1* d2* e5* m4 + 
       a1* c3* d2* e5* m4 + a2* c1* d3* e5* m4 - a1* c2* d3* e5* m4 + 
       a4* c3* d2* e1* m5 - a3* c4* d2* e1* m5 - a4* c2* d3* e1* m5 + 
       a2* c4* d3* e1* m5 + a3* c2* d4* e1* m5 - a2* c3* d4* e1* m5 - 
       a4* c3* d1* e2* m5 + a3* c4* d1* e2* m5 + a4* c1* d3* e2* m5 - 
       a1* c4* d3* e2* m5 - a3* c1* d4* e2* m5 + a1* c3* d4* e2* m5 + 
       a4* c2* d1* e3* m5 - a2* c4* d1* e3* m5 - a4* c1* d2* e3* m5 + 
       a1* c4* d2* e3* m5 + a2* c1* d4* e3* m5 - a1* c2* d4* e3* m5 - 
       a3* c2* d1* e4* m5 + a2* c3* d1* e4* m5 + a3* c1* d2* e4* m5 - 
       a1* c3* d2* e4* m5 - a2* c1* d3* e4* m5 + a1* c2* d3* e4* m5) - 
    a6* (b5* c4* d3* e2* m1 - b4* c5* d3* e2* m1 - b5* c3* d4* e2* m1 + 
       b3* c5* d4* e2* m1 + b4* c3* d5* e2* m1 - b3* c4* d5* e2* m1 - 
       b5* c4* d2* e3* m1 + b4* c5* d2* e3* m1 + b5* c2* d4* e3* m1 - 
       b2* c5* d4* e3* m1 - b4* c2* d5* e3* m1 + b2* c4* d5* e3* m1 + 
       b5* c3* d2* e4* m1 - b3* c5* d2* e4* m1 - b5* c2* d3* e4* m1 + 
       b2* c5* d3* e4* m1 + b3* c2* d5* e4* m1 - b2* c3* d5* e4* m1 - 
       b4* c3* d2* e5* m1 + b3* c4* d2* e5* m1 + b4* c2* d3* e5* m1 - 
       b2* c4* d3* e5* m1 - b3* c2* d4* e5* m1 + b2* c3* d4* e5* m1 - 
       b5* c4* d3* e1* m2 + b4* c5* d3* e1* m2 + b5* c3* d4* e1* m2 - 
       b3* c5* d4* e1* m2 - b4* c3* d5* e1* m2 + b3* c4* d5* e1* m2 + 
       b5* c4* d1* e3* m2 - b4* c5* d1* e3* m2 - b5* c1* d4* e3* m2 + 
       b1* c5* d4* e3* m2 + b4* c1* d5* e3* m2 - b1* c4* d5* e3* m2 - 
       b5* c3* d1* e4* m2 + b3* c5* d1* e4* m2 + b5* c1* d3* e4* m2 - 
       b1* c5* d3* e4* m2 - b3* c1* d5* e4* m2 + b1* c3* d5* e4* m2 + 
       b4* c3* d1* e5* m2 - b3* c4* d1* e5* m2 - b4* c1* d3* e5* m2 + 
       b1* c4* d3* e5* m2 + b3* c1* d4* e5* m2 - b1* c3* d4* e5* m2 + 
       b5* c4* d2* e1* m3 - b4* c5* d2* e1* m3 - b5* c2* d4* e1* m3 + 
       b2* c5* d4* e1* m3 + b4* c2* d5* e1* m3 - b2* c4* d5* e1* m3 - 
       b5* c4* d1* e2* m3 + b4* c5* d1* e2* m3 + b5* c1* d4* e2* m3 - 
       b1* c5* d4* e2* m3 - b4* c1* d5* e2* m3 + b1* c4* d5* e2* m3 + 
       b5* c2* d1* e4* m3 - b2* c5* d1* e4* m3 - b5* c1* d2* e4* m3 + 
       b1* c5* d2* e4* m3 + b2* c1* d5* e4* m3 - b1* c2* d5* e4* m3 - 
       b4* c2* d1* e5* m3 + b2* c4* d1* e5* m3 + b4* c1* d2* e5* m3 - 
       b1* c4* d2* e5* m3 - b2* c1* d4* e5* m3 + b1* c2* d4* e5* m3 - 
       b5* c3* d2* e1* m4 + b3* c5* d2* e1* m4 + b5* c2* d3* e1* m4 - 
       b2* c5* d3* e1* m4 - b3* c2* d5* e1* m4 + b2* c3* d5* e1* m4 + 
       b5* c3* d1* e2* m4 - b3* c5* d1* e2* m4 - b5* c1* d3* e2* m4 + 
       b1* c5* d3* e2* m4 + b3* c1* d5* e2* m4 - b1* c3* d5* e2* m4 - 
       b5* c2* d1* e3* m4 + b2* c5* d1* e3* m4 + b5* c1* d2* e3* m4 - 
       b1* c5* d2* e3* m4 - b2* c1* d5* e3* m4 + b1* c2* d5* e3* m4 + 
       b3* c2* d1* e5* m4 - b2* c3* d1* e5* m4 - b3* c1* d2* e5* m4 + 
       b1* c3* d2* e5* m4 + b2* c1* d3* e5* m4 - b1* c2* d3* e5* m4 + 
       b4* c3* d2* e1* m5 - b3* c4* d2* e1* m5 - b4* c2* d3* e1* m5 + 
       b2* c4* d3* e1* m5 + b3* c2* d4* e1* m5 - b2* c3* d4* e1* m5 - 
       b4* c3* d1* e2* m5 + b3* c4* d1* e2* m5 + b4* c1* d3* e2* m5 - 
       b1* c4* d3* e2* m5 - b3* c1* d4* e2* m5 + b1* c3* d4* e2* m5 + 
       b4* c2* d1* e3* m5 - b2* c4* d1* e3* m5 - b4* c1* d2* e3* m5 + 
       b1* c4* d2* e3* m5 + b2* c1* d4* e3* m5 - b1* c2* d4* e3* m5 - 
       b3* c2* d1* e4* m5 + b2* c3* d1* e4* m5 + b3* c1* d2* e4* m5 - 
       b1* c3* d2* e4* m5 - b2* c1* d3* e4* m5 + 
       b1* c2* d3* e4* m5) + (a5* b4* c3* d2* e1 - a4* b5* c3* d2* e1 - 
       a5* b3* c4* d2* e1 + a3* b5* c4* d2* e1 + a4* b3* c5* d2* e1 - 
       a3* b4* c5* d2* e1 - a5* b4* c2* d3* e1 + a4* b5* c2* d3* e1 + 
       a5* b2* c4* d3* e1 - a2* b5* c4* d3* e1 - a4* b2* c5* d3* e1 + 
       a2* b4* c5* d3* e1 + a5* b3* c2* d4* e1 - a3* b5* c2* d4* e1 - 
       a5* b2* c3* d4* e1 + a2* b5* c3* d4* e1 + a3* b2* c5* d4* e1 - 
       a2* b3* c5* d4* e1 - a4* b3* c2* d5* e1 + a3* b4* c2* d5* e1 + 
       a4* b2* c3* d5* e1 - a2* b4* c3* d5* e1 - a3* b2* c4* d5* e1 + 
       a2* b3* c4* d5* e1 - a5* b4* c3* d1* e2 + a4* b5* c3* d1* e2 + 
       a5* b3* c4* d1* e2 - a3* b5* c4* d1* e2 - a4* b3* c5* d1* e2 + 
       a3* b4* c5* d1* e2 + a5* b4* c1* d3* e2 - a4* b5* c1* d3* e2 - 
       a5* b1* c4* d3* e2 + a1* b5* c4* d3* e2 + a4* b1* c5* d3* e2 - 
       a1* b4* c5* d3* e2 - a5* b3* c1* d4* e2 + a3* b5* c1* d4* e2 + 
       a5* b1* c3* d4* e2 - a1* b5* c3* d4* e2 - a3* b1* c5* d4* e2 + 
       a1* b3* c5* d4* e2 + a4* b3* c1* d5* e2 - a3* b4* c1* d5* e2 - 
       a4* b1* c3* d5* e2 + a1* b4* c3* d5* e2 + a3* b1* c4* d5* e2 - 
       a1* b3* c4* d5* e2 + a5* b4* c2* d1* e3 - a4* b5* c2* d1* e3 - 
       a5* b2* c4* d1* e3 + a2* b5* c4* d1* e3 + a4* b2* c5* d1* e3 - 
       a2* b4* c5* d1* e3 - a5* b4* c1* d2* e3 + a4* b5* c1* d2* e3 + 
       a5* b1* c4* d2* e3 - a1* b5* c4* d2* e3 - a4* b1* c5* d2* e3 + 
       a1* b4* c5* d2* e3 + a5* b2* c1* d4* e3 - a2* b5* c1* d4* e3 - 
       a5* b1* c2* d4* e3 + a1* b5* c2* d4* e3 + a2* b1* c5* d4* e3 - 
       a1* b2* c5* d4* e3 - a4* b2* c1* d5* e3 + a2* b4* c1* d5* e3 + 
       a4* b1* c2* d5* e3 - a1* b4* c2* d5* e3 - a2* b1* c4* d5* e3 + 
       a1* b2* c4* d5* e3 - a5* b3* c2* d1* e4 + a3* b5* c2* d1* e4 + 
       a5* b2* c3* d1* e4 - a2* b5* c3* d1* e4 - a3* b2* c5* d1* e4 + 
       a2* b3* c5* d1* e4 + a5* b3* c1* d2* e4 - a3* b5* c1* d2* e4 - 
       a5* b1* c3* d2* e4 + a1* b5* c3* d2* e4 + a3* b1* c5* d2* e4 - 
       a1* b3* c5* d2* e4 - a5* b2* c1* d3* e4 + a2* b5* c1* d3* e4 + 
       a5* b1* c2* d3* e4 - a1* b5* c2* d3* e4 - a2* b1* c5* d3* e4 + 
       a1* b2* c5* d3* e4 + a3* b2* c1* d5* e4 - a2* b3* c1* d5* e4 - 
       a3* b1* c2* d5* e4 + a1* b3* c2* d5* e4 + a2* b1* c3* d5* e4 - 
       a1* b2* c3* d5* e4 + a4* b3* c2* d1* e5 - a3* b4* c2* d1* e5 - 
       a4* b2* c3* d1* e5 + a2* b4* c3* d1* e5 + a3* b2* c4* d1* e5 - 
       a2* b3* c4* d1* e5 - a4* b3* c1* d2* e5 + a3* b4* c1* d2* e5 + 
       a4* b1* c3* d2* e5 - a1* b4* c3* d2* e5 - a3* b1* c4* d2* e5 + 
       a1* b3* c4* d2* e5 + a4* b2* c1* d3* e5 - a2* b4* c1* d3* e5 - 
       a4* b1* c2* d3* e5 + a1* b4* c2* d3* e5 + a2* b1* c4* d3* e5 - 
       a1* b2* c4* d3* e5 - a3* b2* c1* d4* e5 + a2* b3* c1* d4* e5 + 
       a3* b1* c2* d4* e5 - a1* b3* c2* d4* e5 - a2* b1* c3* d4* e5 + 
			  a1* b2* c3* d4* e5) *m6) *n7;

    if (p==0)
      detA = det;
    else if (p==1)
      detB[0]=det;
    else if (p==2)
      detB[1]=det;
    else if (p==3)
      detB[2]=det;
    else if (p==4)
      detB[3]=det;
    else if (p==5)
      detB[4]=det;
    else if (p==6)
      detB[5]=det;
    else
      detB[6]=det;
    }

    }
    else if (pts==6) {

      for (p=0;p<(pts+1);p++) {
      
	if (p==0)
	  ;
	else if (p==1) {
	  a1 = f1; 
	  a2 = f2;
	  a3 = f3;
	  a4 = f4;
	  a5 = f5;
	  a6 = f6;
	}
	else if (p==2) {
 	  a1=a[0][0]; b1 = f1; 
          a2=a[1][0]; b2 = f2;
	  a3=a[2][0]; b3 = f3;
	  a4=a[3][0]; b4 = f4; 
	  a5=a[4][0]; b5 = f5;
	  a6=a[5][0]; b6 = f6;
        }
	else if (p==3) {
 	  b1=a[0][1]; c1 = f1; 
          b2=a[1][1]; c2 = f2;
	  b3=a[2][1]; c3 = f3;
	  b4=a[3][1]; c4 = f4; 
	  b5=a[4][1]; c5 = f5;
	  b6=a[5][1]; c6 = f6;
        }
	else if (p==4) {
 	  c1=a[0][2]; d1 = f1; 
          c2=a[1][2]; d2 = f2;
	  c3=a[2][2]; d3 = f3;
	  c4=a[3][2]; d4 = f4; 
	  c5=a[4][2]; d5 = f5;
	  c6=a[5][2]; d6 = f6;
        }
	else if (p==5) {
 	  d1=a[0][3]; e1 = f1; 
          d2=a[1][3]; e2 = f2;
	  d3=a[2][3]; e3 = f3;
	  d4=a[3][3]; e4 = f4; 
	  d5=a[4][3]; e5 = f5;
	  d6=a[5][3]; e6 = f6;
        }
	else { // case (p==6) 
 	  e1=a[0][4]; m1 = f1; 
          e2=a[1][4]; m2 = f2;
	  e3=a[2][4]; m3 = f3;
	  e4=a[3][4]; m4 = f4; 
	  e5=a[4][4]; m5 = f5;
	  e6=a[5][4]; m6 = f6;
        }
    	  
    det = -e6* (a5* b4* c3* d2* m1 - a4* b5* c3* d2* m1 - a5* b3* c4* d2* m1 + 
    a3* b5* c4* d2* m1 + a4* b3* c5* d2* m1 - a3* b4* c5* d2* m1 - 
    a5* b4* c2* d3* m1 + a4* b5* c2* d3* m1 + a5* b2* c4* d3* m1 - 
    a2* b5* c4* d3* m1 - a4* b2* c5* d3* m1 + a2* b4* c5* d3* m1 + 
    a5* b3* c2* d4* m1 - a3* b5* c2* d4* m1 - a5* b2* c3* d4* m1 + 
    a2* b5* c3* d4* m1 + a3* b2* c5* d4* m1 - a2* b3* c5* d4* m1 - 
    a4* b3* c2* d5* m1 + a3* b4* c2* d5* m1 + a4* b2* c3* d5* m1 - 
    a2* b4* c3* d5* m1 - a3* b2* c4* d5* m1 + a2* b3* c4* d5* m1 - 
    a5* b4* c3* d1* m2 + a4* b5* c3* d1* m2 + a5* b3* c4* d1* m2 - 
    a3* b5* c4* d1* m2 - a4* b3* c5* d1* m2 + a3* b4* c5* d1* m2 + 
    a5* b4* c1* d3* m2 - a4* b5* c1* d3* m2 - a5* b1* c4* d3* m2 + 
    a1* b5* c4* d3* m2 + a4* b1* c5* d3* m2 - a1* b4* c5* d3* m2 - 
    a5* b3* c1* d4* m2 + a3* b5* c1* d4* m2 + a5* b1* c3* d4* m2 - 
    a1* b5* c3* d4* m2 - a3* b1* c5* d4* m2 + a1* b3* c5* d4* m2 + 
    a4* b3* c1* d5* m2 - a3* b4* c1* d5* m2 - a4* b1* c3* d5* m2 + 
    a1* b4* c3* d5* m2 + a3* b1* c4* d5* m2 - a1* b3* c4* d5* m2 + 
    a5* b4* c2* d1* m3 - a4* b5* c2* d1* m3 - a5* b2* c4* d1* m3 + 
    a2* b5* c4* d1* m3 + a4* b2* c5* d1* m3 - a2* b4* c5* d1* m3 - 
    a5* b4* c1* d2* m3 + a4* b5* c1* d2* m3 + a5* b1* c4* d2* m3 - 
    a1* b5* c4* d2* m3 - a4* b1* c5* d2* m3 + a1* b4* c5* d2* m3 + 
    a5* b2* c1* d4* m3 - a2* b5* c1* d4* m3 - a5* b1* c2* d4* m3 + 
    a1* b5* c2* d4* m3 + a2* b1* c5* d4* m3 - a1* b2* c5* d4* m3 - 
    a4* b2* c1* d5* m3 + a2* b4* c1* d5* m3 + a4* b1* c2* d5* m3 - 
    a1* b4* c2* d5* m3 - a2* b1* c4* d5* m3 + a1* b2* c4* d5* m3 - 
    a5* b3* c2* d1* m4 + a3* b5* c2* d1* m4 + a5* b2* c3* d1* m4 - 
    a2* b5* c3* d1* m4 - a3* b2* c5* d1* m4 + a2* b3* c5* d1* m4 + 
    a5* b3* c1* d2* m4 - a3* b5* c1* d2* m4 - a5* b1* c3* d2* m4 + 
    a1* b5* c3* d2* m4 + a3* b1* c5* d2* m4 - a1* b3* c5* d2* m4 - 
    a5* b2* c1* d3* m4 + a2* b5* c1* d3* m4 + a5* b1* c2* d3* m4 - 
    a1* b5* c2* d3* m4 - a2* b1* c5* d3* m4 + a1* b2* c5* d3* m4 + 
    a3* b2* c1* d5* m4 - a2* b3* c1* d5* m4 - a3* b1* c2* d5* m4 + 
    a1* b3* c2* d5* m4 + a2* b1* c3* d5* m4 - a1* b2* c3* d5* m4 + 
    a4* b3* c2* d1* m5 - a3* b4* c2* d1* m5 - a4* b2* c3* d1* m5 + 
    a2* b4* c3* d1* m5 + a3* b2* c4* d1* m5 - a2* b3* c4* d1* m5 - 
    a4* b3* c1* d2* m5 + a3* b4* c1* d2* m5 + a4* b1* c3* d2* m5 - 
    a1* b4* c3* d2* m5 - a3* b1* c4* d2* m5 + a1* b3* c4* d2* m5 + 
    a4* b2* c1* d3* m5 - a2* b4* c1* d3* m5 - a4* b1* c2* d3* m5 + 
    a1* b4* c2* d3* m5 + a2* b1* c4* d3* m5 - a1* b2* c4* d3* m5 - 
    a3* b2* c1* d4* m5 + a2* b3* c1* d4* m5 + a3* b1* c2* d4* m5 - 
    a1* b3* c2* d4* m5 - a2* b1* c3* d4* m5 + a1* b2* c3* d4* m5) + 
 d6* (a5* b4* c3* e2* m1 - a4* b5* c3* e2* m1 - a5* b3* c4* e2* m1 + 
    a3* b5* c4* e2* m1 + a4* b3* c5* e2* m1 - a3* b4* c5* e2* m1 - 
    a5* b4* c2* e3* m1 + a4* b5* c2* e3* m1 + a5* b2* c4* e3* m1 - 
    a2* b5* c4* e3* m1 - a4* b2* c5* e3* m1 + a2* b4* c5* e3* m1 + 
    a5* b3* c2* e4* m1 - a3* b5* c2* e4* m1 - a5* b2* c3* e4* m1 + 
    a2* b5* c3* e4* m1 + a3* b2* c5* e4* m1 - a2* b3* c5* e4* m1 - 
    a4* b3* c2* e5* m1 + a3* b4* c2* e5* m1 + a4* b2* c3* e5* m1 - 
    a2* b4* c3* e5* m1 - a3* b2* c4* e5* m1 + a2* b3* c4* e5* m1 - 
    a5* b4* c3* e1* m2 + a4* b5* c3* e1* m2 + a5* b3* c4* e1* m2 - 
    a3* b5* c4* e1* m2 - a4* b3* c5* e1* m2 + a3* b4* c5* e1* m2 + 
    a5* b4* c1* e3* m2 - a4* b5* c1* e3* m2 - a5* b1* c4* e3* m2 + 
    a1* b5* c4* e3* m2 + a4* b1* c5* e3* m2 - a1* b4* c5* e3* m2 - 
    a5* b3* c1* e4* m2 + a3* b5* c1* e4* m2 + a5* b1* c3* e4* m2 - 
    a1* b5* c3* e4* m2 - a3* b1* c5* e4* m2 + a1* b3* c5* e4* m2 + 
    a4* b3* c1* e5* m2 - a3* b4* c1* e5* m2 - a4* b1* c3* e5* m2 + 
    a1* b4* c3* e5* m2 + a3* b1* c4* e5* m2 - a1* b3* c4* e5* m2 + 
    a5* b4* c2* e1* m3 - a4* b5* c2* e1* m3 - a5* b2* c4* e1* m3 + 
    a2* b5* c4* e1* m3 + a4* b2* c5* e1* m3 - a2* b4* c5* e1* m3 - 
    a5* b4* c1* e2* m3 + a4* b5* c1* e2* m3 + a5* b1* c4* e2* m3 - 
    a1* b5* c4* e2* m3 - a4* b1* c5* e2* m3 + a1* b4* c5* e2* m3 + 
    a5* b2* c1* e4* m3 - a2* b5* c1* e4* m3 - a5* b1* c2* e4* m3 + 
    a1* b5* c2* e4* m3 + a2* b1* c5* e4* m3 - a1* b2* c5* e4* m3 - 
    a4* b2* c1* e5* m3 + a2* b4* c1* e5* m3 + a4* b1* c2* e5* m3 - 
    a1* b4* c2* e5* m3 - a2* b1* c4* e5* m3 + a1* b2* c4* e5* m3 - 
    a5* b3* c2* e1* m4 + a3* b5* c2* e1* m4 + a5* b2* c3* e1* m4 - 
    a2* b5* c3* e1* m4 - a3* b2* c5* e1* m4 + a2* b3* c5* e1* m4 + 
    a5* b3* c1* e2* m4 - a3* b5* c1* e2* m4 - a5* b1* c3* e2* m4 + 
    a1* b5* c3* e2* m4 + a3* b1* c5* e2* m4 - a1* b3* c5* e2* m4 - 
    a5* b2* c1* e3* m4 + a2* b5* c1* e3* m4 + a5* b1* c2* e3* m4 - 
    a1* b5* c2* e3* m4 - a2* b1* c5* e3* m4 + a1* b2* c5* e3* m4 + 
    a3* b2* c1* e5* m4 - a2* b3* c1* e5* m4 - a3* b1* c2* e5* m4 + 
    a1* b3* c2* e5* m4 + a2* b1* c3* e5* m4 - a1* b2* c3* e5* m4 + 
    a4* b3* c2* e1* m5 - a3* b4* c2* e1* m5 - a4* b2* c3* e1* m5 + 
    a2* b4* c3* e1* m5 + a3* b2* c4* e1* m5 - a2* b3* c4* e1* m5 - 
    a4* b3* c1* e2* m5 + a3* b4* c1* e2* m5 + a4* b1* c3* e2* m5 - 
    a1* b4* c3* e2* m5 - a3* b1* c4* e2* m5 + a1* b3* c4* e2* m5 + 
    a4* b2* c1* e3* m5 - a2* b4* c1* e3* m5 - a4* b1* c2* e3* m5 + 
    a1* b4* c2* e3* m5 + a2* b1* c4* e3* m5 - a1* b2* c4* e3* m5 - 
    a3* b2* c1* e4* m5 + a2* b3* c1* e4* m5 + a3* b1* c2* e4* m5 - 
    a1* b3* c2* e4* m5 - a2* b1* c3* e4* m5 + a1* b2* c3* e4* m5) - 
 c6* (a5* b4* d3* e2* m1 - a4* b5* d3* e2* m1 - a5* b3* d4* e2* m1 + 
    a3* b5* d4* e2* m1 + a4* b3* d5* e2* m1 - a3* b4* d5* e2* m1 - 
    a5* b4* d2* e3* m1 + a4* b5* d2* e3* m1 + a5* b2* d4* e3* m1 - 
    a2* b5* d4* e3* m1 - a4* b2* d5* e3* m1 + a2* b4* d5* e3* m1 + 
    a5* b3* d2* e4* m1 - a3* b5* d2* e4* m1 - a5* b2* d3* e4* m1 + 
    a2* b5* d3* e4* m1 + a3* b2* d5* e4* m1 - a2* b3* d5* e4* m1 - 
    a4* b3* d2* e5* m1 + a3* b4* d2* e5* m1 + a4* b2* d3* e5* m1 - 
    a2* b4* d3* e5* m1 - a3* b2* d4* e5* m1 + a2* b3* d4* e5* m1 - 
    a5* b4* d3* e1* m2 + a4* b5* d3* e1* m2 + a5* b3* d4* e1* m2 - 
    a3* b5* d4* e1* m2 - a4* b3* d5* e1* m2 + a3* b4* d5* e1* m2 + 
    a5* b4* d1* e3* m2 - a4* b5* d1* e3* m2 - a5* b1* d4* e3* m2 + 
    a1* b5* d4* e3* m2 + a4* b1* d5* e3* m2 - a1* b4* d5* e3* m2 - 
    a5* b3* d1* e4* m2 + a3* b5* d1* e4* m2 + a5* b1* d3* e4* m2 - 
    a1* b5* d3* e4* m2 - a3* b1* d5* e4* m2 + a1* b3* d5* e4* m2 + 
    a4* b3* d1* e5* m2 - a3* b4* d1* e5* m2 - a4* b1* d3* e5* m2 + 
    a1* b4* d3* e5* m2 + a3* b1* d4* e5* m2 - a1* b3* d4* e5* m2 + 
    a5* b4* d2* e1* m3 - a4* b5* d2* e1* m3 - a5* b2* d4* e1* m3 + 
    a2* b5* d4* e1* m3 + a4* b2* d5* e1* m3 - a2* b4* d5* e1* m3 - 
    a5* b4* d1* e2* m3 + a4* b5* d1* e2* m3 + a5* b1* d4* e2* m3 - 
    a1* b5* d4* e2* m3 - a4* b1* d5* e2* m3 + a1* b4* d5* e2* m3 + 
    a5* b2* d1* e4* m3 - a2* b5* d1* e4* m3 - a5* b1* d2* e4* m3 + 
    a1* b5* d2* e4* m3 + a2* b1* d5* e4* m3 - a1* b2* d5* e4* m3 - 
    a4* b2* d1* e5* m3 + a2* b4* d1* e5* m3 + a4* b1* d2* e5* m3 - 
    a1* b4* d2* e5* m3 - a2* b1* d4* e5* m3 + a1* b2* d4* e5* m3 - 
    a5* b3* d2* e1* m4 + a3* b5* d2* e1* m4 + a5* b2* d3* e1* m4 - 
    a2* b5* d3* e1* m4 - a3* b2* d5* e1* m4 + a2* b3* d5* e1* m4 + 
    a5* b3* d1* e2* m4 - a3* b5* d1* e2* m4 - a5* b1* d3* e2* m4 + 
    a1* b5* d3* e2* m4 + a3* b1* d5* e2* m4 - a1* b3* d5* e2* m4 - 
    a5* b2* d1* e3* m4 + a2* b5* d1* e3* m4 + a5* b1* d2* e3* m4 - 
    a1* b5* d2* e3* m4 - a2* b1* d5* e3* m4 + a1* b2* d5* e3* m4 + 
    a3* b2* d1* e5* m4 - a2* b3* d1* e5* m4 - a3* b1* d2* e5* m4 + 
    a1* b3* d2* e5* m4 + a2* b1* d3* e5* m4 - a1* b2* d3* e5* m4 + 
    a4* b3* d2* e1* m5 - a3* b4* d2* e1* m5 - a4* b2* d3* e1* m5 + 
    a2* b4* d3* e1* m5 + a3* b2* d4* e1* m5 - a2* b3* d4* e1* m5 - 
    a4* b3* d1* e2* m5 + a3* b4* d1* e2* m5 + a4* b1* d3* e2* m5 - 
    a1* b4* d3* e2* m5 - a3* b1* d4* e2* m5 + a1* b3* d4* e2* m5 + 
    a4* b2* d1* e3* m5 - a2* b4* d1* e3* m5 - a4* b1* d2* e3* m5 + 
    a1* b4* d2* e3* m5 + a2* b1* d4* e3* m5 - a1* b2* d4* e3* m5 - 
    a3* b2* d1* e4* m5 + a2* b3* d1* e4* m5 + a3* b1* d2* e4* m5 - 
    a1* b3* d2* e4* m5 - a2* b1* d3* e4* m5 + a1* b2* d3* e4* m5) + 
 b6* (a5* c4* d3* e2* m1 - a4* c5* d3* e2* m1 - a5* c3* d4* e2* m1 + 
    a3* c5* d4* e2* m1 + a4* c3* d5* e2* m1 - a3* c4* d5* e2* m1 - 
    a5* c4* d2* e3* m1 + a4* c5* d2* e3* m1 + a5* c2* d4* e3* m1 - 
    a2* c5* d4* e3* m1 - a4* c2* d5* e3* m1 + a2* c4* d5* e3* m1 + 
    a5* c3* d2* e4* m1 - a3* c5* d2* e4* m1 - a5* c2* d3* e4* m1 + 
    a2* c5* d3* e4* m1 + a3* c2* d5* e4* m1 - a2* c3* d5* e4* m1 - 
    a4* c3* d2* e5* m1 + a3* c4* d2* e5* m1 + a4* c2* d3* e5* m1 - 
    a2* c4* d3* e5* m1 - a3* c2* d4* e5* m1 + a2* c3* d4* e5* m1 - 
    a5* c4* d3* e1* m2 + a4* c5* d3* e1* m2 + a5* c3* d4* e1* m2 - 
    a3* c5* d4* e1* m2 - a4* c3* d5* e1* m2 + a3* c4* d5* e1* m2 + 
    a5* c4* d1* e3* m2 - a4* c5* d1* e3* m2 - a5* c1* d4* e3* m2 + 
    a1* c5* d4* e3* m2 + a4* c1* d5* e3* m2 - a1* c4* d5* e3* m2 - 
    a5* c3* d1* e4* m2 + a3* c5* d1* e4* m2 + a5* c1* d3* e4* m2 - 
    a1* c5* d3* e4* m2 - a3* c1* d5* e4* m2 + a1* c3* d5* e4* m2 + 
    a4* c3* d1* e5* m2 - a3* c4* d1* e5* m2 - a4* c1* d3* e5* m2 + 
    a1* c4* d3* e5* m2 + a3* c1* d4* e5* m2 - a1* c3* d4* e5* m2 + 
    a5* c4* d2* e1* m3 - a4* c5* d2* e1* m3 - a5* c2* d4* e1* m3 + 
    a2* c5* d4* e1* m3 + a4* c2* d5* e1* m3 - a2* c4* d5* e1* m3 - 
    a5* c4* d1* e2* m3 + a4* c5* d1* e2* m3 + a5* c1* d4* e2* m3 - 
    a1* c5* d4* e2* m3 - a4* c1* d5* e2* m3 + a1* c4* d5* e2* m3 + 
    a5* c2* d1* e4* m3 - a2* c5* d1* e4* m3 - a5* c1* d2* e4* m3 + 
    a1* c5* d2* e4* m3 + a2* c1* d5* e4* m3 - a1* c2* d5* e4* m3 - 
    a4* c2* d1* e5* m3 + a2* c4* d1* e5* m3 + a4* c1* d2* e5* m3 - 
    a1* c4* d2* e5* m3 - a2* c1* d4* e5* m3 + a1* c2* d4* e5* m3 - 
    a5* c3* d2* e1* m4 + a3* c5* d2* e1* m4 + a5* c2* d3* e1* m4 - 
    a2* c5* d3* e1* m4 - a3* c2* d5* e1* m4 + a2* c3* d5* e1* m4 + 
    a5* c3* d1* e2* m4 - a3* c5* d1* e2* m4 - a5* c1* d3* e2* m4 + 
    a1* c5* d3* e2* m4 + a3* c1* d5* e2* m4 - a1* c3* d5* e2* m4 - 
    a5* c2* d1* e3* m4 + a2* c5* d1* e3* m4 + a5* c1* d2* e3* m4 - 
    a1* c5* d2* e3* m4 - a2* c1* d5* e3* m4 + a1* c2* d5* e3* m4 + 
    a3* c2* d1* e5* m4 - a2* c3* d1* e5* m4 - a3* c1* d2* e5* m4 + 
    a1* c3* d2* e5* m4 + a2* c1* d3* e5* m4 - a1* c2* d3* e5* m4 + 
    a4* c3* d2* e1* m5 - a3* c4* d2* e1* m5 - a4* c2* d3* e1* m5 + 
    a2* c4* d3* e1* m5 + a3* c2* d4* e1* m5 - a2* c3* d4* e1* m5 - 
    a4* c3* d1* e2* m5 + a3* c4* d1* e2* m5 + a4* c1* d3* e2* m5 - 
    a1* c4* d3* e2* m5 - a3* c1* d4* e2* m5 + a1* c3* d4* e2* m5 + 
    a4* c2* d1* e3* m5 - a2* c4* d1* e3* m5 - a4* c1* d2* e3* m5 + 
    a1* c4* d2* e3* m5 + a2* c1* d4* e3* m5 - a1* c2* d4* e3* m5 - 
    a3* c2* d1* e4* m5 + a2* c3* d1* e4* m5 + a3* c1* d2* e4* m5 - 
    a1* c3* d2* e4* m5 - a2* c1* d3* e4* m5 + a1* c2* d3* e4* m5) - 
 a6* (b5* c4* d3* e2* m1 - b4* c5* d3* e2* m1 - b5* c3* d4* e2* m1 + 
    b3* c5* d4* e2* m1 + b4* c3* d5* e2* m1 - b3* c4* d5* e2* m1 - 
    b5* c4* d2* e3* m1 + b4* c5* d2* e3* m1 + b5* c2* d4* e3* m1 - 
    b2* c5* d4* e3* m1 - b4* c2* d5* e3* m1 + b2* c4* d5* e3* m1 + 
    b5* c3* d2* e4* m1 - b3* c5* d2* e4* m1 - b5* c2* d3* e4* m1 + 
    b2* c5* d3* e4* m1 + b3* c2* d5* e4* m1 - b2* c3* d5* e4* m1 - 
    b4* c3* d2* e5* m1 + b3* c4* d2* e5* m1 + b4* c2* d3* e5* m1 - 
    b2* c4* d3* e5* m1 - b3* c2* d4* e5* m1 + b2* c3* d4* e5* m1 - 
    b5* c4* d3* e1* m2 + b4* c5* d3* e1* m2 + b5* c3* d4* e1* m2 - 
    b3* c5* d4* e1* m2 - b4* c3* d5* e1* m2 + b3* c4* d5* e1* m2 + 
    b5* c4* d1* e3* m2 - b4* c5* d1* e3* m2 - b5* c1* d4* e3* m2 + 
    b1* c5* d4* e3* m2 + b4* c1* d5* e3* m2 - b1* c4* d5* e3* m2 - 
    b5* c3* d1* e4* m2 + b3* c5* d1* e4* m2 + b5* c1* d3* e4* m2 - 
    b1* c5* d3* e4* m2 - b3* c1* d5* e4* m2 + b1* c3* d5* e4* m2 + 
    b4* c3* d1* e5* m2 - b3* c4* d1* e5* m2 - b4* c1* d3* e5* m2 + 
    b1* c4* d3* e5* m2 + b3* c1* d4* e5* m2 - b1* c3* d4* e5* m2 + 
    b5* c4* d2* e1* m3 - b4* c5* d2* e1* m3 - b5* c2* d4* e1* m3 + 
    b2* c5* d4* e1* m3 + b4* c2* d5* e1* m3 - b2* c4* d5* e1* m3 - 
    b5* c4* d1* e2* m3 + b4* c5* d1* e2* m3 + b5* c1* d4* e2* m3 - 
    b1* c5* d4* e2* m3 - b4* c1* d5* e2* m3 + b1* c4* d5* e2* m3 + 
    b5* c2* d1* e4* m3 - b2* c5* d1* e4* m3 - b5* c1* d2* e4* m3 + 
    b1* c5* d2* e4* m3 + b2* c1* d5* e4* m3 - b1* c2* d5* e4* m3 - 
    b4* c2* d1* e5* m3 + b2* c4* d1* e5* m3 + b4* c1* d2* e5* m3 - 
    b1* c4* d2* e5* m3 - b2* c1* d4* e5* m3 + b1* c2* d4* e5* m3 - 
    b5* c3* d2* e1* m4 + b3* c5* d2* e1* m4 + b5* c2* d3* e1* m4 - 
    b2* c5* d3* e1* m4 - b3* c2* d5* e1* m4 + b2* c3* d5* e1* m4 + 
    b5* c3* d1* e2* m4 - b3* c5* d1* e2* m4 - b5* c1* d3* e2* m4 + 
    b1* c5* d3* e2* m4 + b3* c1* d5* e2* m4 - b1* c3* d5* e2* m4 - 
    b5* c2* d1* e3* m4 + b2* c5* d1* e3* m4 + b5* c1* d2* e3* m4 - 
    b1* c5* d2* e3* m4 - b2* c1* d5* e3* m4 + b1* c2* d5* e3* m4 + 
    b3* c2* d1* e5* m4 - b2* c3* d1* e5* m4 - b3* c1* d2* e5* m4 + 
    b1* c3* d2* e5* m4 + b2* c1* d3* e5* m4 - b1* c2* d3* e5* m4 + 
    b4* c3* d2* e1* m5 - b3* c4* d2* e1* m5 - b4* c2* d3* e1* m5 + 
    b2* c4* d3* e1* m5 + b3* c2* d4* e1* m5 - b2* c3* d4* e1* m5 - 
    b4* c3* d1* e2* m5 + b3* c4* d1* e2* m5 + b4* c1* d3* e2* m5 - 
    b1* c4* d3* e2* m5 - b3* c1* d4* e2* m5 + b1* c3* d4* e2* m5 + 
    b4* c2* d1* e3* m5 - b2* c4* d1* e3* m5 - b4* c1* d2* e3* m5 + 
    b1* c4* d2* e3* m5 + b2* c1* d4* e3* m5 - b1* c2* d4* e3* m5 - 
    b3* c2* d1* e4* m5 + b2* c3* d1* e4* m5 + b3* c1* d2* e4* m5 - 
    b1* c3* d2* e4* m5 - b2* c1* d3* e4* m5 + 	
    b1* c2* d3* e4* m5) + (a5* b4* c3* d2* e1 - a4* b5* c3* d2* e1 - 
    a5* b3* c4* d2* e1 + a3* b5* c4* d2* e1 + a4* b3* c5* d2* e1 - 
    a3* b4* c5* d2* e1 - a5* b4* c2* d3* e1 + a4* b5* c2* d3* e1 + 
    a5* b2* c4* d3* e1 - a2* b5* c4* d3* e1 - a4* b2* c5* d3* e1 + 
    a2* b4* c5* d3* e1 + a5* b3* c2* d4* e1 - a3* b5* c2* d4* e1 - 
    a5* b2* c3* d4* e1 + a2* b5* c3* d4* e1 + a3* b2* c5* d4* e1 - 
    a2* b3* c5* d4* e1 - a4* b3* c2* d5* e1 + a3* b4* c2* d5* e1 + 
    a4* b2* c3* d5* e1 - a2* b4* c3* d5* e1 - a3* b2* c4* d5* e1 + 
    a2* b3* c4* d5* e1 - a5* b4* c3* d1* e2 + a4* b5* c3* d1* e2 + 
    a5* b3* c4* d1* e2 - a3* b5* c4* d1* e2 - a4* b3* c5* d1* e2 + 
    a3* b4* c5* d1* e2 + a5* b4* c1* d3* e2 - a4* b5* c1* d3* e2 - 
    a5* b1* c4* d3* e2 + a1* b5* c4* d3* e2 + a4* b1* c5* d3* e2 - 
    a1* b4* c5* d3* e2 - a5* b3* c1* d4* e2 + a3* b5* c1* d4* e2 + 
    a5* b1* c3* d4* e2 - a1* b5* c3* d4* e2 - a3* b1* c5* d4* e2 + 
    a1* b3* c5* d4* e2 + a4* b3* c1* d5* e2 - a3* b4* c1* d5* e2 - 
    a4* b1* c3* d5* e2 + a1* b4* c3* d5* e2 + a3* b1* c4* d5* e2 - 
    a1* b3* c4* d5* e2 + a5* b4* c2* d1* e3 - a4* b5* c2* d1* e3 - 
    a5* b2* c4* d1* e3 + a2* b5* c4* d1* e3 + a4* b2* c5* d1* e3 - 
    a2* b4* c5* d1* e3 - a5* b4* c1* d2* e3 + a4* b5* c1* d2* e3 + 
    a5* b1* c4* d2* e3 - a1* b5* c4* d2* e3 - a4* b1* c5* d2* e3 + 
    a1* b4* c5* d2* e3 + a5* b2* c1* d4* e3 - a2* b5* c1* d4* e3 - 
    a5* b1* c2* d4* e3 + a1* b5* c2* d4* e3 + a2* b1* c5* d4* e3 - 
    a1* b2* c5* d4* e3 - a4* b2* c1* d5* e3 + a2* b4* c1* d5* e3 + 
    a4* b1* c2* d5* e3 - a1* b4* c2* d5* e3 - a2* b1* c4* d5* e3 + 
    a1* b2* c4* d5* e3 - a5* b3* c2* d1* e4 + a3* b5* c2* d1* e4 + 
    a5* b2* c3* d1* e4 - a2* b5* c3* d1* e4 - a3* b2* c5* d1* e4 + 
    a2* b3* c5* d1* e4 + a5* b3* c1* d2* e4 - a3* b5* c1* d2* e4 - 
    a5* b1* c3* d2* e4 + a1* b5* c3* d2* e4 + a3* b1* c5* d2* e4 - 
    a1* b3* c5* d2* e4 - a5* b2* c1* d3* e4 + a2* b5* c1* d3* e4 + 
    a5* b1* c2* d3* e4 - a1* b5* c2* d3* e4 - a2* b1* c5* d3* e4 + 
    a1* b2* c5* d3* e4 + a3* b2* c1* d5* e4 - a2* b3* c1* d5* e4 - 
    a3* b1* c2* d5* e4 + a1* b3* c2* d5* e4 + a2* b1* c3* d5* e4 - 
    a1* b2* c3* d5* e4 + a4* b3* c2* d1* e5 - a3* b4* c2* d1* e5 - 
    a4* b2* c3* d1* e5 + a2* b4* c3* d1* e5 + a3* b2* c4* d1* e5 - 
    a2* b3* c4* d1* e5 - a4* b3* c1* d2* e5 + a3* b4* c1* d2* e5 + 
    a4* b1* c3* d2* e5 - a1* b4* c3* d2* e5 - a3* b1* c4* d2* e5 + 
    a1* b3* c4* d2* e5 + a4* b2* c1* d3* e5 - a2* b4* c1* d3* e5 - 
    a4* b1* c2* d3* e5 + a1* b4* c2* d3* e5 + a2* b1* c4* d3* e5 - 
    a1* b2* c4* d3* e5 - a3* b2* c1* d4* e5 + a2* b3* c1* d4* e5 + 
    a3* b1* c2* d4* e5 - a1* b3* c2* d4* e5 - a2* b1* c3* d4* e5 + 
		       a1* b2* c3* d4* e5) *m6;

    if (p==0)
      detA = det;
    else if (p==1)
      detB[0]=det;
    else if (p==2)
      detB[1]=det;
    else if (p==3)
      detB[2]=det;
    else if (p==4)
      detB[3]=det;
    else if (p==5)
      detB[4]=det;
    else
      detB[5]=det;
    }

    }
    else if (pts==5) {

      for (p=0;p<(pts+1);p++) {
      
	if (p==0)
	  ;
	else if (p==1) {
	  a1 = f1; 
	  a2 = f2;
	  a3 = f3;
	  a4 = f4;
	  a5 = f5;
	}
	else if (p==2) {
 	  a1=a[0][0]; b1 = f1; 
          a2=a[1][0]; b2 = f2;
	  a3=a[2][0]; b3 = f3;
	  a4=a[3][0]; b4 = f4; 
	  a5=a[4][0]; b5 = f5;
        }
	else if (p==3) {
 	  b1=a[0][1]; c1 = f1; 
          b2=a[1][1]; c2 = f2;
	  b3=a[2][1]; c3 = f3;
	  b4=a[3][1]; c4 = f4; 
	  b5=a[4][1]; c5 = f5;
        }
	else if (p==4) {
 	  c1=a[0][2]; d1 = f1; 
          c2=a[1][2]; d2 = f2;
	  c3=a[2][2]; d3 = f3;
	  c4=a[3][2]; d4 = f4; 
	  c5=a[4][2]; d5 = f5;
        }
	else { // case (p==5) 
 	  d1=a[0][3]; e1 = f1; 
          d2=a[1][3]; e2 = f2;
	  d3=a[2][3]; e3 = f3;
	  d4=a[3][3]; e4 = f4; 
	  d5=a[4][3]; e5 = f5;
        }
    	  

    det = a5*b4*c3*d2*e1 - a4*b5*c3*d2*e1 - a5*b3*c4*d2*e1 + a3*b5*c4*d2*e1 + 
      a4*b3*c5*d2*e1 - a3*b4*c5*d2*e1 - a5*b4*c2*d3*e1 + a4*b5*c2*d3*e1 + 
      a5*b2*c4*d3*e1 - a2*b5*c4*d3*e1 - a4*b2*c5*d3*e1 + a2*b4*c5*d3*e1 + 
      a5*b3*c2*d4*e1 - a3*b5*c2*d4*e1 - a5*b2*c3*d4*e1 + a2*b5*c3*d4*e1 + 
      a3*b2*c5*d4*e1 - a2*b3*c5*d4*e1 - a4*b3*c2*d5*e1 + a3*b4*c2*d5*e1 + 
      a4*b2*c3*d5*e1 - a2*b4*c3*d5*e1 - a3*b2*c4*d5*e1 + a2*b3*c4*d5*e1 - 
      a5*b4*c3*d1*e2 + a4*b5*c3*d1*e2 + a5*b3*c4*d1*e2 - a3*b5*c4*d1*e2 - 
      a4*b3*c5*d1*e2 + a3*b4*c5*d1*e2 + a5*b4*c1*d3*e2 - a4*b5*c1*d3*e2 - 
      a5*b1*c4*d3*e2 + a1*b5*c4*d3*e2 + a4*b1*c5*d3*e2 - a1*b4*c5*d3*e2 - 
      a5*b3*c1*d4*e2 + a3*b5*c1*d4*e2 + a5*b1*c3*d4*e2 - a1*b5*c3*d4*e2 - 
      a3*b1*c5*d4*e2 + a1*b3*c5*d4*e2 + a4*b3*c1*d5*e2 - a3*b4*c1*d5*e2 - 
      a4*b1*c3*d5*e2 + a1*b4*c3*d5*e2 + a3*b1*c4*d5*e2 - a1*b3*c4*d5*e2 + 
      a5*b4*c2*d1*e3 - a4*b5*c2*d1*e3 - a5*b2*c4*d1*e3 + a2*b5*c4*d1*e3 + 
      a4*b2*c5*d1*e3 - a2*b4*c5*d1*e3 - a5*b4*c1*d2*e3 + a4*b5*c1*d2*e3 + 
      a5*b1*c4*d2*e3 - a1*b5*c4*d2*e3 - a4*b1*c5*d2*e3 + a1*b4*c5*d2*e3 + 
      a5*b2*c1*d4*e3 - a2*b5*c1*d4*e3 - a5*b1*c2*d4*e3 + a1*b5*c2*d4*e3 + 
      a2*b1*c5*d4*e3 - a1*b2*c5*d4*e3 - a4*b2*c1*d5*e3 + a2*b4*c1*d5*e3 + 
      a4*b1*c2*d5*e3 - a1*b4*c2*d5*e3 - a2*b1*c4*d5*e3 + a1*b2*c4*d5*e3 - 
      a5*b3*c2*d1*e4 + a3*b5*c2*d1*e4 + a5*b2*c3*d1*e4 - a2*b5*c3*d1*e4 - 
      a3*b2*c5*d1*e4 + a2*b3*c5*d1*e4 + a5*b3*c1*d2*e4 - a3*b5*c1*d2*e4 - 
      a5*b1*c3*d2*e4 + a1*b5*c3*d2*e4 + a3*b1*c5*d2*e4 - a1*b3*c5*d2*e4 - 
      a5*b2*c1*d3*e4 + a2*b5*c1*d3*e4 + a5*b1*c2*d3*e4 - a1*b5*c2*d3*e4 - 
      a2*b1*c5*d3*e4 + a1*b2*c5*d3*e4 + a3*b2*c1*d5*e4 - a2*b3*c1*d5*e4 - 
      a3*b1*c2*d5*e4 + a1*b3*c2*d5*e4 + a2*b1*c3*d5*e4 - a1*b2*c3*d5*e4 + 
      a4*b3*c2*d1*e5 - a3*b4*c2*d1*e5 - a4*b2*c3*d1*e5 + a2*b4*c3*d1*e5 + 
      a3*b2*c4*d1*e5 - a2*b3*c4*d1*e5 - a4*b3*c1*d2*e5 + a3*b4*c1*d2*e5 + 
      a4*b1*c3*d2*e5 - a1*b4*c3*d2*e5 - a3*b1*c4*d2*e5 + a1*b3*c4*d2*e5 + 
      a4*b2*c1*d3*e5 - a2*b4*c1*d3*e5 - a4*b1*c2*d3*e5 + a1*b4*c2*d3*e5 + 
      a2*b1*c4*d3*e5 - a1*b2*c4*d3*e5 - a3*b2*c1*d4*e5 + a2*b3*c1*d4*e5 + 
      a3*b1*c2*d4*e5 - a1*b3*c2*d4*e5 - a2*b1*c3*d4*e5 + a1*b2*c3*d4*e5;

    if (p==0)
      detA = det;
    else if (p==1)
      detB[0]=det;
    else if (p==2)
      detB[1]=det;
    else if (p==3)
      detB[2]=det;
    else if (p==4)
      detB[3]=det;
    else 
      detB[4]=det;
    }

    }
    else if (pts==4) {

    detA    = a4*b3*c2*d1 - a3*b4*c2*d1 - a4*b2*c3*d1 + a2*b4*c3*d1 + a3*b2*c4*d1 - a2*b3*c4*d1 
            - a4*b3*c1*d2 + a3*b4*c1*d2 + a4*b1*c3*d2 - a1*b4*c3*d2 - a3*b1*c4*d2 + a1*b3*c4*d2 
            + a4*b2*c1*d3 - a2*b4*c1*d3 - a4*b1*c2*d3 + a1*b4*c2*d3 + a2*b1*c4*d3 - a1*b2*c4*d3
            - a3*b2*c1*d4 + a2*b3*c1*d4 + a3*b1*c2*d4 - a1*b3*c2*d4 - a2*b1*c3*d4 + a1*b2*c3*d4;
 
    detB[0]  = f4*b3*c2*d1 - f3*b4*c2*d1 - f4*b2*c3*d1 + f2*b4*c3*d1 + f3*b2*c4*d1 - f2*b3*c4*d1 
             - f4*b3*c1*d2 + f3*b4*c1*d2 + f4*b1*c3*d2 - f1*b4*c3*d2 - f3*b1*c4*d2 + f1*b3*c4*d2 
             + f4*b2*c1*d3 - f2*b4*c1*d3 - f4*b1*c2*d3 + f1*b4*c2*d3 + f2*b1*c4*d3 - f1*b2*c4*d3
             - f3*b2*c1*d4 + f2*b3*c1*d4 + f3*b1*c2*d4 - f1*b3*c2*d4 - f2*b1*c3*d4 + f1*b2*c3*d4;

    detB[1]  = a4*f3*c2*d1 - a3*f4*c2*d1 - a4*f2*c3*d1 + a2*f4*c3*d1 + a3*f2*c4*d1 - a2*f3*c4*d1 
             - a4*f3*c1*d2 + a3*f4*c1*d2 + a4*f1*c3*d2 - a1*f4*c3*d2 - a3*f1*c4*d2 + a1*f3*c4*d2 
             + a4*f2*c1*d3 - a2*f4*c1*d3 - a4*f1*c2*d3 + a1*f4*c2*d3 + a2*f1*c4*d3 - a1*f2*c4*d3
             - a3*f2*c1*d4 + a2*f3*c1*d4 + a3*f1*c2*d4 - a1*f3*c2*d4 - a2*f1*c3*d4 + a1*f2*c3*d4;

    detB[2]  = a4*b3*f2*d1 - a3*b4*f2*d1 - a4*b2*f3*d1 + a2*b4*f3*d1 + a3*b2*f4*d1 - a2*b3*f4*d1 
             - a4*b3*f1*d2 + a3*b4*f1*d2 + a4*b1*f3*d2 - a1*b4*f3*d2 - a3*b1*f4*d2 + a1*b3*f4*d2 
             + a4*b2*f1*d3 - a2*b4*f1*d3 - a4*b1*f2*d3 + a1*b4*f2*d3 + a2*b1*f4*d3 - a1*b2*f4*d3
             - a3*b2*f1*d4 + a2*b3*f1*d4 + a3*b1*f2*d4 - a1*b3*f2*d4 - a2*b1*f3*d4 + a1*b2*f3*d4;

    detB[3]  = a4*b3*c2*f1 - a3*b4*c2*f1 - a4*b2*c3*f1 + a2*b4*c3*f1 + a3*b2*c4*f1 - a2*b3*c4*f1 
             - a4*b3*c1*f2 + a3*b4*c1*f2 + a4*b1*c3*f2 - a1*b4*c3*f2 - a3*b1*c4*f2 + a1*b3*c4*f2 
             + a4*b2*c1*f3 - a2*b4*c1*f3 - a4*b1*c2*f3 + a1*b4*c2*f3 + a2*b1*c4*f3 - a1*b2*c4*f3
             - a3*b2*c1*f4 + a2*b3*c1*f4 + a3*b1*c2*f4 - a1*b3*c2*f4 - a2*b1*c3*f4 + a1*b2*c3*f4;

    }
    else if (pts==3) {
      detA    = -a3*b2*c1 + a2*b3*c1 + a3*b1*c2 - a1*b3*c2 - a2*b1*c3 + a1*b2*c3; 
      detB[0] = -f3*b2*c1 + f2*b3*c1 + f3*b1*c2 - f1*b3*c2 - f2*b1*c3 + f1*b2*c3; 
      detB[1] = -a3*f2*c1 + a2*f3*c1 + a3*f1*c2 - a1*f3*c2 - a2*f1*c3 + a1*f2*c3; 
      detB[2] = -a3*b2*f1 + a2*b3*f1 + a3*b1*f2 - a1*b3*f2 - a2*b1*f3 + a1*b2*f3; 
    }
    else {
      fprintf(stderr,"No solution to system of equation for %d points\n",pts);
      exit(0);
    }

  for (i=0;i<(pts);i++) {
    k[i]=detB[i]/detA;
    //printf("k[%d]=%f\n",i,k[i]);
  }
  
  for (i=0;i<(pts-1);i++) {
    pa[i]= k[i]  *(x[(i+1)]-x[i])-(fx[(i+1)]-fx[i]);
    pb[i]=-k[i+1]*(x[(i+1)]-x[i])+(fx[(i+1)]-fx[i]);
    //printf("pa[%d]=%f  pb[%d]=%f\n",i,pa[i],pb[i]);
  }
  for (i=0;i<(pts-1);i++) {
    diffx=(x[(i+1)]-x[i]);
    q0[i] = fx[i] - x[i]*(fx[(i+1)]-fx[i]+pa[i])/diffx + x[i]*x[i]*(pb[i]-2*pa[i])/(diffx*diffx)
      - x[i]*x[i]*x[i]*(pa[i]-pb[i])/(diffx*diffx*diffx);
    q1[i] = (fx[(i+1)]-fx[i]+pa[i])/diffx -2*x[i]*(pb[i]-2*pa[i])/(diffx*diffx) + 3*x[i]*x[i]*(pa[i]-pb[i])/(diffx*diffx*diffx);
    q2[i] = (pb[i]-2*pa[i])/(diffx*diffx) - 3*x[i]*(pa[i]-pb[i])/(diffx*diffx*diffx);
    q3[i] = (pa[i]-pb[i])/(diffx*diffx*diffx);
  }
  for (i=0;i<(pts-1);i++) {
    diffx=(x[(i+1)]-x[i]);
    dq1[i] = (fx[(i+1)]-fx[i]+pa[i])/diffx -2*x[i]*(pb[i]-2*pa[i])/(diffx*diffx) + 3*x[i]*x[i]*(pa[i]-pb[i])/(diffx*diffx*diffx);
    dq2[i] = 2*( (pb[i]-2*pa[i])/(diffx*diffx) - 3*x[i]*(pa[i]-pb[i])/(diffx*diffx*diffx) );
    dq3[i] = 3*(pa[i]-pb[i])/(diffx*diffx*diffx);
    ( dqspline[i][0])=dq3[i];
    ( dqspline[i][1])=dq2[i];
    ( dqspline[i][2])=dq1[i];
  }


  fprintf(stderr,"Cubic spline\n");
  for (i=0;i<(pts-1);i++) {
    fprintf(stderr,"Cubic spline interval %d:%.2f-%.2f: y = %.9lf*x^3 + %.9lf*x^2 + %.9lf*x + %.9lf\n",i,x[i],x[i+1],q3[i],q2[i],q1[i],q0[i]);
  }
  fprintf(stderr,"Derivative\n");
  for (i=0;i<(pts-1);i++) {
    fprintf(stderr,"Cubic spline interval %d:%.2f-%.2f: y = %.9lf*x^2 + %.9lf*x + %.9lf\n",i,x[i],x[i+1],dq3[i],dq2[i],dq1[i]);
  }
}

